@@ -5,19 +5,16 @@ use warnings;
 use Carp;
 use Path::Tiny ();
 use Scalar::Util qw/blessed/;
-use Capture::Tiny 0.17 qw/capture_stdout/;
+use Capture::Tiny 0.17 qw/capture_merged/;
 use Text::ParseWords qw/shellwords/;
 
 # ABSTRACT: Base classes for Alien:: modules
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub import {
   my $class = shift;
 
-  return if $class eq __PACKAGE__;
-
   return if $class->runtime_prop;
 
   return if $class->install_type('system');
@@ -25,7 +22,7 @@ sub import {
   require DynaLoader;
 
   # Sanity check in order to ensure that dist_dir can be found.
-  # This will throw an exception otherwise.
+  # This will throw an exception otherwise.  
   $class->dist_dir;
 
   # get a reference to %Alien::MyLibrary::AlienLoaded
@@ -39,7 +36,7 @@ sub import {
 
   my @libs = $class->split_flags( $class->libs );
 
-  my @L = grep { s/^-L// } map { "$_" } @libs;  ## no critic (ControlStructures::ProhibitMutatingListFunctions)
+  my @L = grep { s/^-L// } @libs;
   my @l = grep { /^-l/ } @libs;
 
   unshift @DynaLoader::dl_library_path, @L;
@@ -69,10 +66,10 @@ sub import {
 sub _dist_dir ($)
 {
   my($dist_name) = @_;
-
+  
   my @pm = split /-/, $dist_name;
   $pm[-1] .= ".pm";
-
+  
   foreach my $inc (@INC)
   {
     my $pm = Path::Tiny->new($inc, @pm);
@@ -95,8 +92,8 @@ sub dist_dir {
   my $dist = blessed $class || $class;
   $dist =~ s/::/-/g;
 
-  my $dist_dir =
-    $class->config('finished_installing')
+  my $dist_dir = 
+    $class->config('finished_installing') 
       ? _dist_dir $dist
       : $class->config('working_directory');
 
@@ -112,7 +109,7 @@ sub new { return bless {}, $_[0] }
 sub _flags
 {
   my($class, $key) = @_;
-
+  
   my $config = $class->runtime_prop;
   my $flags = $config->{$key};
 
@@ -120,17 +117,16 @@ sub _flags
   $prefix =~ s{\\}{/}g if $^O =~ /^(MSWin32|msys)$/;
   my $distdir = $config->{distdir};
   $distdir =~ s{\\}{/}g if $^O =~ /^(MSWin32|msys)$/;
-
+  
   if($prefix ne $distdir)
   {
-    $flags = join ' ', map {
-      my $flag = $_;
-      $flag =~ s/^(-I|-L|-LIBPATH:)?\Q$prefix\E/$1$distdir/;
-      $flag =~ s/(\s)/\\$1/g;
-      $flag;
+    $flags = join ' ', map { 
+      s/^(-I|-L|-LIBPATH:)?\Q$prefix\E/$1$distdir/;
+      s/(\s)/\\$1/g;
+      $_;
     } $class->split_flags($flags);
   }
-
+  
   $flags;
 }
 
@@ -171,68 +167,6 @@ sub version {
 }
 
 
-sub atleast_version {
-  my $self = shift;
-  my ($wantver) = @_;
-
-  defined(my $version = $self->version) or
-    croak "$self has no defined ->version";
-
-  return $self->version_cmp($version, $wantver) >= 0;
-}
-
-sub exact_version {
-  my $self = shift;
-  my ($wantver) = @_;
-
-  defined(my $version = $self->version) or
-    croak "$self has no defined ->version";
-
-  return $self->version_cmp($version, $wantver) == 0;
-}
-
-sub max_version {
-  my $self = shift;
-  my ($wantver) = @_;
-
-  defined(my $version = $self->version) or
-    croak "$self has no defined ->version";
-
-  return $self->version_cmp($version, $wantver) <= 0;
-}
-
-
-# Sort::Versions isn't quite the same algorithm because it differs in
-# behaviour with leading zeroes.
-#   See also  https://dev.gentoo.org/~mgorny/pkg-config-spec.html#version-comparison
-sub version_cmp {
-  shift;
-  my @x = (shift =~ m/([0-9]+|[a-z]+)/ig);
-  my @y = (shift =~ m/([0-9]+|[a-z]+)/ig);
-
-  while(@x and @y) {
-    my $x = shift @x; my $x_isnum = $x =~ m/[0-9]/;
-    my $y = shift @y; my $y_isnum = $y =~ m/[0-9]/;
-
-    if($x_isnum and $y_isnum) {
-      # Numerical comparison
-      return $x <=> $y if $x != $y;
-    }
-    elsif(!$x_isnum && !$y_isnum) {
-      # Alphabetic comparison
-      return $x cmp $y if $x ne $y;
-    }
-    else {
-      # Of differing types, the numeric one is newer
-      return $x_isnum - $y_isnum;
-    }
-  }
-
-  # Equal so far; the longer is newer
-  return @x <=> @y;
-}
-
-
 sub install_type {
   my $self = shift;
   my $type = $self->config('install_type');
@@ -251,7 +185,7 @@ sub _pkgconfig_keyword {
     my $command = Alien::Base::PkgConfig->pkg_config_command . " @{[ $static ? '--static' : '' ]} --\L$keyword\E $name";
 
     $! = 0;
-    chomp ( my $pcdata = capture_stdout { system( $command ) } );
+    chomp ( my $pcdata = capture_merged { system( $command ) } );
 
     # if pkg-config fails for whatever reason, then we try to
     # fallback on alien_provides_*
@@ -273,7 +207,7 @@ sub _pkgconfig_keyword {
   my @pc = $self->_pkgconfig(@_);
   my @strings =
     grep defined,
-    map { $_->keyword($keyword,
+    map { $_->keyword($keyword, 
       #{ pcfiledir => $dist_dir }
     ) }
     @pc;
@@ -284,10 +218,9 @@ sub _pkgconfig_keyword {
     $dist_dir =~ s{\\}{/}g if $^O eq 'MSWin32';
     my $old = quotemeta $self->config('original_prefix');
     @strings = map {
-      my $flag = $_;
-      $flag =~ s{^(-I|-L|-LIBPATH:)?($old)}{$1.$dist_dir}e;
-      $flag =~ s/(\s)/\\$1/g;
-      $flag;
+      s{^(-I|-L|-LIBPATH:)?($old)}{$1.$dist_dir}e;
+      s/(\s)/\\$1/g;
+      $_;
     } map { $self->split_flags($_) } @strings;
   }
 
@@ -307,16 +240,14 @@ sub _pkgconfig {
     $all{$pkg->{package}} = $pkg;
   };
   File::Find::find( $wanted, $self->dist_dir );
-
+    
   croak "No Alien::Base::PkgConfig objects are stored!"
     unless keys %all;
-
+  
   # Run through all pkgconfig objects and ensure that their modules are loaded:
   for my $pkg_obj (values %all) {
     my $perl_module_name = blessed $pkg_obj;
-    my $pm = "$perl_module_name.pm";
-    $pm =~ s/::/\//g;
-    eval { require $pm };
+    eval "require $perl_module_name"; 
   }
 
   return @all{@_} if @_;
@@ -343,19 +274,8 @@ sub config {
   }
 
   my $config = $class . '::ConfigData';
-  my $pm = "$class/ConfigData.pm";
-  $pm =~ s{::}{/}g;
-  eval { require $pm };
-
-  if($@)
-  {
-    warn "Cannot find either a share directory or a ConfigData module for $class.\n";
-    my $pm = "$class.pm";
-    $pm =~ s{::}{/}g;
-    warn "($class loaded from $INC{$pm})\n" if $INC{$pm};
-    warn "Please see https://metacpan.org/pod/distribution/Alien-Build/lib/Alien/Build/Manual/FAQ.pod#Cannot-find-either-a-share-directory-or-a-ConfigData-module\n";
-    die $@;
-  }
+  eval "require $config";
+  warn $@ if $@;
 
   return $config->config(@_);
 }
@@ -390,58 +310,27 @@ sub split_flags_windows {
 
 sub dynamic_libs {
   my ($class) = @_;
-
+  
   require FFI::CheckLib;
-
-  my @find_lib_flags;
-
+  
   if($class->install_type('system')) {
 
-    if(my $prop = $class->runtime_prop)
-    {
-      if($prop->{ffi_checklib}->{system})
-      {
-        push @find_lib_flags, @{ $prop->{ffi_checklib}->{system} };
-      }
-      return FFI::CheckLib::find_lib( lib => $prop->{ffi_name}, @find_lib_flags )
-        if defined $prop->{ffi_name};
-    }
-
     my $name = $class->config('ffi_name');
-    unless(defined $name)
-    {
+    unless(defined $name) {
       $name = $class->config('name');
-      $name = '' unless defined $name;
       # strip leading lib from things like libarchive or libffi
       $name =~ s/^lib//;
       # strip trailing version numbers
       $name =~ s/-[0-9\.]+$//;
     }
-
-    my @libpath;
-    foreach my $flag ($class->split_flags($class->libs))
-    {
-      if($flag =~ /^-L(.*)$/)
-      {
-        push @libpath, $1;
-      }
-    }
-
-    return FFI::CheckLib::find_lib(lib => $name, libpath => \@libpath, @find_lib_flags );
-
+    
+    return FFI::CheckLib::find_lib(lib => $name);
+  
   } else {
-
+  
     my $dir = $class->dist_dir;
     my $dynamic = Path::Tiny->new($class->dist_dir, 'dynamic');
-
-    if(my $prop = $class->runtime_prop)
-    {
-      if($prop->{ffi_checklib}->{share})
-      {
-        push @find_lib_flags, @{ $prop->{ffi_checklib}->{share_flags} };
-      }
-    }
-
+    
     if(-d $dynamic)
     {
       return FFI::CheckLib::find_lib(
@@ -466,8 +355,8 @@ sub bin_dir {
   if($class->install_type('system'))
   {
     my $prop = $class->runtime_prop;
-    return () unless defined $prop;
-    return () unless defined $prop->{system_bin_dir};
+    return unless defined $prop;
+    return unless defined $prop->{system_bin_dir};
     return ref $prop->{system_bin_dir} ? @{ $prop->{system_bin_dir} } : ($prop->{system_bin_dir});
   }
   else
@@ -493,17 +382,14 @@ sub Inline {
   my ($class, $language) = @_;
   return if $language !~ /^(C|CPP)$/;
   my $config = {
-    # INC should arguably be for -I flags only, but
-    # this improves compat with ExtUtils::Depends.
-    # see gh#107, gh#108
-    INC          => $class->cflags,
+    CCFLAGSEX    => $class->cflags,
     LIBS         => $class->libs,
   };
-
+  
   if (@{ $class->inline_auto_include } > 0) {
     $config->{AUTO_INCLUDE} = join "\n", map { "#include \"$_\"" } @{ $class->inline_auto_include };
   }
-
+  
   $config;
 }
 
@@ -514,18 +400,10 @@ sub Inline {
   sub runtime_prop
   {
     my($class) = @_;
-
-    if(ref($class))
-    {
-      # called as an instance method.
-      my $self = $class;
-      $class = ref $self;
-      return $self->{_alt}->{runtime_prop} if defined $self->{_alt};
-    }
-
+  
     return $alien_build_config_cache{$class} if
       exists $alien_build_config_cache{$class};
-
+  
     $alien_build_config_cache{$class} ||= do {
       my $dist = ref $class ? ref $class : $class;
       $dist =~ s/::/-/g;
@@ -542,62 +420,6 @@ sub Inline {
   }
 }
 
-
-sub alt
-{
-  my($old, $name) = @_;
-  my $new = ref $old ? (ref $old)->new : $old->new;
-
-  my $orig;
-
-  if(ref($old) && defined $old->{_alt})
-  { $orig = $old->{_alt}->{orig} }
-  else
-  { $orig = $old->runtime_prop }
-
-  require Storable;
-  my $runtime_prop = Storable::dclone($orig);
-
-  if($runtime_prop->{alt}->{$name})
-  {
-    foreach my $key (keys %{ $runtime_prop->{alt}->{$name} })
-    {
-      $runtime_prop->{$key} = $runtime_prop->{alt}->{$name}->{$key};
-    }
-  }
-  else
-  {
-    Carp::croak("no such alt: $name");
-  }
-
-  $new->{_alt} = {
-    runtime_prop => $runtime_prop,
-    orig         => $orig,
-  };
-
-  $new;
-}
-
-
-sub alt_names
-{
-  my($class) = @_;
-  my $alts = $class->runtime_prop->{alt};
-  defined $alts
-    ? sort keys %$alts
-    : ();
-}
-
-
-sub alt_exists
-{
-  my($class, $alt_name) = @_;
-  my $alts = $class->runtime_prop->{alt};
-  defined $alts
-    ? exists $alts->{$alt_name} && defined $alts->{$alt_name}
-    : 0;
-}
-
 1;
 
 =pod
@@ -610,17 +432,17 @@ Alien::Base - Base classes for Alien:: modules
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  package Alien::MyLibrary;
- 
+
  use strict;
  use warnings;
- 
+
  use parent 'Alien::Base';
- 
+
  1;
 
 (for details on the C<Makefile.PL> or C<Build.PL> and L<alienfile>
@@ -754,7 +576,7 @@ unnecessary.
 =head2 cflags
 
  my $cflags = Alien::MyLibrary->cflags;
- 
+
  use Text::ParseWords qw( shellwords );
  my @cflags = shellwords( Alien::MyLibrary->cflags );
 
@@ -774,7 +596,7 @@ if they are different.
 =head2 libs
 
  my $libs = Alien::MyLibrary->libs;
- 
+
  use Text::ParseWords qw( shellwords );
  my @cflags = shellwords( Alien::MyLibrary->libs );
 
@@ -798,40 +620,12 @@ if they are different.
 Returns the version of the alienized library or tool that was
 determined at install time.
 
-=head2 atleast_version
-
-=head2 exact_version
-
-=head2 max_version
-
- my $ok = Alien::MyLibrary->atleast_version($wanted_version);
- my $ok = Alien::MyLibrary->exact_version($wanted_version);
- my $ok = Alien::MyLibrary->max_version($wanted_version);
-
-Returns true if the version of the alienized library or tool is at least,
-exactly, or at most the version specified, respectively.
-
-=head2 version_cmp
-
-  $cmp = Alien::MyLibrary->version_cmp($x, $y)
-
-Comparison method used by L<atleast_version>, L<exact_version> and
-L<max_version>. May be useful to implement custom comparisons, or for
-subclasses to overload to get different version comparison semantics than the
-default rules, for packages that have some other rules than the F<pkg-config>
-behaviour.
-
-Should return a number less than, equal to, or greater than zero; similar in
-behaviour to the C<< <=> >> and C<cmp> operators.
-
 =head2 install_type
 
  my $install_type = Alien::MyLibrary->install_type;
- my $bool = Alien::MyLibrary->install_type($install_type);
 
 Returns the install type that was used when C<Alien::MyLibrary> was
-installed.  If a type is provided (the second form in the synopsis)
-returns true if the actual install type matches.  Types include:
+installed.  Types include:
 
 =over 4
 
@@ -852,7 +646,7 @@ or bundled with C<Alien::MyLibrary>.
  my $value = Alien::MyLibrary->config($key);
 
 Returns the configuration data as determined during the install
-of L<Alien::MyLibrary>.  For the appropriate config keys, see
+of L<Alien::MyLibrary>.  For the appropriate config keys, see 
 L<Alien::Base::ModuleBuild::API#CONFIG-DATA>.
 
 This is not typically used by L<Alien::Base> and L<alienfile>,
@@ -896,12 +690,12 @@ to override the method to create your own helpers.
 For use with commands specified in and L<alienfile> or in your C<Build.Pl>
 when used with L<Alien::Base::ModuleBuild>.
 
-Helpers allow users of your Alien module to use platform or environment
+Helpers allow users of your Alien module to use platform or environment 
 determined logic to compute command names or arguments in your installer
 logic.  Helpers allow you to do this without making your Alien module a
 requirement when a build from source code is not necessary.
 
-As a concrete example, consider L<Alien::gmake>, which provides the
+As a concrete example, consider L<Alien::gmake>, which provides the 
 helper C<gmake>:
 
  package Alien::gmake;
@@ -920,8 +714,8 @@ helper C<gmake>:
    },
  }
 
-Now consider L<Alien::nasm>.  C<nasm> requires GNU Make to build from
-source code, but if the system C<nasm> package is installed we don't
+Now consider L<Alien::nasm>.  C<nasm> requires GNU Make to build from 
+source code, but if the system C<nasm> package is installed we don't 
 need it.  From the L<alienfile> of C<Alien::nasm>:
 
  use alienfile;
@@ -935,8 +729,8 @@ need it.  From the L<alienfile> of C<Alien::nasm>:
  share {
    ...
    plugin 'Extract' => 'tar.gz';
-   plugin 'Build::MSYS';
- 
+   plugin 'Build::MSYS' => ();
+   
    build [
      'sh configure --prefix=%{alien.install.prefix}',
      '%{gmake}',
@@ -953,7 +747,7 @@ need it.  From the L<alienfile> of C<Alien::nasm>:
 List of header files to automatically include in inline C and C++
 code when using L<Inline::C> or L<Inline::CPP>.  This is provided
 as a public interface primarily so that it can be overridden at run
-time.  This can also be specified in your C<Build.PL> with
+time.  This can also be specified in your C<Build.PL> with 
 L<Alien::Base::ModuleBuild> using the C<alien_inline_auto_include>
 property.
 
@@ -965,64 +759,13 @@ Returns a hash reference of the runtime properties computed by L<Alien::Build> d
 install process.  If the L<Alien::Base> based L<Alien> was not built using L<Alien::Build>,
 then this will return undef.
 
-=head2 alt
-
- my $new_alien = Alien::MyLibrary->alt($alt_name);
- my $new_alien = $old_alien->alt($alt_name);
-
-Returns an L<Alien::Base> instance with the alternate configuration.
-
-Some packages come with multiple libraries, and multiple C<.pc> files to
-use with them.  This method can be used with C<pkg-config> plugins to
-access different configurations.  (It could also be used with non-pkg-config
-based packages too, though there are not as of this writing any build
-time plugins that take advantage of this feature).
-
-From your L<alienfile>
-
- use alienfile;
- 
- plugin 'PkgConfig' => (
-   pkg_name => [ 'libfoo', 'libbar', ],
- );
-
-Then in your base class:
-
- package Alien::MyLibrary;
- 
- use base qw( Alien::Base );
- use Role::Tiny::With qw( with );
- 
- with 'Alien::Role::Alt';
- 
- 1;
-
-Then you can use it:
-
- use Alien::MyLibrary;
- 
- my $cflags = Alien::MyLibrary->alt('foo1')->cflags;
- my $libs   = Alien::MyLibrary->alt('foo1')->libs;
-
-=head2 alt_names
-
- my @alt_names = Alien::MyLibrary->alt_names
-
-Returns the list of all available alternative configuration names.
-
-=head2 alt_exists
-
- my $bool = Alien::MyLibrary->alt_exists($alt_name)
-
-Returns true if the given alternative configuration exists.
-
 =head1 SUPPORT AND CONTRIBUTING
 
 First check the L<Alien::Build::Manual::FAQ> for questions that have already been answered.
 
 IRC: #native on irc.perl.org
 
-L<(click for instant chatroom login)|http://chat.mibbit.com/#native@irc.perl.org>
+L<(click for instant chatroom login)|http://chat.mibbit.com/#native@irc.perl.org> 
 
 If you find a bug, please report it on the projects issue tracker on GitHub:
 
@@ -1042,7 +785,7 @@ in GitHub.
 
 =back
 
-If you have implemented a new feature or fixed a bug, please open a pull
+If you have implemented a new feature or fixed a bug, please open a pull 
 request.
 
 =over 4
@@ -1055,7 +798,7 @@ request.
 
 =over
 
-=item *
+=item * 
 
 L<Alien::Build>
 
@@ -1109,7 +852,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -1123,7 +866,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -1141,27 +884,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
