@@ -2,7 +2,6 @@ package Alien::Build;
 
 use strict;
 use warnings;
-use 5.008001;
 use Path::Tiny ();
 use Carp ();
 use File::chdir;
@@ -10,11 +9,9 @@ use JSON::PP ();
 use Env qw( @PATH );
 use Env qw( @PKG_CONFIG_PATH );
 use Config ();
-use Alien::Build::Log;
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub _path { goto \&Path::Tiny::path }
@@ -35,139 +32,14 @@ sub new
     pkg_config_path => [],
     aclocal_path => [],
   }, $class;
-
+  
   $self->meta->filename(
     $args{filename} || do {
       my(undef, $filename) = caller;
       _path($filename)->absolute->stringify;
     }
   );
-
-  if($args{meta_prop})
-  {
-    $self->meta->prop->{$_} = $args{meta_prop}->{$_} for keys %{ $args{meta_prop} };
-  }
-
-  $self;
-}
-
-
-my $count = 0;
-
-sub load
-{
-  my(undef, $alienfile, @args) = @_;
-
-  my $rcfile = Path::Tiny->new($ENV{ALIEN_BUILD_RC} || '~/.alienbuild/rc.pl')->absolute;
-  if(-r $rcfile)
-  {
-    require Alien::Build::rc;
-    package Alien::Build::rc;
-    require $rcfile;
-  }
-
-  unless(-r $alienfile)
-  {
-    Carp::croak "Unable to read alienfile: $alienfile";
-  }
-
-  my $file = _path $alienfile;
-  my $name = $file->parent->basename;
-  $name =~ s/^alien-//i;
-  $name =~ s/[^a-z]//g;
-  $name = 'x' if $name eq '';
-  $name = ucfirst $name;
-
-  my $class = "Alien::Build::Auto::$name@{[ $count++ ]}";
-
-  { no strict 'refs';
-  @{ "${class}::ISA" } = ('Alien::Build');
-  *{ "${class}::Alienfile::meta" } = sub {
-    $class =~ s{::Alienfile$}{};
-    $class->meta;
-  }};
-
-  my @preload = qw( Core::Setup Core::Download Core::FFI Core::Override Core::CleanInstall );
-  push @preload, @Alien::Build::rc::PRELOAD;
-  push @preload, split /;/, $ENV{ALIEN_BUILD_PRELOAD}
-    if defined $ENV{ALIEN_BUILD_PRELOAD};
-
-  my @postload = qw( Core::Legacy Core::Gather Core::Tail );
-  push @postload, @Alien::Build::rc::POSTLOAD;
-  push @postload, split /;/, $ENV{ALIEN_BUILD_POSTLOAD}
-    if defined $ENV{ALIEN_BUILD_POSTLOAD};
-
-  my $self = $class->new(
-    filename => $file->absolute->stringify,
-    @args,
-  );
-
-  require alienfile;
-
-  foreach my $preload (@preload)
-  {
-    ref $preload eq 'CODE' ? $preload->($self->meta) : $self->meta->apply_plugin($preload);
-  }
-
-  # TODO: do this without a string eval ?
-  ## no critic
-  eval '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
-    package ${class}::Alienfile;
-    do '@{[ $file->absolute->stringify ]}';
-    die \$\@ if \$\@;
-  };
-  die $@ if $@;
-  ## use critic
-
-  foreach my $postload (@postload)
-  {
-    ref $postload eq 'CODE' ? $postload->($self->meta) : $self->meta->apply_plugin($postload);
-  }
-
-  $self->{args} = \@args;
-  unless(defined $self->meta->prop->{arch})
-  {
-    $self->meta->prop->{arch} = 1;
-  }
-
-  unless(defined $self->meta->prop->{network})
-  {
-    $self->meta->prop->{network} = 1;
-    ## https://github.com/Perl5-Alien/Alien-Build/issues/23#issuecomment-341114414
-    #$self->meta->prop->{network} = 0 if $ENV{NO_NETWORK_TESTING};
-    $self->meta->prop->{network} = 0 if (defined $ENV{ALIEN_INSTALL_NETWORK}) && ! $ENV{ALIEN_INSTALL_NETWORK};
-  }
-
-  unless(defined $self->meta->prop->{local_source})
-  {
-    if(! defined $self->meta->prop->{start_url})
-    {
-      $self->meta->prop->{local_source} = 0;
-    }
-    # we assume URL schemes are at least two characters, that
-    # way Windows absolute paths can be used as local start_url
-    elsif($self->meta->prop->{start_url} =~ /^([a-z]{2,}):/i)
-    {
-      my $scheme = $1;
-      $self->meta->prop->{local_source} = $scheme eq 'file';
-    }
-    else
-    {
-      $self->meta->prop->{local_source} = 1;
-    }
-  }
-
-  return $self;
-}
-
-
-sub resume
-{
-  my(undef, $alienfile, $root) = @_;
-  my $h = JSON::PP::decode_json(_path("$root/state.json")->slurp);
-  my $self = Alien::Build->load("$alienfile", @{ $h->{args} });
-  $self->{install_prop} = $h->{install};
-  $self->{runtime_prop} = $h->{runtime};
+  
   $self;
 }
 
@@ -207,20 +79,106 @@ sub _command_prop
       hook    => $self->hook_prop,
       meta    => $self->meta_prop,
     },
-    perl => {
+    perl    => {
       config => \%Config::Config,
     },
-    env => \%ENV,
   };
 }
 
 
+my $count = 0;
+
+sub load
+{
+  my(undef, $alienfile, @args) = @_;
+
+  my $rcfile = Path::Tiny->new($ENV{ALIEN_BUILD_RC} || '~/.alienbuild/rc.pl')->absolute;
+  if(-r $rcfile)
+  {
+    package Alien::Build::rc;
+    sub logx ($)
+    {
+      unshift @_, 'Alien::Build';
+      goto &Alien::Build::log;
+    };
+    sub preload ($)
+    {
+      push @Alien::Build::rc::PRELOAD, $_[0];
+    }
+    sub postload ($)
+    {
+      push @Alien::Build::rc::POSTLOAD, $_[0];
+    }
+    require $rcfile;
+  }
+
+  unless(-r $alienfile)
+  {
+    Carp::croak "Unable to read alienfile: $alienfile";
+  }
+
+  my $file = _path $alienfile;
+  my $name = $file->parent->basename;
+  $name =~ s/^alien-//i;
+  $name =~ s/[^a-z]//g;
+  $name = 'x' if $name eq '';
+  $name = ucfirst $name;
+
+  my $class = "Alien::Build::Auto::$name@{[ $count++ ]}";
+
+  { no strict 'refs';  
+  @{ "${class}::ISA" } = ('Alien::Build');
+  *{ "${class}::Alienfile::meta" } = sub {
+    $class =~ s{::Alienfile$}{};
+    $class->meta;
+  }};
+
+  my @preload = qw( Core::Setup Core::Download Core::FFI );
+  push @preload, @Alien::Build::rc::PRELOAD;
+  push @preload, split ';', $ENV{ALIEN_BUILD_PRELOAD}
+    if defined $ENV{ALIEN_BUILD_PRELOAD};
+  
+  my @postload = qw( Core::Legacy Core::Gather );
+  push @postload, @Alien::Build::rc::POSTLOAD;
+  push @postload, split ';', $ENV{ALIEN_BUILD_POSTLOAD}
+    if defined $ENV{ALIEN_BUILD_POSTLOAD};
+
+  my $self = $class->new(
+    filename => $file->absolute->stringify,
+    @args,
+  );
+  
+  require alienfile;
+
+  eval '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
+    package ${class}::Alienfile;
+    foreach my \$preload (\@preload) {
+      ref \$preload eq 'CODE' ? \$preload->(meta()) : alienfile::plugin(\$preload);
+    }
+    do '@{[ $file->absolute->stringify ]}';
+    die \$\@ if \$\@;
+    foreach my \$postload (\@postload) {
+      ref \$postload eq 'CODE' ? \$postload->(meta()) : alienfile::plugin(\$postload);
+    }
+  };
+  die $@ if $@;
+  
+  $self->{args} = \@args;
+  unless(defined $self->meta->prop->{arch})
+  {
+    $self->meta->prop->{arch} = 1;
+  }
+
+  return $self;
+}
+
+
 sub checkpoint
 {
   my($self) = @_;
   my $root = $self->root;
   _path("$root/state.json")->spew(
-    JSON::PP->new->pretty->canonical(1)->ascii->encode({
+    JSON::PP->new->pretty->encode({
       install => $self->install_prop,
       runtime => $self->runtime_prop,
       args    => $self->{args},
@@ -230,6 +188,17 @@ sub checkpoint
 }
 
 
+sub resume
+{
+  my(undef, $alienfile, $root) = @_;
+  my $h = JSON::PP::decode_json(_path("$root/state.json")->slurp);
+  my $self = Alien::Build->load("$alienfile", @{ $h->{args} });
+  $self->{install_prop} = $h->{install};
+  $self->{runtime_prop} = $h->{runtime};
+  $self;
+}
+
+
 sub root
 {
   my($self) = @_;
@@ -249,10 +218,10 @@ sub install_type
 sub set_prefix
 {
   my($self, $prefix) = @_;
-
+  
   if($self->meta_prop->{destdir})
   {
-    $self->runtime_prop->{prefix} =
+    $self->runtime_prop->{prefix} = 
     $self->install_prop->{prefix} = $prefix;
   }
   else
@@ -296,29 +265,14 @@ sub requires
 
 sub load_requires
 {
-  my($self, $phase, $eval) = @_;
+  my($self, $phase) = @_;
   my $reqs = $self->requires($phase);
   foreach my $mod (keys %$reqs)
   {
     my $ver = $reqs->{$mod};
-    my $check = sub {
-      my $pm = "$mod.pm";
-      $pm =~ s{::}{/}g;
-      require $pm;
-    };
-    if($eval)
-    {
-      eval { $check->() };
-      die "Required $mod @{[ $ver || 'undef' ]}, missing" if $@;
-    }
-    else
-    {
-      $check->();
-    }
-    # note Test::Alien::Build#alienfile_skip_if_missing_prereqs does a regex
-    # on this diagnostic, so if you change it here, change it there too.
-    die "Required $mod $ver, have @{[ $mod->VERSION || 0 ]}" if $ver && ! $mod->VERSION($ver);
-
+    eval qq{ use $mod @{[ $ver ? $ver : '' ]} () };
+    die if $@;
+    
     # allow for requires on Alien::Build or Alien::Base
     next if $mod eq 'Alien::Build';
     next if $mod eq 'Alien::Base';
@@ -331,14 +285,12 @@ sub load_requires
     if(($mod->can('runtime_prop') && $mod->runtime_prop)
     || ($mod->isa('Alien::Base')  && $mod->install_type('share')))
     {
-      for my $dir (qw(lib share)) {
-          my $path = _path($mod->dist_dir)->child("$dir/pkgconfig");
-          if(-d $path)
-          {
-            push @{ $self->{pkg_config_path} }, $path->stringify;
-          }
+      my $path = _path($mod->dist_dir)->child('lib/pkgconfig');
+      if(-d $path)
+      {
+        push @{ $self->{pkg_config_path} }, $path->stringify;
       }
-      my $path = _path($mod->dist_dir)->child('share/aclocal');
+      $path = _path($mod->dist_dir)->child('share/aclocal');
       if(-d $path)
       {
         $path = "$path";
@@ -350,14 +302,14 @@ sub load_requires
         push @{ $self->{aclocal_path} }, $path;
       }
     }
-
+    
     # sufficiently new Autotools have a aclocal_dir which will
     # give us the directories we need.
     if($mod eq 'Alien::Autotools' && $mod->can('aclocal_dir'))
     {
       push @{ $self->{aclocal_path} }, $mod->aclocal_dir;
     }
-
+    
     if($mod->can('alien_helper'))
     {
       my $helpers = $mod->alien_helper;
@@ -375,27 +327,29 @@ sub load_requires
 sub _call_hook
 {
   my $self = shift;
-
+  
   local $ENV{PATH} = $ENV{PATH};
   unshift @PATH, @{ $self->{bin_dir} };
-
+  
   local $ENV{PKG_CONFIG_PATH} = $ENV{PKG_CONFIG_PATH};
   unshift @PKG_CONFIG_PATH, @{ $self->{pkg_config_path} };
-
+  
   local $ENV{ACLOCAL_PATH} = $ENV{ACLOCAL_PATH};
   # autoconf uses MSYS paths, even for the ACLOCAL_PATH environment variable, so we can't use Env for this.
   {
     my @path;
-    @path = split /:/, $ENV{ACLOCAL_PATH} if defined $ENV{ACLOCAL_PATH};
+    @path = split ':', $ENV{ACLOCAL_PATH} if defined $ENV{ACLOCAL_PATH};
     unshift @path, @{ $self->{aclocal_path} };
     $ENV{ACLOCAL_PATH} = join ':', @path;
   }
-
+  
   my $config = ref($_[0]) eq 'HASH' ? shift : {};
   my($name, @args) = @_;
-
-  local $self->{hook_prop} = {};
-
+  
+  local $self->{hook_prop} = {
+    name => $name,
+  };
+  
   $self->meta->call_hook( $config, $name => $self, @args );
 }
 
@@ -405,13 +359,11 @@ sub probe
   my($self) = @_;
   local $CWD = $self->root;
   my $dir;
-
-  my $env = $self->_call_hook('override');
+  
+  my $env = $ENV{ALIEN_INSTALL_TYPE} || '';
   my $type;
   my $error;
-
-  $env = '' if $env eq 'default';
-
+  
   if($env eq 'share')
   {
     $type = 'share';
@@ -437,7 +389,7 @@ sub probe
     $error = $@;
     $type = 'share' unless defined $type;
   }
-
+  
   if($error)
   {
     if($env eq 'system')
@@ -449,26 +401,19 @@ sub probe
     $self->log("Do not file a bug unless you expected a system install to succeed.");
     $type = 'share';
   }
-
+  
   if($env && $env ne $type)
   {
     die "requested $env install not available";
   }
-
+  
   if($type !~ /^(system|share)$/)
   {
     Carp::croak "probe hook returned something other than system or share: $type";
   }
-
-  if($type eq 'share' && (!$self->meta_prop->{network}) && (!$self->meta_prop->{local_source}))
-  {
-    $self->log("install type share requested or detected, but network fetch is turned off");
-    $self->log("see https://metacpan.org/pod/Alien::Build::Manual::FAQ#Network-fetch-is-turned-off");
-    Carp::croak "network fetch is turned off";
-  }
-
+  
   $self->runtime_prop->{install_type} = $type;
-
+  
   $type;
 }
 
@@ -476,16 +421,16 @@ sub probe
 sub download
 {
   my($self) = @_;
-
+  
   return $self unless $self->install_type eq 'share';
   return $self if $self->install_prop->{complete}->{download};
-
+  
   if($self->meta->has_hook('download'))
   {
     my $tmp;
     local $CWD;
     my $valid = 0;
-
+    
     $self->_call_hook(
       {
         before => sub {
@@ -494,9 +439,9 @@ sub download
         },
         verify => sub {
           my @list = grep { $_->basename !~ /^\./, } _path('.')->children;
-
+    
           my $count = scalar @list;
-
+    
           if($count == 0)
           {
             die "no files downloaded";
@@ -518,11 +463,11 @@ sub download
           }
           else
           {
-            $self->log("multiple files, assuming directory");
+            $self->log("multiple files, assuming directoryn");
             $self->install_prop->{complete}->{download} = 1;
             $self->install_prop->{download} = _path('.')->absolute->stringify;
             $valid = 1;
-          }
+          }   
         },
         after  => sub {
           $CWD = $self->root;
@@ -530,7 +475,7 @@ sub download
       },
       'download',
     );
-
+    
     return $self if $valid;
   }
   else
@@ -538,9 +483,9 @@ sub download
     # This will call the default download hook
     # defined in Core::Download since the recipe
     # does not provide a download hook
-    return $self->_call_hook('download');
+    return $self->_call_hook('download');  
   }
-
+  
   die "download failed";
 }
 
@@ -569,48 +514,32 @@ sub prefer
 sub extract
 {
   my($self, $archive) = @_;
-
+  
   $archive ||= $self->install_prop->{download};
-
+  
   unless(defined $archive)
   {
     die "tried to call extract before download";
   }
-
-  my $nick_name = 'build';
-
-  if($self->meta_prop->{out_of_source})
-  {
-    $nick_name = 'extract';
-    my $extract = $self->install_prop->{extract};
-    return $extract if defined $extract && -d $extract;
-  }
-
+  
   my $tmp;
   local $CWD;
   my $ret;
 
   $self->_call_hook({
-
+  
     before => sub {
-      # called build instead of extract, because this
+      # called build instead of extract, because this 
       # will be used for the build step, and technically
       # extract is a substage of build anyway.
-      $tmp = Alien::Build::TempDir->new($self, $nick_name);
+      $tmp = Alien::Build::TempDir->new($self, "build");
       $CWD = "$tmp";
     },
     verify => sub {
-
-      my $path = '.';
-      if($self->meta_prop->{out_of_source} && $self->install_prop->{extract})
-      {
-        $path = $self->install_prop->{extract};
-      }
-
-      my @list = grep { $_->basename !~ /^\./ && $_->basename ne 'pax_global_header' } _path($path)->children;
-
+      my @list = grep { $_->basename !~ /^\./ && $_->basename ne 'pax_global_header' } _path('.')->children;
+      
       my $count = scalar @list;
-
+      
       if($count == 0)
       {
         die "no files extracted";
@@ -623,15 +552,14 @@ sub extract
       {
         $ret = "$tmp";
       }
-
+    
     },
     after => sub {
       $CWD = $self->root;
     },
-
+  
   }, 'extract', $archive);
-
-  $self->install_prop->{extract} ||= $ret;
+  
   $ret ? $ret : ();
 }
 
@@ -643,12 +571,10 @@ sub build
   # save the evironment, in case some plugins decide
   # to alter it.  Or us!  See just a few lines below.
   local %ENV = %ENV;
-
+  
   my $stage = _path($self->install_prop->{stage});
   $stage->mkpath;
-
-  my $tmp;
-
+  
   if($self->install_type eq 'share')
   {
     foreach my $suffix ('', '_ffi')
@@ -656,34 +582,15 @@ sub build
       local $CWD;
       delete $ENV{DESTDIR} unless $self->meta_prop->{destdir};
 
-      my %env_meta = %{ $self->meta_prop   ->{env} || {} };
-      my %env_inst = %{ $self->install_prop->{env} || {} };
-
-      if($self->meta_prop->{env_interpolate})
-      {
-        foreach my $key (keys %env_meta)
-        {
-          $env_meta{$key} = $self->meta->interpolator->interpolate($env_meta{$key});
-        }
-      }
-
-      %ENV = (%ENV, %env_meta);
-      %ENV = (%ENV, %env_inst);
+      %ENV = (%ENV, %{ $self->meta_prop->{env} || {} });
+      %ENV = (%ENV, %{ $self->install_prop->{env} || {} });
 
       my $destdir;
 
       $self->_call_hook(
       {
         before => sub {
-          if($self->meta_prop->{out_of_source})
-          {
-            $self->extract;
-            $CWD = $tmp = Alien::Build::TempDir->new($self, 'build');
-          }
-          else
-          {
-            $CWD = $tmp = $self->extract;
-          }
+          $CWD = $self->extract;
           if($self->meta_prop->{destdir})
           {
             $destdir = Alien::Build::TempDir->new($self, 'destdir');
@@ -696,17 +603,15 @@ sub build
         },
       }, "build${suffix}");
 
-      $self->install_prop->{"_ab_build@{[ $suffix || '_share' ]}"} = "$CWD";
-
       $self->_call_hook("gather@{[ $suffix || '_share' ]}");
     }
   }
-
+  
   elsif($self->install_type eq 'system')
   {
     local $CWD = $self->root;
     my $dir;
-
+  
     $self->_call_hook(
       {
         before => sub {
@@ -719,67 +624,27 @@ sub build
       },
       'gather_system',
     );
-
+  
     $self->install_prop->{finished} = 1;
-    $self->install_prop->{complete}->{gather_system} = 1;
+    $self->install_prop->{complete}->{gather_system} = 1;  
   }
-
+  
   $self;
 }
 
 
-sub test
-{
-  my($self) = @_;
-
-  if($self->install_type eq 'share')
-  {
-    foreach my $suffix ('_share', '_ffi')
-    {
-      if($self->meta->has_hook("test$suffix"))
-      {
-        my $dir = $self->install_prop->{"_ab_build$suffix"};
-        Carp::croak("no build directory to run tests") unless $dir && -d $dir;
-        local $CWD = $dir;
-        $self->_call_hook("test$suffix");
-      }
-    }
-  }
-  else
-  {
-    if($self->meta->has_hook("test_system"))
-    {
-      my $dir = Alien::Build::TempDir->new($self, "test");
-      local $CWD = "$dir";
-      $self->_call_hook("test_system");
-    }
-  }
-
-}
-
-
-sub clean_install
-{
-  my($self) = @_;
-  if($self->install_type eq 'share')
-  {
-    $self->_call_hook("clean_install");
-  }
-}
-
-
 sub system
 {
   my($self, $command, @args) = @_;
-
+  
   my $prop = $self->_command_prop;
-
-  ($command, @args) = map {
+  
+  ($command, @args) = map { 
     $self->meta->interpolator->interpolate($_, $prop)
   } ($command, @args);
 
   $self->log("+ $command @args");
-
+  
   scalar @args
     ? system $command, @args
     : system $command;
@@ -789,15 +654,9 @@ sub system
 sub log
 {
   my(undef, $message) = @_;
-  my $caller = [caller];
+  my $caller = caller;
   chomp $message;
-  foreach my $line (split /\n/, $message)
-  {
-    Alien::Build::Log->default->log(
-      caller  => $caller,
-      message => $line,
-    );
-  }
+  print "$caller> $message\n";
 }
 
 
@@ -914,16 +773,10 @@ sub _instr
       prefer        => 'share',
       extract       => 'share',
       patch         => 'share',
-      patch_ffi     => 'share',
       build         => 'share',
-      build_ffi     => 'share',
       stage         => 'share',
-      gather_ffi    => 'share',
       gather_share  => 'share',
       gather_system => 'system',
-      test_ffi      => 'share',
-      test_share    => 'share',
-      test_system   => 'system',
     );
     require Alien::Build::CommandSequence;
     my $seq = Alien::Build::CommandSequence->new(@$instr);
@@ -1003,9 +856,9 @@ sub call_hook
   my %args = ref $_[0] ? %{ shift() } : ();
   my($name, @args) = @_;
   my $error;
-
+  
   my @hooks = @{ $self->{hook}->{$name} || []};
-
+  
   if(@hooks == 0)
   {
     if(defined $self->{default_hook}->{$name})
@@ -1017,18 +870,11 @@ sub call_hook
       Carp::croak "No hooks registered for $name";
     }
   }
-
+  
   my $value;
 
   foreach my $hook (@hooks)
   {
-    if(eval { $args[0]->isa('Alien::Build') })
-    {
-      %{ $args[0]->{hook_prop} } = (
-        name => $name,
-      );
-    }
-
     my $wrapper = $self->{around}->{$name} || sub { my $code = shift; $code->(@_) };
     my $value;
     $args{before}->() if $args{before};
@@ -1063,69 +909,16 @@ sub call_hook
       return $value;
     }
   }
-
+  
   die $error if $error && ! $args{all};
-
+  
   $value;
 }
 
-
-sub apply_plugin
-{
-  my($self, $name, @args) = @_;
-
-  my $class;
-  my $pm;
-  my $found;
-
-  if($name =~ /^=(.*)$/)
-  {
-    $class = $1;
-    $pm    = "$class.pm";
-    $pm    =~ s!::!/!g;
-    $found = 1;
-  }
-
-  if($name !~ /::/ && !$found)
-  {
-    foreach my $inc (@INC)
-    {
-      # TODO: allow negotiators to work with @INC hooks
-      next if ref $inc;
-      my $file = Path::Tiny->new("$inc/Alien/Build/Plugin/$name/Negotiate.pm");
-      if(-r $file)
-      {
-        $class = "Alien::Build::Plugin::${name}::Negotiate";
-        $pm    = "Alien/Build/Plugin/$name/Negotiate.pm";
-        $found = 1;
-        last;
-      }
-    }
-  }
-
-  unless($found)
-  {
-    $class = "Alien::Build::Plugin::$name";
-    $pm    = "Alien/Build/Plugin/$name.pm";
-    $pm    =~ s{::}{/}g;
-  }
-
-  require $pm unless $class->can('new');
-  my $plugin = $class->new(@args);
-  $plugin->init($self);
-  $self;
-}
-
 package Alien::Build::TempDir;
 
-# TODO: it's confusing that there is both a AB::TempDir and AB::Temp
-# although they do different things.  there could maybe be a better
-# name for AB::TempDir (maybe AB::TempBuildDir, though that is a little
-# redundant).  Happily both are private classes, and either are able to
-# rename, if a good name can be thought of.
-
 use Path::Tiny qw( path );
-use overload '""' => sub { shift->as_string }, bool => sub { 1 }, fallback => 1;
+use overload '""' => sub { shift->as_string };
 use File::Temp qw( tempdir );
 
 sub new
@@ -1166,7 +959,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -1183,19 +976,16 @@ version 1.99_01
 
 =head1 DESCRIPTION
 
-This module provides tools for building external (non-CPAN) dependencies
-for CPAN.  It is mainly designed to be used at install time of a CPAN
+This module provides tools for building external (non-CPAN) dependencies 
+for CPAN.  It is mainly designed to be used at install time of a CPAN 
 client, and work closely with L<Alien::Base> which is used at runtime.
 
 This is the detailed documentation for the L<Alien::Build> class.
-If you are starting out you probably want to do so from one of these documents:
+If you
+are starting out you probably want to do so from one of these documents:
 
 =over 4
 
-=item L<Alien::Build::Manual::Alien>
-
-A broad overview of C<Alien-Build> and its ecosystem.
-
 =item L<Alien::Build::Manual::AlienUser>
 
 For users of an C<Alien::libfoo> that is implemented using L<Alien::Base>.
@@ -1218,13 +1008,12 @@ L<Alien::Build> + L<alienfile>.
 
 =back
 
-Note that you will not usually create a L<Alien::Build> instance
+Note that you will usually not usually create a L<Alien::Build> instance
 directly, but rather be using a thin installer layer, such as
-L<Alien::Build::MM> (for use with L<ExtUtils::MakeMaker>) or
-L<Alien::Build::MB> (for use with L<Module::Build>).  One of the
+L<Alien::Build::MM> (for use with L<ExtUtils::MakeMaker>).  One of the
 goals of this project is to remain installer agnostic.
 
-=head1 CONSTRUCTORS
+=head1 CONSTRUCTOR
 
 =head2 new
 
@@ -1234,21 +1023,6 @@ This creates a new empty instance of L<Alien::Build>.  Normally you will
 want to use C<load> below to create an instance of L<Alien::Build> from
 an L<alienfile> recipe.
 
-=head2 load
-
- my $build = Alien::Build->load($alienfile);
-
-This creates an L<Alien::Build> instance with the given L<alienfile>
-recipe.
-
-=head2 resume
-
- my $build = Alien::Build->resume($alienfile, $root);
-
-Load a checkpointed L<Alien::Build> instance.  You will need the original
-L<alienfile> and the build root (usually C<_alien>), and a build that
-had been properly checkpointed using the C<checkpoint> method below.
-
 =head1 PROPERTIES
 
 There are three main properties for L<Alien::Build>.  There are a number
@@ -1257,8 +1031,8 @@ properties may need to be serialized into something primitive like JSON
 that does not support: regular expressions, code references of blessed
 objects.
 
-If you are writing a plugin (L<Alien::Build::Plugin>) you should use a
-prefix like "plugin_I<name>" (where I<name> is the name of your plugin)
+If you are writing a plugin (L<Alien::Build::Plugin>) you should use a 
+prefix like "plugin_I<name>" (where I<name> is the name of your plugin) 
 so that it does not interfere with other plugin or future versions of
 L<Alien::Build>.  For example, if you were writing
 C<Alien::Build::Plugin::Fetch::NewProtocol>, please use the prefix
@@ -1267,9 +1041,9 @@ C<plugin_fetch_newprotocol>:
  sub init
  {
    my($self, $meta) = @_;
- 
+   
    $meta->prop( plugin_fetch_newprotocol_foo => 'some value' );
- 
+   
    $meta->register_hook(
      some_hook => sub {
        my($build) = @_;
@@ -1341,19 +1115,6 @@ Same as C<destdir_filter> except applies to C<build_ffi> instead of C<build>.
 
 Environment variables to override during the build stage.
 
-=item env_interpolate
-
-Environment variable values will be interpolated with helpers.  Example:
-
- meta->prop->{env_interpolate} = 1;
- meta->prop->{env}->{PERL} = '%{perl}';
-
-=item local_source
-
-Set to true if source code package is available locally.  (that is not fetched
-over the internet).  This is computed by default based on the C<start_url>
-property.  Can be set by an L<alienfile> or plugin.
-
 =item platform
 
 Hash reference.  Contains information about the platform beyond just C<$^O>.
@@ -1410,21 +1171,6 @@ on windows!
 
 =back
 
-=item out_of_source
-
-Build in a different directory from the where the source code is stored.
-In autoconf this is referred to as a "VPATH" build.  Everyone else calls this
-an "out-of-source" build.  When this property is true, instead of extracting
-to the source build root, the downloaded source will be extracted to an source
-extraction directory and the source build root will be empty.  You can use the
-C<extract> install property to get the location of the extracted source.
-
-=item network
-
-True if a network fetch is available.  This should NOT be set by an L<alienfile>
-or plugin.  This is computed based on the C<ALIEN_INSTALL_NETWORK> environment
-variables.
-
 =item start_url
 
 The default or start URL used by fetch plugins.
@@ -1451,21 +1197,10 @@ which are understood by the MSYS tools, but not by Perl.  You should
 only use this if you are using L<Alien::Build::Plugin::Autoconf> in
 your L<alienfile>.
 
-=item download
-
-The location of the downloaded archive (tar.gz, or similar) or directory.
-
 =item env
 
 Environment variables to override during the build stage.
 
-=item extract
-
-The location of the last source extraction.  For a "out-of-source" build
-(see the C<out_of_source> meta property above), this will only be set once.
-For other types of builds, the source code may be extracted multiple times,
-and thus this property may change.
-
 =item old
 
 Hash containing information on a previously installed Alien of the same
@@ -1476,8 +1211,7 @@ reuse the previous install if it is still sufficient.
 
 =item prefix
 
-The prefix for the previous install.  Versions prior to 1.42 unfortunately
-had this in typo form of C<preifx>.
+The prefix for the previous install.
 
 =item runtime
 
@@ -1544,39 +1278,6 @@ The command name for tools where the name my differ from platform to
 platform.  For example, the GNU version of make is usually C<make> in
 Linux and C<gmake> on FreeBSD.
 
-=item ffi_name
-
-The name DLL or shared object "name" to use when searching for dynamic
-libraries at runtime.  This is passed into L<FFI::CheckLib>, so if
-your library is something like C<libarchive.so> or C<archive.dll> you
-would set this to C<archive>.  This may be a string or an array of
-strings.
-
-=item ffi_checklib
-
-This property contains two sub properties:
-
-=over 4
-
-=item share
-
- $build->runtime_prop->{ffi_checklib}->{share} = [ ... ];
-
-Array of additional L<FFI::CheckLib> flags to pass in to C<find_lib>
-for a C<share> install.
-
-=item system
-
-Array of additional L<FFI::CheckLib> flags to pass in to C<find_lib>
-for a C<system> install.
-
-Among other things, useful for specifying the C<try_linker_script>
-flag:
-
- $build->runtime_prop->{ffi_checklib}->{system} = [ try_linker_script => 1 ];
-
-=back
-
 =item install_type
 
 The install type.  Is one of:
@@ -1635,26 +1336,31 @@ If no hook is currently running then C<hook_prop> will return C<undef>.
 
 The name of the currently running hook.
 
-=item version (probe)
-
-Probe and PkgConfig plugins I<may> set this property indicating the
-version of the alienized package.  Not all plugins and configurations
-may be able to provide this.
-
 =back
 
 =head1 METHODS
 
+=head2 load
+
+ my $build = Alien::Build->load($alienfile);
+
+This creates an L<Alien::Build> instance with the given L<alienfile>
+recipe.
+
 =head2 checkpoint
 
  $build->checkpoint;
 
 Save any install or runtime properties so that they can be reloaded on
-a subsequent run in a separate process.  This is useful if your build
-needs to be done in multiple stages from a C<Makefile>, such as with
-L<ExtUtils::MakeMaker>.  Once checkpointed you can use the C<resume>
-constructor (documented above) to resume the probe/build/install]
-process.
+a subsequent run.  This is useful if your build needs to be done in
+multiple stages from a C<Makefile>, such as with L<ExtUtils::MakeMaker>.
+
+=head2 resume
+
+ my $build = Alien::Build->resume($alienfile, $root);
+
+Load a checkpointed L<Alien::Build> instance.  You will need the original
+L<alienfile> and the build root (usually C<_alien>).
 
 =head2 root
 
@@ -1664,7 +1370,7 @@ This is just a shortcut for:
 
  my $root = $build->install_prop->{root};
 
-Except that it will be created if it does not already exist.
+Except that it will be created if it does not already exist.  
 
 =head2 install_type
 
@@ -1797,22 +1503,6 @@ The C<gather_system> hook will be executed.
 
 =back
 
-=head2 test
-
- $build->test;
-
-Run the test phase
-
-=head2 clean_install
-
- $build->clean_install
-
-Clean files from the final install location.  The default implementation removes all
-files recursively except for the C<_alien> directory.  This is helpful when you have
-an old install with files that may break the new build.
-
-For a non-share install this doesn't do anything.
-
 =head2 system
 
  $build->system($command);
@@ -1920,51 +1610,15 @@ a method.  For example, this will add a probe system requirement:
    },
  );
 
-=head2 apply_plugin
-
- Alien::Build->meta->apply_plugin($name);
- Alien::Build->meta->apply_plugin($name, @args);
-
-Apply the given plugin with the given arguments.
-
 =head1 ENVIRONMENT
 
 L<Alien::Build> responds to these environment variables:
 
 =over 4
 
-=item ALIEN_INSTALL_NETWORK
-
-If set to true (the default), then network fetch will be allowed.  If set to
-false, then network fetch will not be allowed.
-
-What constitutes a local vs. network fetch is determined based on the C<start_url>
-and C<local_source> meta properties.  An L<alienfile> or plugin C<could> override
-this detection (possibly inappropriately), so this variable is not a substitute
-for properly auditing of Perl modules for environments that require that.
-
 =item ALIEN_INSTALL_TYPE
 
 If set to C<share> or C<system>, it will override the system detection logic.
-If set to C<default>, it will use the default setting for the L<alienfile>.
-The behavior of other values is undefined.
-
-Although the recommended way for a consumer to use an L<Alien::Base> based L<Alien>
-is to declare it as a static configure and build-time dependency, some consumers
-may prefer to fallback on using an L<Alien> only when the consumer itself cannot
-detect the necessary package. In some cases the consumer may want the user to opt-in
-to using an L<Alien> before requiring it.
-
-To keep the interface consistent among Aliens, the consumer of the fallback opt-in
-L<Alien> may fallback on the L<Alien> if the environment variable C<ALIEN_INSTALL_TYPE>
-is set to any value. The rationale is that by setting this environment variable the
-user is aware that L<Alien> modules may be installed and have indicated consent.
-The actual implementation of this, by its nature would have to be in the consuming
-CPAN module.
-
-=item ALIEN_BUILD_LOG
-
-The default log class used.  See L<Alien::Build::Log> and L<Alien:Build::Log::Default>.
 
 =item ALIEN_BUILD_RC
 
@@ -1981,7 +1635,7 @@ chooses the best C<pkg-config> plugin.
 semicolon separated list of plugins to automatically load before parsing
 your L<alienfile>.
 
-=item ALIEN_BUILD_POSTLOAD
+=item ALIEN_BUILD_PRELOAD
 
 semicolon separated list of plugins to automatically load after parsing
 your L<alienfile>.
@@ -1993,7 +1647,7 @@ This environment variable will be manipulated during a destdir install.
 =item PKG_CONFIG
 
 This environment variable can be used to override the program name for C<pkg-config>
-when using the command line plugin: L<Alien::Build::Plugin::PkgConfig::CommandLine>.
+for some PkgConfig plugins: L<Alien::Build::Plugin::PkgConfig>.
 
 =item ftp_proxy, all_proxy
 
@@ -2005,11 +1659,11 @@ be used by some Fetch plugins, if they support it.
 
 =head1 SUPPORT
 
-The intent of the C<Alien-Build> team is to support as best as possible
-all Perls from 5.8.1 to the latest production version.  So long as they
+The intent of the C<Alien-Build> team is to support as best as possible 
+all Perls from 5.8.1 to the latest production version.  So long as they 
 are also supported by the Perl toolchain.
 
-Please feel encouraged to report issues that you encounter to the
+Please feel encouraged to report issues that you encounter to the 
 project GitHub Issue tracker:
 
 =over 4
@@ -2018,7 +1672,7 @@ project GitHub Issue tracker:
 
 =back
 
-Better if you can fix the issue yourself, please feel encouraged to open
+Better if you can fix the issue yourself, please feel encouraged to open 
 pull-request on the project GitHub:
 
 =over 4
@@ -2027,8 +1681,8 @@ pull-request on the project GitHub:
 
 =back
 
-If you are confounded and have questions, join us on the C<#native>
-channel on irc.perl.org.  The C<Alien-Build> developers frequent this
+If you are confounded and have questions, join us on the C<#native> 
+channel on irc.perl.org.  The C<Alien-Build> developers frequent this 
 channel and can probably help point you in the right direction.  If you
 don't have an IRC client handy, you can use this web interface:
 
@@ -2048,25 +1702,6 @@ L<Alien::Build::Manual::PluginAuthor>
 
 L<alienfile>, L<Alien::Build::MM>, L<Alien::Build::Plugin>, L<Alien::Base>, L<Alien>
 
-=head1 THANKS
-
-L<Alien::Base> was originally written by Joel Berger, the rest of this project would
-not have been possible without him getting the project started.  Thanks to his support
-I have been able to augment the original L<Alien::Base> system with a reliable set
-of tools (L<Alien::Build>, L<alienfile>, L<Test::Alien>), which make up this toolset.
-
-The original L<Alien::Base> is still copyright (c) 2012-2017 Joel Berger.  It has
-the same license as the rest of the Alien::Build and related tools distributed as
-C<Alien-Build>.  Joel Berger thanked a number of people who helped in in the development
-of L<Alien::Base>, in the documentation for that module.
-
-I would also like to acknowledge the other members of the Perl5-Alien github
-organization, Zakariyya Mughal (sivoais, ZMUGHAL) and mohawk (ETJ).  Also important
-in the early development of L<Alien::Build> were the early adopters Chase Whitener
-(genio, CAPOEIRAB, author of L<Alien::libuv>), William N. Braswell, Jr (willthechill,
-WBRASWELL, author of L<Alien::JPCRE2> and L<Alien::PCRE2>) and Ahmad Fatoum (a3f,
-ATHREEF, author of L<Alien::libudev> and L<Alien::LibUSB>).
-
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
@@ -2075,7 +1710,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -2089,7 +1724,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -2107,27 +1742,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
