@@ -2,12 +2,10 @@ package Alien::Build::CommandSequence;
 
 use strict;
 use warnings;
-use Text::ParseWords qw( shellwords );
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: Alien::Build command sequence
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub new
@@ -43,74 +41,23 @@ sub apply_requirements
   $self;
 }
 
-my %built_in = (
-
-  cd => sub {
-    my(undef, $dir) = @_;
-    if(!defined $dir)
-    {
-      die "undef passed to cd";
-    }
-    elsif(-d $dir)
-    {
-      chdir($dir) || die "unable to cd $dir $!";
-    }
-    else
-    {
-      die "unable to cd $dir, does not exist";
-    }
-  },
-
-);
-
-sub _run_list
+sub _run
 {
   my($build, @cmd) = @_;
   $build->log("+ @cmd");
-  return $built_in{$cmd[0]}->(@cmd) if $built_in{$cmd[0]};
   system @cmd;
   die "external command failed" if $?;
 }
 
-sub _run_string
-{
-  my($build, $cmd) = @_;
-  $build->log("+ $cmd");
-
-  {
-    my $cmd = $cmd;
-    $cmd =~ s{\\}{\\\\}g if $^O eq 'MSWin32';
-    my @cmd = shellwords($cmd);
-    return $built_in{$cmd[0]}->(@cmd) if $built_in{$cmd[0]};
-  }
-
-  system $cmd;
-  die "external command failed" if $?;
-}
-
 sub _run_with_code
 {
   my($build, @cmd) = @_;
   my $code = pop @cmd;
   $build->log("+ @cmd");
   my %args = ( command => \@cmd );
-
-  if($built_in{$cmd[0]})
-  {
-    my $error;
-    ($args{out}, $args{err}, $error) = capture {
-      eval { $built_in{$cmd[0]}->(@cmd) };
-      $@;
-    };
-    $args{exit} = $error eq '' ? 0 : 2;
-    $args{builtin} = 1;
-  }
-  else
-  {
-    ($args{out}, $args{err}, $args{exit}) = capture {
-      system @cmd; $?
-    };
-  }
+  ($args{out}, $args{err}, $args{exit}) = capture {
+    system @cmd; $?
+  };
   $build->log("[output consumed by Alien::Build recipe]");
   $code->($build, \%args);
 }
@@ -135,7 +82,7 @@ sub execute
   my $intr = $build->meta->interpolator;
 
   my $prop = $build->_command_prop;
-
+  
   foreach my $command (@{ $self->{commands} })
   {
     if(ref($command) eq 'CODE')
@@ -145,9 +92,8 @@ sub execute
     elsif(ref($command) eq 'ARRAY')
     {
       my($command, @args) = @$command;
-      my $code;
-      $code = pop @args if $args[-1] && ref($args[-1]) eq 'CODE';
-
+      my $code = pop @args if $args[-1] && ref($args[-1]) eq 'CODE';
+      
       if($args[-1] && ref($args[-1]) eq 'SCALAR')
       {
         my $dest = ${ pop @args };
@@ -168,22 +114,22 @@ sub execute
           die "illegal destination: $dest";
         }
       }
-
+      
       ($command, @args) = map { $intr->interpolate($_, $prop) } ($command, @args);
-
+      
       if($code)
       {
         _run_with_code $build, $command, @args, $code;
       }
       else
       {
-        _run_list $build, $command, @args;
+        _run $build, $command, @args;
       }
     }
     else
     {
       my $command = $intr->interpolate($command,$prop);
-      _run_string $build, $command;
+      _run $build, $command;
     }
   }
 }
@@ -202,7 +148,7 @@ Alien::Build::CommandSequence - Alien::Build command sequence
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 CONSTRUCTOR
 
@@ -228,7 +174,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -242,7 +188,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -260,27 +206,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
