@@ -4,8 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Advanced interpolation engine for Alien builds
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub new
@@ -30,7 +29,7 @@ sub add_helper
     require Carp;
     Carp::croak("duplicate implementation for interpolated key $name");
   }
-
+  
   while(@_)
   {
     my $module = shift;
@@ -38,7 +37,7 @@ sub add_helper
     $version ||= 0;
     $self->{helper}->{$name}->{require}->{$module} = $version;
   }
-
+  
   $self->{helper}->{$name}->{code} = $code;
 }
 
@@ -60,29 +59,27 @@ sub has_helper
   {
     my $version = $self->{helper}->{$name}->{require}->{$module};
 
-    {
-      my $pm = "$module.pm";
-      $pm =~ s/::/\//g;
-      require $pm;
-      $module->VERSION($version) if $version;
-    }
+    # yeah we do have to eval every time in case $version is different
+    # from the last load.
+    eval qq{ use $module @{[ $version ? $version : '' ]} (); 1 };
+    die $@ if $@;
 
     unless($self->{classes}->{$module})
     {
       if($module->can('alien_helper'))
       {
         my $helpers = $module->alien_helper;
-        foreach my $k (keys %$helpers)
+        while(my($k,$v) = each %$helpers)
         {
-          $self->{helper}->{$k}->{code} = $helpers->{$k};
+          $self->{helper}->{$k}->{code} = $v;
         }
       }
       $self->{classes}->{$module} = 1;
     }
   }
-
+  
   my $code = $self->{helper}->{$name}->{code};
-
+  
   return unless defined $code;
 
   if(ref($code) ne 'CODE')
@@ -90,14 +87,12 @@ sub has_helper
     my $perl = $code;
     package Alien::Build::Interpolate::Helper;
     $code = sub {
-      ##  no critic
       my $value = eval $perl;
-      ## use critic
       die $@ if $@;
       $value;
     };
   }
-
+  
   $code;
 }
 
@@ -105,10 +100,10 @@ sub has_helper
 sub execute_helper
 {
   my($self, $name) = @_;
-
+  
   my $code = $self->has_helper($name);
   die "no helper defined for $name" unless defined $code;
-
+  
   $code->();
 }
 
@@ -116,9 +111,9 @@ sub execute_helper
 sub _get_prop
 {
   my($name, $prop, $orig) = @_;
-
+  
   $name =~ s/^\./alien./;
-
+  
   if($name =~ /^(.*?)\.(.*)$/)
   {
     my($key,$rest) = ($1,$2);
@@ -139,7 +134,7 @@ sub interpolate
 {
   my($self, $string, $prop) = @_;
   $prop ||= {};
-
+  
   $string =~ s{(?<!\%)\%\{([a-zA-Z_][a-zA-Z_0-9]+)\}}{$self->execute_helper($1)}eg;
   $string =~ s{(?<!\%)\%\{([a-zA-Z_\.][a-zA-Z_0-9\.]+)\}}{_get_prop($1,$prop,$1)}eg;
   $string =~ s/\%(?=\%)//g;
@@ -160,9 +155,9 @@ sub requires
 sub clone
 {
   my($self) = @_;
-
+  
   require Storable;
-
+  
   my %help;
   foreach my $helper (keys %{ $self->{helper} })
   {
@@ -190,7 +185,7 @@ Alien::Build::Interpolate - Advanced interpolation engine for Alien builds
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 CONSTRUCTOR
 
@@ -239,7 +234,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -253,7 +248,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -271,27 +266,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
