@@ -8,43 +8,22 @@ use Capture::Tiny qw( capture );
 use Carp ();
 
 # ABSTRACT: Alien::Build installer code for ExtUtils::MakeMaker
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub new
 {
-  my($class, %prop) = @_;
-
+  my($class) = @_;
+  
   my $self = bless {}, $class;
-
-  my %meta = map { $_ => $prop{$_} } grep /^my_/, keys %prop;
-
+  
   my $build = $self->{build} =
     Alien::Build->load('alienfile',
       root     => "_alien",
       (-d 'patch' ? (patch => 'patch') : ()),
-      meta_prop => \%meta,
     )
   ;
-
-  if(%meta)
-  {
-    $build->meta->add_requires(configure => 'Alien::Build::MM' => '1.20');
-    $build->meta->add_requires(configure => 'Alien::Build' => '1.20');
-  }
-
-  if(defined $prop{alienfile_meta})
-  {
-    $self->{alienfile_meta} = $prop{alienfile_meta};
-  }
-  else
-  {
-    $self->{alienfile_meta} = 1;
-  }
-
-  $self->{clean_install} = $prop{clean_install};
-
+  
   $self->build->load_requires('configure');
   $self->build->root;
   $self->build->checkpoint;
@@ -59,22 +38,10 @@ sub build
 }
 
 
-sub alienfile_meta
-{
-  shift->{alienfile_meta};
-}
-
-
-sub clean_install
-{
-  shift->{clean_install};
-}
-
-
 sub mm_args
 {
   my($self, %args) = @_;
-
+  
   if($args{DISTNAME})
   {
     $self->build->set_stage(Path::Tiny->new("blib/lib/auto/share/dist/$args{DISTNAME}")->absolute->stringify);
@@ -96,7 +63,7 @@ sub mm_args
         unless($@)
         {
           $self->build->install_prop->{old}->{runtime} = $old_runtime;
-          $self->build->install_prop->{old}->{prefix}  = $old_prefix;
+          $self->build->install_prop->{old}->{preifx}  = $old_prefix;
         }
       }
     }
@@ -105,14 +72,9 @@ sub mm_args
   {
     Carp::croak "DISTNAME is required";
   }
-
+  
   my $ab_version = '0.25';
-
-  if($self->clean_install)
-  {
-    $ab_version = '1.74';
-  }
-
+  
   $args{CONFIGURE_REQUIRES} = Alien::Build::_merge(
     'Alien::Build::MM' => $ab_version,
     %{ $args{CONFIGURE_REQUIRES} || {} },
@@ -139,29 +101,15 @@ sub mm_args
   {
     die "unknown install type: @{[ $self->build->install_type ]}"
   }
-
+  
   $args{PREREQ_PM} = Alien::Build::_merge(
     'Alien::Build' => $ab_version,
     %{ $args{PREREQ_PM} || {} },
   );
-
+ 
   #$args{META_MERGE}->{'meta-spec'}->{version} = 2;
   $args{META_MERGE}->{dynamic_config} = 1;
-
-  if($self->alienfile_meta)
-  {
-    $args{META_MERGE}->{x_alienfile} = {
-      generated_by => "@{[ __PACKAGE__ ]} version @{[ __PACKAGE__->VERSION || 'dev' ]}",
-      requires => {
-        map {
-          my %reqs = %{ $self->build->requires($_) };
-          $reqs{$_} = "$reqs{$_}" for keys %reqs;
-          $_ => \%reqs;
-        } qw( share system )
-      },
-    };
-  }
-
+  
   $self->build->checkpoint;
   %args;
 }
@@ -169,28 +117,16 @@ sub mm_args
 
 sub mm_postamble
 {
-  # NOTE: older versions of the Alien::Build::MM documentation
-  # didn't include $mm and @rest args, so anything that this
-  # method uses them for has to be optional.
-  # (as of this writing they are unused, but are being added
-  #  to match the way mm_install works).
-
-  my($self, $mm, @rest) = @_;
-
+  my($self) = @_;
+  
   my $postamble = '';
-
+  
   # remove the _alien directory on a make realclean:
   $postamble .= "realclean :: alien_realclean\n" .
                 "\n" .
                 "alien_realclean:\n" .
                 "\t\$(RM_RF) _alien\n\n";
 
-  # remove the _alien directory on a make clean:
-  $postamble .= "clean :: alien_clean\n" .
-                "\n" .
-                "alien_clean:\n" .
-                "\t\$(RM_RF) _alien\n\n";
-
   my $dirs = $self->build->meta_prop->{arch}
     ? '$(INSTALLARCHLIB) $(INSTALLSITEARCH) $(INSTALLVENDORARCH)'
     : '$(INSTALLPRIVLIB) $(INSTALLSITELIB) $(INSTALLVENDORLIB)'
@@ -215,14 +151,10 @@ sub mm_postamble
   $postamble .= "alien_build : _alien/mm/build\n\n" .
                 "_alien/mm/build : _alien/mm/download\n" .
                 "\t\$(FULLPERL) -MAlien::Build::MM=cmd -e build\n\n";
-
+  
   # append to all
   $postamble .= "pure_all :: _alien/mm/build\n\n";
-
-  $postamble .= "subdirs-test_dynamic subdirs-test_static subdirs-test :: alien_test\n\n";
-  $postamble .= "alien_test :\n" .
-                "\t\$(FULLPERL) -MAlien::Build::MM=cmd -e test\n\n";
-
+  
   # prop
   $postamble .= "alien_prop :\n" .
                 "\t\$(FULLPERL) -MAlien::Build::MM=cmd -e dumpprop\n\n";
@@ -231,33 +163,11 @@ sub mm_postamble
   $postamble .= "alien_prop_install :\n" .
                 "\t\$(FULLPERL) -MAlien::Build::MM=cmd -e dumpprop install\n\n";
   $postamble .= "alien_prop_runtime :\n" .
-                "\t\$(FULLPERL) -MAlien::Build::MM=cmd -e dumpprop runtime\n\n";
-
-  # install
-  $postamble .= "alien_clean_install : _alien/mm/prefix\n" .
-                "\t\$(FULLPERL) -MAlien::Build::MM=cmd -e clean_install\n\n";
-
+                "\t\$(FULLPERL) -MAlien::Build::MM=cmd -e dumpprop install\n\n";
+  
   $postamble;
 }
 
-
-sub mm_install
-{
-  # NOTE: older versions of the Alien::Build::MM documentation
-  # didn't include this method, so anything that this method
-  # does has to be optional
-
-  my($self, $mm, @rest) = @_;
-
-  my $section = do {
-    package
-      MY;
-    $mm->SUPER::install(@rest);
-  };
-
-  "install :: alien_clean_install\n\n$section";
-}
-
 sub import
 {
   my(undef, @args) = @_;
@@ -266,7 +176,7 @@ sub import
     if($arg eq 'cmd')
     {
       package main;
-
+      
       *_args = sub
       {
         my $build = Alien::Build->resume('alienfile', '_alien');
@@ -274,14 +184,14 @@ sub import
         $build->load_requires($build->install_type);
         ($build, @ARGV)
       };
-
+      
       *_touch = sub {
         my($name) = @_;
         my $path = Path::Tiny->new("_alien/mm/$name");
         $path->parent->mkpath;
         $path->touch;
       };
-
+      
       *prefix = sub
       {
         my($build, $type, $perl, $site, $vendor) = _args();
@@ -302,16 +212,16 @@ sub import
         $build->checkpoint;
         _touch('prefix');
       };
-
+      
       *version = sub
       {
         my($build, $version) = _args();
-
+        
         $build->runtime_prop->{perl_module_version} = $version;
         $build->checkpoint;
         _touch('version');
       };
-
+      
       *download = sub
       {
         my($build) = _args();
@@ -319,11 +229,11 @@ sub import
         $build->checkpoint;
        _touch('download');
       };
-
+      
       *build = sub
       {
         my($build) = _args();
-
+        
         $build->build;
 
         my $distname = $build->install_prop->{mm}->{distname};
@@ -335,10 +245,10 @@ sub import
           my $archfile = $archdir->child($archdir->basename . '.txt');
           $archfile->spew('Alien based distribution with architecture specific file in share');
         }
-
+        
         my $cflags = $build->runtime_prop->{cflags};
         my $libs   = $build->runtime_prop->{libs};
-
+        
         if(($cflags && $cflags !~ /^\s*$/)
         || ($libs   && $libs   !~ /^\s*$/))
         {
@@ -358,35 +268,21 @@ sub import
             "=cut\n",
           );
         }
-
+        
         $build->checkpoint;
         _touch('build');
       };
-
-      *test = sub
-      {
-        my($build) = _args();
-        $build->test;
-        $build->checkpoint;
-      };
-
-      *clean_install = sub
-      {
-        my($build) = _args();
-        $build->clean_install;
-        $build->checkpoint;
-      };
-
+      
       *dumpprop = sub
       {
         my($build, $type) = _args();
-
+        
         my %h = (
           meta    => $build->meta_prop,
           install => $build->install_prop,
           runtime => $build->runtime_prop,
         );
-
+        
         require Alien::Build::Util;
         print Alien::Build::Util::_dump($type ? $h{$type} : \%h);
       }
@@ -408,11 +304,11 @@ Alien::Build::MM - Alien::Build installer code for ExtUtils::MakeMaker
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
-In your C<Makefile.PL>:
+In your Makefile.PL:
 
  use ExtUtils::MakeMaker;
  use Alien::Build::MM;
@@ -428,45 +324,18 @@ In your C<Makefile.PL>:
  ));
  
  sub MY::postamble {
-   $abmm->mm_postamble(@_);
- }
- 
- sub MY::install {
-   $abmm->mm_install(@_);
+   $abmm->mm_postamble;
  }
 
-In your C<lib/Alien/Libfoo.pm>:
+In your lib/Alien/Libfoo.pm:
 
  package Alien::Libfoo;
  use base qw( Alien::Base );
  1;
 
-In your alienfile (needs to be named C<alienfile> and should be in the root of your dist):
-
- use alienfile;
- 
- plugin 'PkgConfig' => 'libfoo';
- 
- share {
-   start_url 'http://libfoo.org';
-   ...
- };
-
 =head1 DESCRIPTION
 
 This class allows you to use Alien::Build and Alien::Base with L<ExtUtils::MakeMaker>.
-It load the L<alienfile> recipe in the root of your L<Alien> dist, updates the prereqs
-passed into C<WriteMakefile> if any are specified by your L<alienfile> or its plugins,
-and adds a postamble to the C<Makefile> that will download/build/test the alienized
-package as appropriate.
-
-The L<alienfile> must be named C<alienfile>.
-
-If you are using L<Dist::Zilla> to author your L<Alien> dist, you should consider using
-the L<Dist::Zilla::Plugin::AlienBuild> plugin.
-
-I personally don't recommend it, but if you want to use L<Module::Build> instead, you
-can use L<Alien::Build::MB>.
 
 =head1 CONSTRUCTOR
 
@@ -484,30 +353,6 @@ Create a new instance of L<Alien::Build::MM>.
 
 The L<Alien::Build> instance.
 
-=head2 alienfile_meta
-
- my $bool = $abmm->alienfile_meta
-
-Set to a false value, in order to turn off the x_alienfile meta
-
-=head2 clean_install
-
- my $bool = $abmm->clean_install;
-
-Set to a true value, in order to clean the share directory prior to
-installing.  If you use this you have to make sure that you install
-the install handler in your C<Makefile.PL>:
-
- $abmm = Alien::Build::MM->new(
-   clean_install => 1,
- );
- 
- ...
- 
- sub MY::install {
-   $abmm->mm_install(@_);
- }
-
 =head1 METHODS
 
 =head2 mm_args
@@ -518,8 +363,7 @@ Adjust the arguments passed into C<WriteMakefile> as needed by L<Alien::Build>.
 
 =head2 mm_postamble
 
- my $postamble $abmm->mm_postamble;
- my $postamble $abmm->mm_postamble($mm);
+ my %args = $abmm->mm_args(%args);
 
 Returns the postamble for the C<Makefile> needed for L<Alien::Build>.
 This adds the following C<make> targets which are normally called when
@@ -544,36 +388,15 @@ Downloads the source from the internet.  Does nothing for a system install.
 Build from source (if a share install).  Gather configuration (for either
 system or share install).
 
-=item alien_prop, alien_prop_meta, alien_prop_install, alien_prop_runtime
+=item alien_prop
 
 Prints the meta, install and runtime properties for the Alien.
 
-=item alien_realclean, alien_clean
-
-Removes the alien specific files.  These targets are executed when you call
-the C<realclean> and C<clean> targets respectively.
-
-=item alien_clean_install
-
-Cleans out the Alien's share directory.  Caution should be used in invoking
-this target directly, as if you do not understand what you are doing you
-are likely to break your already installed Alien.
-
 =back
 
-=head2 mm_install
-
- sub MY::install {
-   $abmm->mm_install(@_);
- }
-
-B<EXPERIMENTAL>
-
-Adds an install rule to clean the final install dist directory prior to installing.
-
 =head1 SEE ALSO
 
-L<Alien::Build>, L<Alien::Base>, L<Alien>, L<Dist::Zilla::Plugin::AlienBuild>, L<Alien::Build::MB>
+L<Alien::Build>, L<Alien::Base>, L<Alien>
 
 =head1 AUTHOR
 
@@ -583,7 +406,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -597,7 +420,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -615,27 +438,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
