@@ -2,13 +2,13 @@ package Alien::Build::Plugin;
 
 use strict;
 use warnings;
+use Module::Load ();
 use Carp ();
 
-our @CARP_NOT = qw( alienfile Alien::Build Alien::Build::Meta );
+our @CARP_NOT = qw( alienfile );
 
 # ABSTRACT: Plugin base class for Alien::Build
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub new
@@ -16,22 +16,22 @@ sub new
   my $class = shift;
   my %args = @_ == 1 ? ($class->meta->default => $_[0]) : @_;
   my $self = bless {}, $class;
-
+  
   my $prop = $self->meta->prop;
   foreach my $name (keys %$prop)
   {
-    $self->{$name} = defined $args{$name}
-      ? delete $args{$name}
+    $self->{$name} = defined $args{$name} 
+      ? delete $args{$name} 
       : ref($prop->{$name}) eq 'CODE'
         ? $prop->{$name}->()
         : $prop->{$name};
   }
-
+  
   foreach my $name (keys %args)
   {
     Carp::carp "$class has no $name property";
   }
-
+  
   $self;
 }
 
@@ -50,13 +50,13 @@ sub import
 
   my $caller = caller;
   { no strict 'refs'; @{ "${caller}::ISA" } = __PACKAGE__ }
-
+  
   my $meta = $caller->meta;
   my $has = sub {
     my($name, $default) = @_;
     $meta->add_property($name, $default);
   };
-
+  
   { no strict 'refs'; *{ "${caller}::has" } = $has }
 }
 
@@ -64,11 +64,8 @@ sub import
 sub subplugin
 {
   my(undef, $name, %args) = @_;
-  Carp::carp("subplugin method is deprecated");
   my $class = "Alien::Build::Plugin::$name";
-  my $pm = "$class.pm";
-  $pm =~ s/::/\//g;
-  require $pm unless eval { $class->can('new') };
+  Module::Load::load($class) unless eval { $class->can('new') };
   delete $args{$_} for grep { ! defined $args{$_} } keys %args;
   $class->new(%args);
 }
@@ -113,7 +110,7 @@ sub add_property
     $self->{$name} = $new if defined $new;
     $self->{$name};
   };
-
+  
   # add the accessor
   { no strict 'refs'; *{ $self->{class} . '::' . $name} = $accessor }
 
@@ -139,7 +136,7 @@ Alien::Build::Plugin - Plugin base class for Alien::Build
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -157,11 +154,11 @@ Create your plugin:
  sub init
  {
    my($self, $meta) = @_;
- 
+
    my $prop1 = $self->prop1;
    my $prop2 = $self->prop2;
    my $prop3 = $self->prop3;
- 
+   
    $meta->register_hook(sub {
      build => [ '%{make}', '%{make} install' ],
    });
@@ -235,12 +232,10 @@ hooks and set meta properties on the L<Alien::Build> class.
 
 =head2 subplugin
 
-B<DEPRECATED>: Maybe removed, but not before 1 October 2018.
-
  my $plugin2 = $plugin1->subplugin($plugin_name, %args);
 
-Finds the given plugin and loads it (unless already loaded) and creats a
-new instance and returns it.  Most useful from a Negotiate plugin,
+Finds the given plugin and loads it using L<Module::Load> (unless already loaded)
+and creats a new instance and returns it.  Most useful from a Negotiate plugin,
 like this:
 
  sub init
@@ -284,7 +279,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -298,7 +293,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -316,27 +311,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
