@@ -8,8 +8,7 @@ use Alien::Build::Plugin;
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: CMake plugin for Alien::Build
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub cmake_generator
@@ -17,7 +16,7 @@ sub cmake_generator
   if($^O eq 'MSWin32')
   {
     return 'MinGW Makefiles' if is_dmake();
-
+  
     {
       my($out, $err) = capture { system $Config{make}, '/?' };
       return 'NMake Makefiles' if $out =~ /NMAKE/;
@@ -39,9 +38,9 @@ sub cmake_generator
 sub init
 {
   my($self, $meta) = @_;
-
+  
   $meta->prop->{destdir} = $^O eq 'MSWin32' ? 0 : 1;
-
+  
   $meta->add_requires('configure' => 'Alien::Build::Plugin::Build::CMake' => '0.99');
   $meta->add_requires('share'     => 'Alien::cmake3' => '0.02');
 
@@ -75,10 +74,9 @@ sub init
   $meta->interpolator->add_helper('cmake_generator' => \&cmake_generator);
 
   my @args = (
-    -G => '%{cmake_generator}',
+    -G => '%{cmake_generator}', 
     '-DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=true',
     '-DCMAKE_INSTALL_PREFIX:PATH=%{.install.prefix}',
-    '-DCMAKE_INSTALL_LIBDIR:PATH=lib',
     '-DCMAKE_MAKE_PROGRAM:PATH=%{make}',
   );
 
@@ -86,7 +84,7 @@ sub init
 
   $meta->default_hook(
     build => [
-      ['%{cmake}', @args, '%{.install.extract}' ],
+      ['%{cmake}', @args, '.' ],
       ['%{make}' ],
       ['%{make}', 'install' ],
     ],
@@ -129,7 +127,7 @@ Alien::Build::Plugin::Build::CMake - CMake plugin for Alien::Build
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -142,7 +140,7 @@ version 1.99_01
      [ '%{cmake}',
          @{ meta->prop->{plugin_build_cmake}->{args} },
          # ... put extra cmake args here ...
-         '%{.install.extract}'
+         '.'
      ],
      '%{make}',
      '%{make} install',
@@ -161,11 +159,8 @@ but for the moment includes:
  -G %{cmake_generator}                          \
  -DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=true    \
  -DCMAKE_INSTALL_PREFIX:PATH=%{.install.prefix} \
- -DCMAKE_INSTALL_LIBDIR:PATH=lib                \
  -DCMAKE_MAKE_PROGRAM:PATH=%{make}
 
-This plugin supports out-of-source builds via the meta property C<out_of_source>.
-
 =head1 METHODS
 
 =head2 cmake_generator
@@ -215,7 +210,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -229,7 +224,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -247,27 +242,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
