@@ -7,8 +7,7 @@ use File::Which ();
 use Env qw( @PATH );
 
 # ABSTRACT: MSYS plugin for Alien::Build
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has msys_version   => '0.07';
@@ -16,18 +15,18 @@ has msys_version   => '0.07';
 sub init
 {
   my($self, $meta) = @_;
-
+  
   if($self->msys_version ne '0.07')
   {
     $meta->add_requires('configure' => 'Alien::Build::Plugin::Build::MSYS' => '0.84');
   }
-
+  
   if(_win_and_needs_msys($meta))
   {
     $meta->add_requires('share' => 'Alien::MSYS' => $self->msys_version);
-
+    
     $meta->around_hook(
-      $_ => sub {
+      build => sub {
         my $orig = shift;
         my $build = shift;
 
@@ -36,10 +35,10 @@ sub init
 
         $orig->($build, @_);
       },
-    ) for qw( build build_ffi test_share test_ffi );
+    );
   }
 
-
+ 
   if($^O eq 'MSWin32')
   {
     # Most likely if we are trying to build something unix-y and
@@ -50,7 +49,7 @@ sub init
     );
 
   }
-
+  
   $self;
 }
 
@@ -81,12 +80,12 @@ Alien::Build::Plugin::Build::MSYS - MSYS plugin for Alien::Build
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- plugin 'Build::MSYS';
+ plugin 'Build::MSYS' => ();
 
 =head1 DESCRIPTION
 
@@ -127,7 +126,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -141,7 +140,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -159,27 +158,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
