@@ -8,8 +8,7 @@ use Capture::Tiny qw( capture );
 use Alien::Build::Plugin;
 
 # ABSTRACT: Make plugin for Alien::Build
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+make_type' => undef;
@@ -19,23 +18,23 @@ sub init
   my($self, $meta) = @_;
 
   $meta->add_requires('configure', 'Alien::Build::Plugin::Build::Make', '0.99');
-
+  
   my $type = $self->make_type;
-
+  
   return unless defined $type;
-
+  
   $type = 'gmake' if $^O eq 'MSWin32' && $type eq 'umake';
-
+  
   if($type eq 'nmake')
   {
     $meta->interpolator->replace_helper( make => sub { 'nmake' } );
   }
-
+  
   elsif($type eq 'dmake')
   {
     $meta->interpolator->replace_helper( make => sub { 'dmake' } );
   }
-
+  
   elsif($type eq 'gmake')
   {
     my $found = 0;
@@ -54,12 +53,12 @@ sub init
       $meta->interpolator->replace_helper('make' => sub { require Alien::gmake; Alien::gmake->exe });
     }
   }
-
+  
   elsif($type eq 'umake')
   {
     # nothing
   }
-
+  
   else
   {
     Carp::croak("unknown make type = ", $self->make_type);
@@ -80,7 +79,7 @@ Alien::Build::Plugin::Build::Make - Make plugin for Alien::Build
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -98,8 +97,8 @@ projects do not use.  This plugin will alter the L<alienfile> recipe to use a di
 case of C<gmake> / L<Alien::gmake>) automatically download and install an alienized version of that C<make> if it
 is not already installed.
 
-This plugin should NOT be used with other plugins that replace the C<make> helper, like
-L<Alien::Build::Plugin::Build::CMake>, L<Alien::Build::Plugin::Build::Autoconf>,
+This plugin should NOT be used with other plugins that replace the C<make> helper, like 
+L<Alien::Build::Plugin::Build::CMake>, L<Alien::Build::Plugin::Build::Autoconf>, 
 L<Alien::Build::Plugin::Build::MSYS>.  This plugin is intended instead for projects that use vanilla makefiles of
 a specific type.
 
@@ -148,7 +147,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -162,7 +161,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -180,27 +179,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
