@@ -10,8 +10,7 @@ use Alien::Build::Util qw( _mirror _destdir_prefix );
 use JSON::PP ();
 
 # ABSTRACT: Core gather plugin
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub init
@@ -25,18 +24,15 @@ sub init
   $meta->around_hook(
     gather_share => sub {
       my($orig, $build) = @_;
-
+      
       local $ENV{PATH} = $ENV{PATH};
       local $ENV{PKG_CONFIG_PATH} = $ENV{PKG_CONFIG_PATH};
       unshift @PATH, Path::Tiny->new('bin')->absolute->stringify
         if -d 'bin';
-
-      for my $dir (qw(share lib)) {
-          unshift @PKG_CONFIG_PATH, Path::Tiny->new("$dir/pkgconfig")->absolute->stringify
-            if -d "$dir/pkgconfig";
-      }
-
-      $orig->($build)
+      unshift @PKG_CONFIG_PATH, Path::Tiny->new('lib/pkgconfig')->absolute->stringify
+        if -d 'lib/pkgconfig';
+      
+      $orig->($build) 
     }
   );
 
@@ -45,7 +41,7 @@ sub init
     $meta->around_hook(
       "gather_$type" => sub {
         my($orig, $build) = @_;
-
+        
         if($build->meta_prop->{destdir})
         {
           my $destdir = $ENV{DESTDIR};
@@ -53,24 +49,20 @@ sub init
           {
             my $src = Path::Tiny->new(_destdir_prefix($ENV{DESTDIR}, $build->install_prop->{prefix}));
             my $dst = Path::Tiny->new($build->install_prop->{stage});
-
+        
             my $res = do {
               local $CWD = "$src";
               $orig->($build);
             };
-
+        
             $build->log("mirror $src => $dst");
-
+        
             $dst->mkpath;
-            # Please note: _mirror and Alien::Build::Util are ONLY
-            # allowed to be used by core plugins.  If you are writing
-            # a non-core plugin it may be removed.  That is why it
-            # is private.
             _mirror("$src", "$dst", {
               verbose => 1,
               filter => $build->meta_prop->{$type eq 'share' ? 'destdir_filter' : 'destdir_ffi_filter'},
             });
-
+        
             return $res;
           }
           else
@@ -87,37 +79,37 @@ sub init
           # prefix with the runtime prefix.
           my $old = $build->install_prop->{prefix};
           my $new = $build->runtime_prop->{prefix};
-
+        
           foreach my $flag (qw( cflags cflags_static libs libs_static ))
           {
             next unless defined $build->runtime_prop->{$flag};
             $build->runtime_prop->{$flag} =~ s{(-I|-L|-LIBPATH:)\Q$old\E}{$1 . $new}eg;
           }
-
+        
           return $ret;
         }
       }
     );
   }
-
+  
   $meta->after_hook(
     $_ => sub {
       my($build) = @_;
 
       die "stage is not defined.  be sure to call set_stage on your Alien::Build instance"
         unless $build->install_prop->{stage};
-
+      
       my $stage = Path::Tiny->new($build->install_prop->{stage});
       $build->log("mkdir -p $stage/_alien");
       $stage->child('_alien')->mkpath;
-
+      
       # drop a alien.json file for the runtime properties
       $stage->child('_alien/alien.json')->spew(
-        JSON::PP->new->pretty->canonical(1)->ascii->encode($build->runtime_prop)
+        JSON::PP->new->pretty->encode($build->runtime_prop)
       );
-
+      
       # copy the alienfile, if we managed to keep it around.
-      if($build->meta->filename                 &&
+      if($build->meta->filename                 && 
          -r $build->meta->filename              &&
          $build->meta->filename !~ /\.(pm|pl)$/ &&
          ! -d $build->meta->filename)
@@ -125,17 +117,13 @@ sub init
         Path::Tiny->new($build->meta->filename)
                   ->copy($stage->child('_alien/alienfile'));
       }
-
+      
       if($build->install_prop->{patch} && -d $build->install_prop->{patch})
       {
-        # Please note: _mirror and Alien::Build::Util are ONLY
-        # allowed to be used by core plugins.  If you are writing
-        # a non-core plugin it may be removed.  That is why it
-        # is private.
         _mirror($build->install_prop->{patch},
                 $stage->child('_alien/patch')->stringify);
       }
-
+    
     },
   ) for qw( gather_share gather_system );
 }
@@ -154,7 +142,7 @@ Alien::Build::Plugin::Core::Gather - Core gather plugin
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -177,7 +165,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -191,7 +179,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -209,27 +197,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
