@@ -7,13 +7,12 @@ use Config;
 use File::Which qw( which );
 
 # ABSTRACT: Core setup plugin
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub init
 {
-  my($self, $meta) = @_;
+  my($self, $meta) = @_;  
   $meta->prop->{platform} ||= {};
   $self->_platform($meta->prop->{platform});
 }
@@ -21,7 +20,7 @@ sub init
 sub _platform
 {
   my(undef, $hash) = @_;
-
+  
   if($^O eq 'MSWin32' && $Config{ccname} eq 'cl')
   {
     $hash->{compiler_type} = 'microsoft';
@@ -30,7 +29,7 @@ sub _platform
   {
     $hash->{compiler_type} = 'unix';
   }
-
+  
   if($^O eq 'MSWin32')
   {
     $hash->{system_type} = 'windows-unknown';
@@ -85,7 +84,7 @@ Alien::Build::Plugin::Core::Setup - Core setup plugin
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -108,7 +107,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -122,7 +121,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -140,27 +139,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
