@@ -8,8 +8,7 @@ use File::Temp ();
 use Path::Tiny ();
 
 # ABSTRACT: Plugin to extract a tarball using Archive::Tar
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+format' => 'tar';
@@ -17,36 +16,17 @@ has '+format' => 'tar';
 
 sub handles
 {
-  my(undef, $ext) = @_;
-
+  my($class, $ext) = @_;
+  
   return 1 if $ext =~ /^(tar|tar.gz|tar.bz2|tbz|taz)$/;
-
-  return 0;
-}
-
-
-sub available
-{
-  my(undef, $ext) = @_;
-
-  if($ext eq 'tar.gz')
-  {
-    return !! eval { require Archive::Tar; Archive::Tar->has_zlib_support };
-  }
-  elsif($ext eq 'tar.bz2')
-  {
-    return !! eval { require Archive::Tar; Archive::Tar->has_bzip2_support && __PACKAGE__->_can_bz2 };
-  }
-  else
-  {
-    return $ext eq 'tar';
-  }
+  
+  return;
 }
 
 sub init
 {
   my($self, $meta) = @_;
-
+  
   $meta->add_requires('share' => 'Archive::Tar' => 0);
   if($self->format eq 'tar.gz' || $self->format eq 'tgz')
   {
@@ -57,7 +37,7 @@ sub init
     $meta->add_requires('share' => 'IO::Uncompress::Bunzip2' => 0);
     $meta->add_requires('share' => 'IO::Compress::Bzip2' => 0);
   }
-
+  
   $meta->register_hook(
     extract => sub {
       my($build, $src) = @_;
@@ -103,7 +83,7 @@ Alien::Build::Plugin::Extract::ArchiveTar - Plugin to extract a tarball using Ar
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -138,12 +118,6 @@ correctly, since compressed archives require extra Perl modules to be installed.
 Returns true if the plugin is able to handle the archive of the
 given format.
 
-=head2 available
-
- Alien::Build::Plugin::Extract::ArchiveTar->available($ext);
-
-Returns true if the plugin has what it needs right now to extract from the given format
-
 =head1 SEE ALSO
 
 L<Alien::Build::Plugin::Extract::Negotiate>, L<Alien::Build>, L<alienfile>, L<Alien::Build::MM>, L<Alien>
@@ -156,7 +130,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -170,7 +144,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -188,27 +162,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
