@@ -4,9 +4,8 @@ use strict;
 use warnings;
 use Alien::Build::Plugin;
 
-# ABSTRACT: Plugin to extract a tarball using Archive::Zip
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: Plugin to extract a tarball using Archive::Tar
+our $VERSION = '1.01'; # VERSION
 
 
 has '+format' => 'zip';
@@ -15,26 +14,18 @@ has '+format' => 'zip';
 sub handles
 {
   my($class, $ext) = @_;
-
+  
   return 1 if $ext eq 'zip';
-
-  return 0;
-}
-
-
-sub available
-{
-  my(undef, $ext) = @_;
-
-  !! ( $ext eq 'zip' && eval { require Archive::Zip; 1} );
+  
+  return;
 }
 
 sub init
 {
   my($self, $meta) = @_;
-
+  
   $meta->add_requires('share' => 'Archive::Zip' => 0);
-
+  
   $meta->register_hook(
     extract => sub {
       my($build, $src) = @_;
@@ -55,11 +46,11 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Extract::ArchiveZip - Plugin to extract a tarball using Archive::Zip
+Alien::Build::Plugin::Extract::ArchiveZip - Plugin to extract a tarball using Archive::Tar
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -74,10 +65,6 @@ Note: in most case you will want to use L<Alien::Build::Plugin::Extract::Negotia
 instead.  It picks the appropriate Extract plugin based on your platform and environment.
 In some cases you may need to use this plugin directly instead.
 
-B<Note>: Seriously do NOT use this plugin! L<Archive::Zip> is pretty unreliable and
-breaks all-the-time.  If you use the negotiator plugin mentioned above, then it will
-prefer installing L<Alien::unzip>, which is much more reliable than L<Archive::Zip>.
-
 This plugin extracts from an archive in zip format using L<Archive::Zip>.
 
 =head2 format
@@ -94,12 +81,6 @@ Gives a hint as to the expected format.  This should always be C<zip>.
 Returns true if the plugin is able to handle the archive of the
 given format.
 
-=head2 available
-
- Alien::Build::Plugin::Extract::ArchiveZip->available($ext);
-
-Returns true if the plugin has what it needs right now to extract from the given format
-
 =head1 SEE ALSO
 
 L<Alien::Build::Plugin::Extract::Negotiate>, L<Alien::Build>, L<alienfile>, L<Alien::Build::MM>, L<Alien>
@@ -112,7 +93,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -126,7 +107,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -144,27 +125,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
