@@ -10,80 +10,48 @@ use File::Temp qw( tempdir );
 use Capture::Tiny qw( capture_merged );
 
 # ABSTRACT: Plugin to extract an archive using command line tools
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+format' => 'tar';
 
 
-sub gzip_cmd
-{
+has gzip_cmd => sub {
   _which('gzip') ? 'gzip' : undef;
-}
-
-
-sub _which { scalar File::Which::which(@_) }
-
-sub bzip2_cmd
-{
-  _which('bzip2') ? 'bzip2' : undef;
-}
-
-
-sub xz_cmd
-{
-  _which('xz') ? 'xz' : undef;
-}
-
-
-{
-  my $bsd_tar;
-
-  # Note: GNU tar can be iffy to very bad on windows, where absolute
-  # paths get confused with remote tars.  We used to assume that 'tar.exe'
-  # is borked on Windows, but recent versions of Windows 10 come bundled
-  # with bsdtar (libarchive) named 'tar.exe', and we should definitely
-  # prefer that to ptar.
-  sub _windows_tar_is_bsdtar
-  {
-    return 1 if $^O ne 'MSWin32';
-    return $bsd_tar if defined $bsd_tar;
-    my($out) = capture_merged {
-      system 'tar', '--version';
-    };
-    return $bsd_tar = $out =~ /bsdtar/ ? 1 : 0
-  }
-}
-
-sub tar_cmd
-{
-  _which('bsdtar')
-    ? 'bsdtar'
-    # Slowlaris /usr/bin/tar doesn't seem to like pax global header
-    # but seems to have gtar in the path by default, which is okay with it
-    : $^O eq 'solaris' && _which('gtar')
-      ? 'gtar'
-      # See note above for Windows logic.
-      : _which('tar') && _windows_tar_is_bsdtar()
-        ? 'tar'
-        : _which('ptar')
-          ? 'ptar'
-          : undef;
 };
 
 
-sub unzip_cmd
-{
-  if($^O eq 'MSWin32' && _which('tar') && _windows_tar_is_bsdtar())
-  {
-    (_which('tar'), 'xf');
-  }
-  else
-  {
-    _which('unzip') ? 'unzip' : undef;
-  }
-}
+sub _which { File::Which::which(@_) }
+
+has bzip2_cmd => sub {
+  _which('bzip2') ? 'bzip2' : undef;
+};
+
+
+has xz_cmd => sub {
+  _which('xz') ? 'xz' : undef;
+};
+
+
+has tar_cmd => sub {
+  _which('bsdtar')
+    ? 'bsdtar'
+    # TODO: GNU tar can be iffy on windows, where absolute
+    # paths get confused with remote tars.  *sigh* fix later
+    # if we can, for now just assume that 'tar.exe' is borked
+    # on windows to be on the safe side.  The Fetch::ArchiveTar
+    # is probably a better plugin to use on windows anyway.
+    : _which('tar') && $^O ne 'MSWin32'
+      ? 'tar'
+      : _which('ptar')
+        ? 'ptar'
+        : undef;
+};
+
+
+has unzip_cmd => sub {
+  _which('unzip') ? 'unzip' : undef;
+};
 
 sub _run
 {
@@ -137,7 +105,7 @@ sub _dcon
     $self->xz_cmd(_which('xz')) unless defined $self->xz_cmd;
     $cmd = $self->xz_cmd unless $self->_tar_can('tar.xz');
   }
-
+  
   if($cmd && $src =~ /\.(gz|bz2|xz|Z)$/)
   {
     $name = $src;
@@ -148,7 +116,7 @@ sub _dcon
     $name = $src;
     $name =~ s/\.(tgz|tbz|txz|taz)$/.tar/;
   }
-
+  
   ($name,$cmd);
 }
 
@@ -156,7 +124,7 @@ sub _dcon
 sub handles
 {
   my($class, $ext) = @_;
-
+  
   my $self = ref $class
   ? $class
   : __PACKAGE__->new;
@@ -166,34 +134,25 @@ sub handles
   $ext = 'tar.bz2' if $ext eq 'tbz';
   $ext = 'tar.xz'  if $ext eq 'txz';
 
-  return 1 if $ext eq 'tar.gz'  && $self->_tar_can('tar.gz');
-  return 1 if $ext eq 'tar.Z'   && $self->_tar_can('tar.Z');
+  return 1 if $ext eq 'tar.gz' && $self->_tar_can('tar.gz');
+  return 1 if $ext eq 'tar.Z' && $self->_tar_can('tar.Z');
   return 1 if $ext eq 'tar.bz2' && $self->_tar_can('tar.bz2');
-  return 1 if $ext eq 'tar.xz'  && $self->_tar_can('tar.xz');
-
-  return 0 if $ext =~ s/\.(gz|Z)$// && (!$self->gzip_cmd);
-  return 0 if $ext =~ s/\.bz2$//    && (!$self->bzip2_cmd);
-  return 0 if $ext =~ s/\.xz$//     && (!$self->xz_cmd);
-
-  return 1 if $ext eq 'tar' && $self->_tar_can('tar');
-  return 1 if $ext eq 'zip' && $self->_tar_can('zip');
-
-  return 0;
-}
-
-
-sub available
-{
-  my(undef, $ext) = @_;
-
-  # this is actually the same as handles
-  __PACKAGE__->handles($ext);
+  return 1 if $ext eq 'tar.xz' && $self->_tar_can('tar.xz');
+  
+  return if $ext =~ s/\.(gz|Z)$// && (!$self->gzip_cmd);
+  return if $ext =~ s/\.bz2$//    && (!$self->bzip2_cmd);
+  return if $ext =~ s/\.xz$//     && (!$self->xz_cmd);
+  
+  return 1 if $ext eq 'tar' && $self->tar_cmd;
+  return 1 if $ext eq 'zip' && $self->unzip_cmd;
+  
+  return;
 }
 
 sub init
 {
   my($self, $meta) = @_;
-
+  
   if($self->format eq 'tar.xz' && !$self->handles('tar.xz'))
   {
     $meta->add_requires('share' => 'Alien::xz' => '0.06');
@@ -206,17 +165,13 @@ sub init
   {
     $meta->add_requires('share' => 'Alien::gzip' => '0.03');
   }
-  elsif($self->format eq 'zip' && !$self->handles('zip'))
-  {
-    $meta->add_requires('share' => 'Alien::unzip' => '0');
-  }
-
+  
   $meta->register_hook(
     extract => sub {
       my($build, $src) = @_;
-
+      
       my($dcon_name, $dcon_cmd) = _dcon($self, $src);
-
+      
       if($dcon_name)
       {
         unless($dcon_cmd)
@@ -242,7 +197,7 @@ sub init
         }
         $src = $dcon_name;
       }
-
+      
       if($src =~ /\.zip$/i)
       {
         $self->_run($build, $self->unzip_cmd, $src);
@@ -265,22 +220,25 @@ sub _tar_can
 {
   my($self, $ext) = @_;
 
+  my $tar = $self->tar_cmd;
+
+  return 1 if $ext eq 'tar';
+  
   unless(%tars)
   {
     my $name = '';
-    local $_; # to avoid dynamically scoped read-only $_ from upper scopes
-    while(my $line = <DATA>)
+    while(<DATA>)
     {
-      if($line =~ /^\[ (.*) \]$/)
+      if(/^\[ (.*) \]$/)
       {
         $name = $1;
       }
       else
       {
-        $tars{$name} .= $line;
+        $tars{$name} .= $_;
       }
     }
-
+    
     foreach my $key (keys %tars)
     {
       $tars{$key} = unpack "u", $tars{$key};
@@ -292,7 +250,7 @@ sub _tar_can
   return 0 unless $tars{$name};
 
   local $CWD = tempdir( CLEANUP => 1 );
-
+  
   my $cleanup = sub {
     my $save = $CWD;
     unlink $name;
@@ -300,29 +258,23 @@ sub _tar_can
     $CWD = '..';
     rmdir $save;
   };
-
+  
   Path::Tiny->new($name)->spew_raw($tars{$name});
 
-  my @cmd = ($self->tar_cmd, 'xf', $name);
-  if($ext eq 'zip')
-  {
-    @cmd = ($self->unzip_cmd, $name);
-  }
-
   my(undef, $exit) = capture_merged {
-    system(@cmd);
+    system($self->tar_cmd, 'xf', $name);
     $?;
   };
-
+  
   if($exit)
   {
     $cleanup->();
     return 0;
   }
-
+  
   my $content = eval { Path::Tiny->new('xx.txt')->slurp };
   $cleanup->();
-
+  
   return defined $content && $content eq "xx\n";
 }
 
@@ -338,7 +290,7 @@ Alien::Build::Plugin::Extract::CommandLine - Plugin to extract an archive using
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -391,13 +343,6 @@ The C<unzip> command, if available.  C<undef> if not available.
 Returns true if the plugin is able to handle the archive of the
 given format.
 
-=head2 available
-
- Alien::Build::Plugin::Extract::CommandLine->available($ext);
-
-Returns true if the plugin is available to extract without
-installing anything new.
-
 =head1 SEE ALSO
 
 L<Alien::Build::Plugin::Extract::Negotiate>, L<Alien::Build>, L<alienfile>, L<Alien::Build::MM>, L<Alien>
@@ -410,7 +355,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -424,7 +369,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -442,27 +387,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -470,86 +397,25 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 __DATA__
+[ xx.tar.xz ]
+M_3=Z6%H```3FUK1&`@`A`18```!T+^6CX`?_`&!=`#Q@M.AX.4O&N38V648.
+M[J6L\\<_[3M*R;CASOTX?P=AC_+TG]8[KH(8/FH'K8A88=^>]Y`\*#,F=7,6
+MMB.:40OP*L85<<5!.@M$*(&TH(*TAWN"E)(+1>_I$^W5V^4=``!FY,=\7,&)
+9IP`!?(`0````:OY*7K'$9_L"``````196@``
 
-[ xx.tar ]
-M>'@N='AT````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M`````````````#`P,#8T-"``,#`P-S8U(``P,#`P,C0@`#`P,#`P,#`P,#`S
-M(#$S-#,U,#0S-#(R(#`Q,C<P,P`@,```````````````````````````````
-M````````````````````````````````````````````````````````````
-M``````````````````````````````````````````!U<W1A<@`P,&]L;&ES
-M9P``````````````````````````````````<W1A9F8`````````````````
-M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M``````````````````````!X>`H`````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-M````````````````````````````````````````````````````````````
-7````````````````````````````````
+[ xx.tar.bz2 ]
+M0EIH.3%!62936=+(]$0``$A[D-$0`8!``7^``!!AI)Y`!```""``=!JGIH-(
+MT#0]0/2!**---&F@;4#0&:D;X?(6@JH(2<%'N$%3VHC-9E>S/N@"6&I*1@GN
+JNHCC2>$I5(<0BKR.=XBZ""HVZ;T,CV\LJ!K&*?9`#\7<D4X4)#2R/1$`
 
+[ xx.tar.gz ]
+M'XL(`(;*<%D``ZNHT"NI*&&@*3`P,#`S,5$`T>9FIF#:P`C"AP)C!4-C0V,3
+M0Q-30W-S!0-#(W-#0P8%`]HZ"P)*BTL2BX!.R<_)R2Q.QZT.J"PM#8\Y$(\H
+>P.DA`BHJN`;:":-@%(R"43`*!@```)9R\&H`"```
 
-[ xx.tar.Z ]
+[ xx.tar.Z]
 M'YV0>/"XH(.'#H"#"!,J7,BPH<.'$"-*1`BCH@T:-$``J`CCAHT:&CG"D)%Q
-MH\B3,T#$F$%C1@T8+6G(D`$"1@P9-V#,`%!SHL^?0(,*!5!G#ITP<DR^8<,F
+MH\B3,T#$F+&21@P:-6+<N`$"1@P9-V+$`%!SHL^?0(,*!5!G#ITP<DR^8<,F
 MS9PS0Q<:#6/&3-2%)V&$/*GQJM>O8,.*'1I0P=BS:-.J7<NVK=NW<./*G4NW
 7KMV[>//JW<NWK]^_@`,+'DRXL.'#0P$`
 
-
-[ xx.tar.bz2 ]
-M0EIH.3%!629365(,+ID``$A[D-$0`8!``7^``!!AI)Y`!```""``=!JGIBC3
-M30&CU`]($HHTTR:`>D#0)SI*Z'R%H*J"&3@H]P@J>U$F5BMHOC`$L-"8C!(V
-I"`'?*WA:(9*4U)@4)+"(V%.G]#W(_E6B'J8G]D`/Q=R13A0D%(,+ID``
-
-
-[ xx.tar.gz ]
-M'XL("!)'=%P``WAX+G1A<@"KJ-`KJ2AAH"DP,#`P,S%1`-'F9J9@VL`(PH<"
-M8P5#8Q-C4P,38Q,C(P4#0R-S`V,&!0/:.@L"2HM+$HN`3LG/R<DL3L>M#J@L
-E+0V/.1"/*,#I(0(J*K@&V@FC8!2,@E$P"@8````U:,3F``@`````
-
-
-[ xx.tar.xz ]
-M_3=Z6%H```3FUK1&`@`A`18```!T+^6CX`?_`&!=`#Q@M.AX.4O&N38V648.
-M[J6L\\<_[3M*R;CASOTX?B.F\V:^)+G;\YY4"!4MLF9`*\N40G=O+K,J0"NF
-M0VU7J%NN(A,R^DM8@/(_YGR5CAO+1CS_YNHE:,1!G%6L1\GT``"[$^?"O*"!
-9`P`!?(`0````:OY*7K'$9_L"``````196@``
-
-
-[ xx.zip ]
-M4$L#!`H``````%5V64X:^I"B`P````,````&`!P`>'@N='AT550)``,21W1<
-M$D=T7'5X"P`!!/4!```$%````'AX"E!+`0(>`PH``````%5V64X:^I"B`P``
-M``,````&`!@```````$```"D@0````!X>"YT>'155`4``Q)'=%QU>`L``03U
->`0``!!0```!02P4&``````$``0!,````0P``````
-
-
