@@ -7,8 +7,7 @@ use Alien::Build::Util qw( _mirror );
 use Path::Tiny ();
 
 # ABSTRACT: Plugin to extract a downloaded directory to a build directory
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+format' => 'd';
@@ -16,40 +15,24 @@ has '+format' => 'd';
 
 sub handles
 {
-  my(undef, $ext) = @_;
+  my($class, $ext) = @_;
   $ext eq 'd' ? 1 : ();
 }
 
-
-sub available
-{
-  my(undef, $ext) = @_;
-  __PACKAGE__->handles($ext);
-}
-
 sub init
 {
   my($self, $meta) = @_;
-
+  
   $meta->register_hook(
     extract => sub {
       my($build, $src) = @_;
-
       die "not a directory: $src" unless -d $src;
-
-      if($build->meta_prop->{out_of_source})
-      {
-        $build->install_prop->{extract} = Path::Tiny->new($src)->absolute->stringify;
-      }
-      else
-      {
-        my $dst = Path::Tiny->new('.')->absolute;
-        # Please note: _mirror and Alien::Build::Util are ONLY
-        # allowed to be used by core plugins.  If you are writing
-        # a non-core plugin it may be removed.  That is why it
-        # is private.
-        _mirror $src => $dst, { verbose => 1 };
-      }
+      my $dst = Path::Tiny::path('.')->absolute;
+      # Please note: _mirror and Alien::Build::Util are ONLY
+      # allowed to be used by core plugins.  If you are writing
+      # a non-core plugin it may be removed.  That is why it
+      # is private.
+      _mirror $src => $dst, { verbose => 1 };
     }
   );
 }
@@ -68,12 +51,12 @@ Alien::Build::Plugin::Extract::Directory - Plugin to extract a downloaded direct
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- plugin 'Extract::Directory';
+ plugin 'Extract::Directory' => ();
 
 =head1 DESCRIPTION
 
@@ -99,14 +82,6 @@ Should always set to C<d> (for directories).
 Returns true if the plugin is able to handle the archive of the
 given format.  Only returns true for C<d> (for directory).
 
-=head2 available
-
- Alien::Build::Plugin::Extract::Directory->available($ext);
- $plugin->available($ext);
-
-Returns true if the plugin can extract the given format with
-what is already installed.
-
 =head1 SEE ALSO
 
 L<Alien::Build::Plugin::Extract::Negotiate>, L<Alien::Build>, L<alienfile>, L<Alien::Build::MM>, L<Alien>
@@ -119,7 +94,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -133,7 +108,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -151,27 +126,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
