@@ -3,14 +3,9 @@ package Alien::Build::Plugin::Extract::Negotiate;
 use strict;
 use warnings;
 use Alien::Build::Plugin;
-use Alien::Build::Plugin::Extract::ArchiveTar;
-use Alien::Build::Plugin::Extract::ArchiveZip;
-use Alien::Build::Plugin::Extract::CommandLine;
-use Alien::Build::Plugin::Extract::Directory;
 
 # ABSTRACT: Extraction negotiation plugin
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+format' => 'tar';
@@ -18,55 +13,74 @@ has '+format' => 'tar';
 sub init
 {
   my($self, $meta) = @_;
-
+  
   my $format = $self->format;
   $format = 'tar.gz'  if $format eq 'tgz';
   $format = 'tar.bz2' if $format eq 'tbz';
   $format = 'tar.xz'  if $format eq 'txz';
-
-  my $plugin = $self->pick($format);
-  $meta->apply_plugin($plugin, format => $format);
-  $self;
+  
+  my $extract = $self->_pick($format);
+  
+  $self->_plugin($meta, 'Extract', $extract, format => $format);
 }
 
-
-sub pick
+sub _pick
 {
   my(undef, $format) = @_;
-
-  if($format =~ /^tar(\.(gz|bz2))?$/)
+  
+  if($format eq 'tar')
   {
-    if(Alien::Build::Plugin::Extract::ArchiveTar->available($format))
+    return 'ArchiveTar';
+  }
+  elsif($format eq 'tar.gz')
+  {
+    if(eval q{ require Archive::Tar; Archive::Tar->has_zlib_support })
     {
-      return 'Extract::ArchiveTar';
+      return 'ArchiveTar';
     }
     else
     {
-      return 'Extract::CommandLine';
+      return 'CommandLine';
+    }
+  }
+  elsif($format eq 'tar.bz2')
+  {
+    if(eval q{ require Alien::Build::Plugin::Extract::ArchiveTar; Alien::Build::Plugin::Extract::ArchiveTar->_can_bz2 })
+    {
+      return 'ArchiveTar';
+    }
+    else
+    {
+      return 'CommandLine';
     }
   }
   elsif($format eq 'zip')
   {
     # Archive::Zip is not that reliable.  But if it is already installed it is probably working
-    if(Alien::Build::Plugin::Extract::ArchiveZip->available($format))
+    if(eval q{ require Archive::Zip; 1 })
     {
-      return 'Extract::ArchiveZip';
+      return 'ArchiveZip';
     }
-
-    # If it isn't available, then use the command-line unzip.  Alien::unzip will be used
-    # as necessary in environments where it isn't already installed.
+    
+    # if we don't have Archive::Zip, check if we have the unzip command
+    elsif(eval { require Alien::Build::Plugin::Extract::CommandLine; Alien::Build::Plugin::Extract::CommandLine->new->unzip_cmd })
+    {
+      return 'CommandLine';
+    }
+    
+    # okay fine.  I will try to install Archive::Zip :(
     else
     {
-      return 'Extract::CommandLine';
+      return 'ArchiveZip';
     }
   }
   elsif($format eq 'tar.xz' || $format eq 'tar.Z')
   {
-    return 'Extract::CommandLine';
+    return 'CommandLine';
   }
   elsif($format eq 'd')
   {
-    return 'Extract::Directory';
+    return 'Directory';
   }
   else
   {
@@ -74,6 +88,16 @@ sub pick
   }
 }
 
+sub _plugin
+{
+  my($self, $meta, $type, $name, @args) = @_;
+  my $class = "Alien::Build::Plugin::${type}::$name";
+  my $pm    = "Alien/Build/Plugin/$type/$name.pm";
+  require $pm;
+  my $plugin = $class->new(@args);
+  $plugin->init($meta); 
+}
+
 1;
 
 __END__
@@ -88,7 +112,7 @@ Alien::Build::Plugin::Extract::Negotiate - Extraction negotiation plugin
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -99,7 +123,7 @@ version 1.99_01
 
 =head1 DESCRIPTION
 
-This is a negotiator plugin for extracting packages downloaded from the internet.
+This is a negotiator plugin for extracting packages downloaded from the internet. 
 This plugin picks the best Extract plugin to do the actual work.  Which plugins are
 picked depend on the properties you specify, your platform and environment.  It is
 usually preferable to use a negotiator plugin rather than using a specific Extract
@@ -112,14 +136,6 @@ Plugin from your L<alienfile>.
 The expected format for the download.  Possible values include:
 C<tar>, C<tar.gz>, C<tar.bz2>, C<tar.xz>, C<zip>, C<d>.
 
-=head1 METHODS
-
-=head2 pick
-
- my $name = Alien::Build::Plugin::Extract::Negotiate->pick($format);
-
-Returns the name of the best plugin for the given format.
-
 =head1 SEE ALSO
 
 L<Alien::Build>, L<alienfile>, L<Alien::Build::MM>, L<Alien>
@@ -132,7 +148,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -146,7 +162,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -164,27 +180,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
