@@ -4,12 +4,10 @@ use strict;
 use warnings;
 use Alien::Build::Plugin;
 use File::Basename ();
-use Alien::Build::Util qw( _ssl_reqs );
 use Carp ();
 
-# ABSTRACT: Plugin for fetching files using HTTP::Tiny
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: LWP plugin for fetching files
+our $VERSION = '1.01'; # VERSION
 
 
 has '+url' => '';
@@ -17,9 +15,6 @@ has '+url' => '';
 
 has ssl => 0;
 
-# ignored for compatability
-has bootstrap_ssl => 1;
-
 sub init
 {
   my($self, $meta) = @_;
@@ -33,15 +28,12 @@ sub init
 
   if($self->url =~ /^https:/ || $self->ssl)
   {
-    my $reqs = _ssl_reqs;
-    foreach my $mod (sort keys %$reqs)
-    {
-      $meta->add_requires('share' => $mod => $reqs->{$mod});
-    }
+    $meta->add_requires('share' => 'IO::Socket::SSL' => '1.56' );
+    $meta->add_requires('share' => 'Net::SSLeay'     => '1.49' );
   }
-
+  
   $meta->register_hook( fetch => sub {
-    my($build, $url) = @_;
+    my(undef, $url) = @_;
     $url ||= $self->url;
 
     my $ua = HTTP::Tiny->new;
@@ -51,32 +43,10 @@ sub init
     {
       my $status = $res->{status} || '---';
       my $reason = $res->{reason} || 'unknown';
-
-      $build->log("$status $reason fetching $url");
-      if($status == 599)
-      {
-        $build->log("exception: $_") for split /\n/, $res->{content};
-
-        my($can_ssl, $why_ssl) = HTTP::Tiny->can_ssl;
-        if(! $can_ssl)
-        {
-          if($res->{redirects}) {
-            foreach my $redirect (@{ $res->{redirects} })
-            {
-              if(defined $redirect->{headers}->{location} && $redirect->{headers}->{location} =~ /^https:/)
-              {
-                $build->log("An attempt at a SSL URL https was made, but your HTTP::Tiny does not appear to be able to use https.");
-                $build->log("Please see: https://metacpan.org/pod/Alien::Build::Manual::FAQ#599-Internal-Exception-errors-downloading-packages-from-the-internet");
-              }
-            }
-          }
-        }
-      }
-
       die "error fetching $url: $status $reason";
     }
 
-    my($type) = split /;/, $res->{headers}->{'content-type'};
+    my($type) = split ';', $res->{headers}->{'content-type'};
     $type = lc $type;
     my $base            = URI->new($res->{url});
     my $filename        = File::Basename::basename do { my $name = $base->path; $name =~ s{/$}{}; $name };
@@ -91,7 +61,7 @@ sub init
         $filename = $1;
       }
     }
-
+    
     if($type eq 'text/html')
     {
       return {
@@ -108,7 +78,7 @@ sub init
         content  => $res->{content},
       };
     }
-
+    
   });
 
   $self;
@@ -124,19 +94,17 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Fetch::HTTPTiny - Plugin for fetching files using HTTP::Tiny
+Alien::Build::Plugin::Fetch::HTTPTiny - LWP plugin for fetching files
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- share {
-   start_url 'http://ftp.gnu.org/gnu/make';
-   plugin 'Fetch::HTTPTiny';
- };
+ meta->prop->{start_url} = 'http://ftp.gnu.org/gnu/make';
+ plugin 'Fetch::HTTPTiny' => ();
 
 =head1 DESCRIPTION
 
@@ -173,7 +141,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -187,7 +155,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -205,27 +173,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
