@@ -5,9 +5,8 @@ use warnings;
 use Alien::Build::Plugin;
 use Carp ();
 
-# ABSTRACT: Plugin for fetching files using LWP
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: LWP plugin for fetching files
+our $VERSION = '1.01'; # VERSION
 
 
 has '+url' => '';
@@ -20,7 +19,7 @@ sub init
   my($self, $meta) = @_;
 
   $meta->add_requires('share' => 'LWP::UserAgent' => 0 );
-
+  
   $meta->prop->{start_url} ||= $self->url;
   $self->url($meta->prop->{start_url});
   $self->url || Carp::croak('url is a required property');
@@ -51,7 +50,7 @@ sub init
         type    => 'html',
         charset => $charset,
         base    => "$base",
-        content => $res->decoded_content || $res->content,
+        content => $res->decoded_content,
       };
     }
     elsif($type eq 'text/ftp-dir-listing')
@@ -59,7 +58,7 @@ sub init
       return {
         type => 'dir_listing',
         base => "$base",
-        content => $res->decoded_content || $res->content,
+        content => $res->decoded_content,
       };
     }
     else
@@ -70,7 +69,7 @@ sub init
         content  => $res->content,
       };
     }
-
+    
   });
 
   $self;
@@ -86,19 +85,17 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Fetch::LWP - Plugin for fetching files using LWP
+Alien::Build::Plugin::Fetch::LWP - LWP plugin for fetching files
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- share {
-   start_url 'http://ftp.gnu.org/gnu/make';
-   plugin 'Fetch::LWP';
- };
+ meta->prop->{start_url} = 'http://ftp.gnu.org/gnu/make';
+ plugin 'Fetch::LWP' => ();
 
 =head1 DESCRIPTION
 
@@ -135,7 +132,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -149,7 +146,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -167,27 +164,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
