@@ -6,9 +6,8 @@ use Alien::Build::Plugin;
 use File::chdir;
 use Path::Tiny ();
 
-# ABSTRACT: Plugin for fetching a local file
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: Local file plugin for fetching files
+our $VERSION = '1.01'; # VERSION
 
 
 has '+url' => '';
@@ -22,7 +21,7 @@ has ssl => 0;
 sub init
 {
   my($self, $meta) = @_;
-
+    
   $meta->prop->{start_url} ||= $self->url;
   $self->url($meta->prop->{start_url} || 'patch');
 
@@ -45,12 +44,12 @@ sub init
     }
     $self->root($root);
   }
-
+  
   $meta->register_hook( fetch => sub {
     my(undef, $path) = @_;
-
+    
     $path ||= $self->url;
-
+    
     if($path =~ /^file:/)
     {
       my $root = URI::file->new($self->root);
@@ -58,15 +57,15 @@ sub init
       $path = URI::Escape::uri_unescape($url->path);
       $path =~ s{^/([a-z]:)}{$1}i if $^O eq 'MSWin32';
     }
-
+    
     $path = Path::Tiny->new($path)->absolute($self->root);
-
+    
     if(-d $path)
     {
       return {
         type => 'list',
         list => [
-          map { { filename => $_->basename, url => $_->stringify } }
+          map { { filename => $_->basename, url => $_->stringify } } 
           sort { $a->basename cmp $b->basename } $path->children,
         ],
       };
@@ -84,8 +83,8 @@ sub init
     {
       die "no such file or directory $path";
     }
-
-
+    
+    
   });
 }
 
@@ -99,19 +98,17 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Fetch::Local - Plugin for fetching a local file
+Alien::Build::Plugin::Fetch::Local - Local file plugin for fetching files
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- share {
-   start_url 'patch/libfoo-1.00.tar.gz';
-   plugin 'Fetch::Local';
- };
+ meta->prop->{start_url} = 'patch/libfoo-1.00.tar.gz';
+ plugin 'Fetch::Local';
 
 =head1 DESCRIPTION
 
@@ -164,7 +161,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -178,7 +175,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -196,27 +193,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
