@@ -6,9 +6,8 @@ use Alien::Build::Plugin;
 use File::chdir;
 use Path::Tiny ();
 
-# ABSTRACT: Plugin for fetching a local directory
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: Local directory plugin for fetching files
+our $VERSION = '1.01'; # VERSION
 
 
 has root => undef;
@@ -19,9 +18,9 @@ has ssl => 0;
 sub init
 {
   my($self, $meta) = @_;
-
+  
   my $url = $meta->prop->{start_url} || 'patch';
-
+  
   $meta->add_requires('configure' => 'Alien::Build::Plugin::Fetch::LocalDir' => '0.72' );
 
   if($url =~ /^file:/)
@@ -42,13 +41,13 @@ sub init
     }
     $self->root($root);
   }
-
+  
   $meta->register_hook(
     fetch => sub {
       my($build, $path) = @_;
-
+      
       $path ||= $url;
-
+      
       if($path =~ /^file:/)
       {
         my $root = URI::file->new($self->root);
@@ -56,9 +55,9 @@ sub init
         $path = $url->path;
         $path =~ s{^/([a-z]:)}{$1}i if $^O eq 'MSWin32';
       }
-
+      
       $path = Path::Tiny->new($path)->absolute($self->root);
-
+      
       if(-d $path)
       {
         return {
@@ -88,19 +87,17 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Fetch::LocalDir - Plugin for fetching a local directory
+Alien::Build::Plugin::Fetch::LocalDir - Local directory plugin for fetching files
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- share {
-   start_url 'patch/libfoo-1.00/';
-   plugin 'Fetch::LocalDir';
- };
+ meta->prop->{start_url} = 'patch/libfoo-1.00/';
+ plugin 'Fetch::LocalDir';
 
 =head1 DESCRIPTION
 
@@ -148,7 +145,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -162,7 +159,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -180,27 +177,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
