@@ -7,9 +7,8 @@ use Carp ();
 use File::Temp ();
 use Path::Tiny qw( path );
 
-# ABSTRACT: Plugin for fetching files using Net::FTP
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: Net::FTP plugin for fetching files
+our $VERSION = '1.01'; # VERSION
 
 
 has '+url' => '';
@@ -36,12 +35,12 @@ sub init
   $meta->register_hook( fetch => sub {
     my($build, $url) = @_;
     $url ||= $self->url;
-
+    
     $url = URI->new($url);
 
     die "Fetch::NetFTP does not support @{[ $url->scheme ]}"
       unless $url->scheme eq 'ftp';
-
+    
     $build->log("trying passive mode FTP first") if $self->passive;
     my $ftp = _ftp_connect($url, $self->passive);
 
@@ -49,30 +48,30 @@ sub init
 
     unless($path =~ m!/$!)
     {
-      my(@parts) = split /\//, $path;
+      my(@parts) = split '/', $path;
       my $filename = pop @parts;
       my $dir      = join '/', @parts;
-
+      
       my $path = eval {
         $ftp->cwd($dir) or die;
         my $tdir = File::Temp::tempdir( CLEANUP => 1);
         my $path = path("$tdir/$filename")->stringify;
-
+        
         unless(eval { $ftp->get($filename, $path) }) # NAT problem? try to use passive mode
         {
           $ftp->quit;
-
+          
           $build->log("switching to @{[ $self->passive ? 'active' : 'passive' ]} mode");
           $ftp = _ftp_connect($url, !$self->passive);
-
+          
           $ftp->cwd($dir) or die;
-
+          
           $ftp->get($filename, $path) or die;
         }
-
+        
         $path;
       };
-
+      
       if(defined $path)
       {
         return {
@@ -81,33 +80,33 @@ sub init
           path     => $path,
         };
       }
-
+      
       $path .= "/";
     }
-
+    
     $ftp->quit;
     $ftp = _ftp_connect($url, $self->passive);
     $ftp->cwd($path) or die "unable to fetch $url as either a directory or file";
-
+    
     my $list = eval { $ftp->ls };
     unless(defined $list) # NAT problem? try to use passive mode
     {
       $ftp->quit;
-
+      
       $build->log("switching to @{[ $self->passive ? 'active' : 'passive' ]} mode");
       $ftp = _ftp_connect($url, !$self->passive);
-
+      
       $ftp->cwd($path) or die "unable to fetch $url as either a directory or file";
-
+      
       $list = $ftp->ls;
-
+      
       die "cannot list directory $path on $url" unless defined $list;
     }
-
+    
     die "no files found at $url" unless @$list;
 
     $path .= '/' unless $path =~ /\/$/;
-
+    
     return {
       type => 'list',
       list => [
@@ -123,7 +122,7 @@ sub init
         } sort @$list,
       ],
     };
-
+    
   });
 
   $self;
@@ -136,12 +135,12 @@ sub _ftp_connect {
   my $ftp = Net::FTP->new(
     $url->host, Port =>$url->port, Passive =>$is_passive,
   ) or die "error fetching $url: $@";
-
+  
   $ftp->login($url->user, $url->password)
     or die "error on login $url: @{[ $ftp->message ]}";
-
+  
   $ftp->binary;
-
+  
   $ftp;
 }
 
@@ -155,19 +154,17 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Fetch::NetFTP - Plugin for fetching files using Net::FTP
+Alien::Build::Plugin::Fetch::NetFTP - Net::FTP plugin for fetching files
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- share {
-   start_url 'ftp://ftp.gnu.org/gnu/make';
-   plugin 'Fetch::NetFTP';
- };
+ meta->prop->{start_url} = 'ftp://ftp.gnu.org/gnu/make';
+ plugin 'Fetch::NetFTP' => ();
 
 =head1 DESCRIPTION
 
@@ -205,7 +202,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -219,7 +216,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -237,27 +234,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
