@@ -7,18 +7,17 @@ use Path::Tiny ();
 use Alien::Build::Util qw( _destdir_prefix );
 use File::Copy ();
 
-# ABSTRACT: Plugin to gather dynamic libraries into a separate directory
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+# ABSTRACT: LWP plugin for fetching files
+our $VERSION = '1.01'; # VERSION
 
 
 sub init
 {
   my($self, $meta) = @_;
 
-  # plugin was introduced in 0.42, but had a bug which was fixed in 0.48
+  # plugin was introduced in 0.42, but had a bug which was fixed in 0.48  
   $meta->add_requires('share' => 'Alien::Build::Plugin::Gather::IsolateDynamic' => '0.48' );
-
+  
   $meta->after_hook(
     gather_share => sub {
       my($build) = @_;
@@ -65,11 +64,11 @@ __END__
 
 =head1 NAME
 
-Alien::Build::Plugin::Gather::IsolateDynamic - Plugin to gather dynamic libraries into a separate directory
+Alien::Build::Plugin::Gather::IsolateDynamic - LWP plugin for fetching files
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -83,7 +82,7 @@ their own C<dynamic> directory.  This allows them to be used by FFI modules, but
 by XS modules.
 
 This plugin provides the equivalent functionality of the C<alien_isolate_dynamic> attribute
-from L<Alien::Base::ModuleBuild>.
+from L<Alien::Base::ModuleBuild>.  
 
 =head1 SEE ALSO
 
@@ -97,7 +96,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -111,7 +110,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -129,27 +128,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
