@@ -6,18 +6,14 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Probe system and determine library or tool properties using the pkg-config command line interface
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+pkg_name' => sub {
   Carp::croak "pkg_name is a required property";
 };
 
-# NOT used, for compat with other PkgConfig plugins
-has register_prereqs => 1;
-
-sub _bin_name {
+has bin_name => sub {
 
   # We prefer pkgconf to pkg-config because it seems to be the future.
 
@@ -31,17 +27,6 @@ sub _bin_name {
         : undef;
 };
 
-has bin_name => \&_bin_name;
-
-
-has atleast_version => undef;
-
-
-has exact_version => undef;
-
-
-has max_version => undef;
-
 
 has minimum_version => undef;
 
@@ -62,65 +47,32 @@ sub _val
   ();
 }
 
-
-sub available
-{
-  !!_bin_name();
-}
-
 sub init
 {
   my($self, $meta) = @_;
-
+  
   my $pkgconf = $self->bin_name;
 
-  unless(defined $meta->prop->{env}->{PKG_CONFIG})
-  {
-    $meta->prop->{env}->{PKG_CONFIG} = $pkgconf;
-  }
-
   my($pkg_name, @alt_names) = (ref $self->pkg_name) ? (@{ $self->pkg_name }) : ($self->pkg_name);
-
+  
   my @probe = map { [$pkgconf, '--exists', $_] } ($pkg_name, @alt_names);
-
+  
   if(defined $self->minimum_version)
   {
     push @probe, [ $pkgconf, '--atleast-version=' . $self->minimum_version, $pkg_name ];
   }
-  elsif(defined $self->atleast_version)
-  {
-    push @probe, [ $pkgconf, '--atleast-version=' . $self->atleast_version, $pkg_name ];
-  }
-
-  if(defined $self->exact_version)
-  {
-    push @probe, [ $pkgconf, '--exact-version=' . $self->exact_version, $pkg_name ];
-  }
-
-  if(defined $self->max_version)
-  {
-    push @probe, [ $pkgconf, '--max-version=' . $self->max_version, $pkg_name ];
-  }
-
-  push @probe, [ $pkgconf, '--modversion', $pkg_name, sub {
-    my($build, $args) = @_;
-    my $version = $args->{out};
-    $version =~ s{^\s+}{};
-    $version =~ s{\s*$}{};
-    $build->hook_prop->{version} = $version;
-  }];
 
   unshift @probe, sub {
     my($build) = @_;
     $build->runtime_prop->{legacy}->{name} ||= $pkg_name;
   };
-
+  
   $meta->register_hook(
     probe => \@probe
   );
 
   my @gather = map { [ $pkgconf, '--exists', $_] } ($pkg_name, @alt_names);
-
+  
   foreach my $prop_name (qw( cflags libs version ))
   {
     my $flag = $prop_name eq 'version' ? '--modversion' : "--$prop_name";
@@ -149,7 +101,7 @@ sub init
       }
     }
   }
-
+  
   $meta->register_hook(gather_system => [@gather]);
 
   if($meta->prop->{platform}->{system_type} eq 'windows-mingw')
@@ -171,7 +123,7 @@ sub init
       }
     },
   ) for qw( gather_system gather_share );
-
+  
   $self;
 }
 
@@ -189,7 +141,7 @@ Alien::Build::Plugin::PkgConfig::CommandLine - Probe system and determine librar
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -214,29 +166,9 @@ the best command line tools to accomplish this task.
 The package name.  If this is a list reference then .pc files with all those package
 names must be present.
 
-=head2 atleast_version
-
-The minimum required version that is acceptable version as provided by the system.
-
-=head2 exact_version
-
-The exact required version that is acceptable version as provided by the system.
-
-=head2 max_version
-
-The max required version that is acceptable version as provided by the system.
-
 =head2 minimum_version
 
-Alias for C<atleast_version> for backward compatibility.
-
-=head1 METHODS
-
-=head2 available
-
- my $bool = Alien::Build::Plugin::PkgConfig::CommandLine->available;
-
-Returns true if the necessary prereqs for this plugin are I<already> installed.
+The minimum required version that is acceptable version as provided by the system.
 
 =head1 SEE ALSO
 
@@ -250,7 +182,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -264,7 +196,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -282,27 +214,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
