@@ -6,8 +6,7 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Probe system and determine library or tool properties using PkgConfig::LibPkgConf
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -15,121 +14,67 @@ has '+pkg_name' => sub {
 };
 
 
-has atleast_version => undef;
-
-
-has exact_version => undef;
-
-
-has max_version => undef;
-
-
 has minimum_version => undef;
 
-# private for now, used by negotiator
-has register_prereqs => 1;
-
-
-use constant _min_version => '0.04';
-
-sub available
-{
-  !!eval { require PkgConfig::LibPkgConf; PkgConfig::LibPkgConf->VERSION(_min_version) };
-}
-
 sub init
 {
   my($self, $meta) = @_;
 
-  unless(defined $meta->prop->{env}->{PKG_CONFIG})
-  {
-    # TODO: this doesn't yet find pkgconf in the bin dir of a share
-    # install.
-    my $command_line =
-      File::Which::which('pkgconf')
-      ? 'pkgconf'
-      : File::Which::which('pkg-config')
-        ? 'pkg-config'
-        : undef;
-    $meta->prop->{env}->{PKG_CONFIG} = $command_line
-      if defined $command_line;
-  }
-
-  if($self->register_prereqs)
+  my $caller = caller;
+  
+  if($caller ne 'Alien::Build::Plugin::PkgConfig::Negotiate')
   {
     # Also update in Neotiate.pm
-    $meta->add_requires('configure' => 'PkgConfig::LibPkgConf::Client' => _min_version);
-
-    if(defined $self->minimum_version || defined $self->atleast_version || defined $self->exact_version || defined $self->max_version)
+    $meta->add_requires('configure' => 'PkgConfig::LibPkgConf::Client' => '0.04');
+  
+    if(defined $self->minimum_version)
     {
-      $meta->add_requires('configure' => 'PkgConfig::LibPkgConf::Util' => _min_version);
+      $meta->add_requires('configure' => 'PkgConfig::LibPkgConf::Util' => '0.04');
     }
   }
-
+  
   my($pkg_name, @alt_names) = (ref $self->pkg_name) ? (@{ $self->pkg_name }) : ($self->pkg_name);
 
   $meta->register_hook(
     probe => sub {
       my($build) = @_;
       $build->runtime_prop->{legacy}->{name} ||= $pkg_name;
-
+    
       require PkgConfig::LibPkgConf::Client;
       my $client = PkgConfig::LibPkgConf::Client->new;
       my $pkg = $client->find($pkg_name);
       die "package $pkg_name not found" unless $pkg;
-
-      $build->hook_prop->{version} = $pkg->version;
-      my $atleast_version = $self->atleast_version;
-      $atleast_version = $self->minimum_version unless defined $self->atleast_version;
-      if($atleast_version)
+      if(defined $self->minimum_version)
       {
         require PkgConfig::LibPkgConf::Util;
-        if(PkgConfig::LibPkgConf::Util::compare_version($pkg->version, $atleast_version) == -1)
+        if(PkgConfig::LibPkgConf::Util::compare_version($pkg->version, $self->minimum_version) == -1)
         {
-          die "package $pkg_name is version @{[ $pkg->version ]}, but at least $atleast_version is required.";
+          die "package $pkg_name is not recent enough";
         }
       }
-
-      if($self->exact_version)
-      {
-        require PkgConfig::LibPkgConf::Util;
-        if(PkgConfig::LibPkgConf::Util::compare_version($pkg->version, $self->exact_version) != 0)
-        {
-          die "package $pkg_name is version @{[ $pkg->version ]}, but exactly @{[ $self->exact_version ]} is required.";
-        }
-      }
-
-      if($self->max_version)
-      {
-        require PkgConfig::LibPkgConf::Util;
-        if(PkgConfig::LibPkgConf::Util::compare_version($pkg->version, $self->max_version) == 1)
-        {
-          die "package $pkg_name is version @{[ $pkg->version ]}, but max @{[ $self->max_version ]} is required.";
-        }
-      }
-
+      
       foreach my $alt (@alt_names)
       {
         my $pkg = $client->find($alt);
         die "package $alt not found" unless $pkg;
       }
-
+      
       'system';
     },
   );
-
+  
   $meta->register_hook(
     $_ => sub {
       my($build) = @_;
       require PkgConfig::LibPkgConf::Client;
       my $client = PkgConfig::LibPkgConf::Client->new;
-
+      
       foreach my $name ($pkg_name, @alt_names)
       {
         my $pkg = $client->find($name);
         die "reload of package $name failed" unless defined $pkg;
 
-        my %prop;
+        my %prop;      
         $prop{version}        = $pkg->version;
         $prop{cflags}         = $pkg->cflags;
         $prop{libs}           = $pkg->libs;
@@ -137,7 +82,7 @@ sub init
         $prop{libs_static}    = $pkg->libs_static;
         $build->runtime_prop->{alt}->{$name} = \%prop;
       }
-
+      
       foreach my $key (keys %{ $build->runtime_prop->{alt}->{$pkg_name} })
       {
         $build->runtime_prop->{$key} = $build->runtime_prop->{alt}->{$pkg_name}->{$key};
@@ -149,7 +94,7 @@ sub init
       }
     },
   ) for qw( gather_system gather_share );
-
+  
   $self;
 }
 
@@ -167,7 +112,7 @@ Alien::Build::Plugin::PkgConfig::LibPkgConf - Probe system and determine library
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -196,29 +141,9 @@ it in core.  If it is spun off it will get its own distribution some time in the
 The package name.  If this is a list reference then .pc files with all those package
 names must be present.
 
-=head2 atleast_version
-
-The minimum required version that is acceptable version as provided by the system.
-
-=head2 exact_version
-
-The exact required version that is acceptable version as provided by the system.
-
-=head2 max_version
-
-The max required version that is acceptable version as provided by the system.
-
 =head2 minimum_version
 
-Alias for C<atleast_version> for backward compatibility.
-
-=head1 METHODS
-
-=head2 available
-
- my $bool = Alien::Build::Plugin::PkgConfig::LibPkgConf->available;
-
-Returns true if the necessary prereqs for this plugin are I<already> installed.
+The minimum required version that is acceptable version as provided by the system.
 
 =head1 SEE ALSO
 
@@ -232,7 +157,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -246,7 +171,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -264,27 +189,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
