@@ -6,8 +6,7 @@ use Alien::Build::Plugin;
 use Path::Tiny ();
 
 # ABSTRACT: Convert .pc files into static
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has path => undef;
@@ -15,14 +14,14 @@ has path => undef;
 sub _convert
 {
   my($self, $build, $path) = @_;
-
+  
   die "unable to read $path" unless -r $path;
   die "unable to write $path" unless -w $path;
-
+  
   $build->log("converting $path to static");
-
+  
   my %h = map {
-    my($key, $value) = /^(.*?):(.*?)$/;
+    my($key, $value) = $_ =~ /^(.*?):(.*?)$/;
     $value =~ s{^\s+}{};
     $value =~ s{\s+$}{};
     ($key => $value);
@@ -30,15 +29,15 @@ sub _convert
 
   $h{Cflags} = '' unless defined $h{Cflags};
   $h{Libs}   = '' unless defined $h{Libs};
-
+  
   $h{Cflags} .= ' ' . $h{"Cflags.private"} if defined $h{"Cflags.private"};
   $h{Libs}   .= ' ' . $h{"Libs.private"} if defined $h{"Libs.private"};
-
+  
   $h{"Cflags.private"} = '';
   $h{"Libs.private"}  = '';
-
+  
   $path->edit_lines(sub {
-
+  
     if(/^(.*?):/)
     {
       my $key = $1;
@@ -48,7 +47,7 @@ sub _convert
         delete $h{$key};
       }
     }
-
+  
   });
 
   $path->append("$_: $h{$_}\n") foreach keys %h;
@@ -57,7 +56,7 @@ sub _convert
 sub _recurse
 {
   my($self, $build, $dir) = @_;
-
+  
   foreach my $child ($dir->children)
   {
     if(-d $child)
@@ -80,7 +79,7 @@ sub init
   $meta->before_hook(
     gather_share => sub {
       my($build) = @_;
-
+    
       if($self->path)
       {
         $self->_convert($build, Path::Tiny->new($self->path)->absolute);
@@ -89,7 +88,7 @@ sub init
       {
         $self->_recurse($build, Path::Tiny->new(".")->absolute);
       }
-
+    
     },
   );
 }
@@ -108,7 +107,7 @@ Alien::Build::Plugin::PkgConfig::MakeStatic - Convert .pc files into static
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -138,7 +137,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -152,7 +151,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -170,27 +169,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
