@@ -4,12 +4,10 @@ use strict;
 use warnings;
 use Alien::Build::Plugin;
 use Carp ();
-use File::Which ();
 use Env qw( @PKG_CONFIG_PATH );
 
 # ABSTRACT: Probe system and determine library or tool properties using PkgConfig.pm
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -17,28 +15,8 @@ has '+pkg_name' => sub {
 };
 
 
-has atleast_version => undef;
-
-
-has exact_version => undef;
-
-
-has max_version => undef;
-
-
 has minimum_version => undef;
 
-
-use constant _min_version => '0.14026';
-
-# private for now, used by negotiator
-has register_prereqs => 1;
-
-sub available
-{
-  !!eval { require PkgConfig; PkgConfig->VERSION(_min_version) };
-}
-
 sub _cleanup
 {
   my($value) = @_;
@@ -49,31 +27,14 @@ sub _cleanup
 sub init
 {
   my($self, $meta) = @_;
-
-  unless(defined $meta->prop->{env}->{PKG_CONFIG})
+  
+  my $caller = caller;
+  
+  if($caller ne 'Alien::Build::Plugin::PkgConfig::Negotiate')
   {
-    # TODO: Better would be to to "execute" lib/PkgConfig.pm
-    # as that should always be available, and will match the
-    # exact version of PkgConfig.pm that we are using here.
-    # there are a few corner cases to deal with before we
-    # can do this.  What is here should handle most use cases.
-    my $command_line =
-      File::Which::which('ppkg-config')
-      ? 'ppkg-config'
-      : File::Which::which('pkg-config.pl')
-        ? 'pkg-config.pl'
-        : File::Which::which('pkg-config')
-          ? 'pkg-config'
-          : undef;
-    $meta->prop->{env}->{PKG_CONFIG} = $command_line
-      if defined $command_line;
+    $meta->add_requires('configure' => 'PkgConfig' => '0.14026');
   }
-
-  if($self->register_prereqs)
-  {
-    $meta->add_requires('configure' => 'PkgConfig' => _min_version);
-  }
-
+  
   my($pkg_name, @alt_names) = (ref $self->pkg_name) ? (@{ $self->pkg_name }) : ($self->pkg_name);
 
   $meta->register_hook(
@@ -81,48 +42,24 @@ sub init
       my($build) = @_;
       $build->runtime_prop->{legacy}->{name} ||= $pkg_name;
 
-      require PkgConfig;
       my $pkg = PkgConfig->find($pkg_name);
       die "package @{[ $pkg_name ]} not found" if $pkg->errmsg;
-
-      $build->hook_prop->{version} = $pkg->pkg_version;
-      my $version = PkgConfig::Version->new($pkg->pkg_version);
-
-      my $atleast_version = $self->atleast_version;
-      $atleast_version = $self->minimum_version unless defined $atleast_version;
-      if(defined $atleast_version)
+      if(defined $self->minimum_version)
       {
-        my $need    = PkgConfig::Version->new($atleast_version);
+        my $version = PkgConfig::Version->new($pkg->pkg_version);
+        my $need    = PkgConfig::Version->new($self->minimum_version);
         if($version < $need)
         {
-          die "package @{[ $pkg_name ]} is @{[ $pkg->pkg_version ]}, but at least $atleast_version is required.";
+          die "package @{[ $pkg_name ]} is not recent enough";
         }
       }
-
-      if(defined $self->exact_version)
-      {
-        my $need = PkgConfig::Version->new($self->exact_version);
-        if($version != $need)
-        {
-          die "package @{[ $pkg_name ]} is @{[ $pkg->pkg_version ]}, but exactly @{[ $self->exact_version ]} is required.";
-        }
-      }
-
-      if(defined $self->max_version)
-      {
-        my $need = PkgConfig::Version->new($self->max_version);
-        if($version > $need)
-        {
-          die "package @{[ $pkg_name ]} is @{[ $pkg->pkg_version ]}, but max of @{[ $self->max_version ]} is required.";
-        }
-      }
-
+      
       foreach my $alt (@alt_names)
       {
         my $pkg = PkgConfig->find($alt);
         die "package $alt not found" if $pkg->errmsg;
       }
-
+      
       'system';
     },
   );
@@ -133,7 +70,6 @@ sub init
 
     foreach my $name ($pkg_name, @alt_names)
     {
-      require PkgConfig;
       my $pkg = PkgConfig->find($name, search_path => [@PKG_CONFIG_PATH]);
       if($pkg->errmsg)
       {
@@ -163,7 +99,7 @@ sub init
       delete $build->runtime_prop->{alt};
     }
   };
-
+  
   $meta->register_hook(
     gather_system => $gather,
   );
@@ -171,7 +107,7 @@ sub init
   $meta->register_hook(
     gather_share => $gather,
   );
-
+  
   $self;
 }
 
@@ -189,7 +125,7 @@ Alien::Build::Plugin::PkgConfig::PP - Probe system and determine library or tool
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -214,29 +150,9 @@ L<PkgConfig> to accomplish this task.
 The package name.  If this is a list reference then .pc files with all those package
 names must be present.
 
-=head2 atleast_version
-
-The minimum required version that is acceptable version as provided by the system.
-
-=head2 exact_version
-
-The exact required version that is acceptable version as provided by the system.
-
-=head2 max_version
-
-The max required version that is acceptable version as provided by the system.
-
 =head2 minimum_version
 
-Alias for C<atleast_version> for backward compatibility.
-
-=head1 METHODS
-
-=head2 available
-
- my $bool = Alien::Build::Plugin::PkgConfig::PP->available;
-
-Returns true if the necessary prereqs for this plugin are I<already> installed.
+The minimum required version that is acceptable version as provided by the system.
 
 =head1 SEE ALSO
 
@@ -250,7 +166,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -264,7 +180,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -282,27 +198,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
