@@ -5,8 +5,7 @@ use warnings;
 use Alien::Build::Plugin;
 
 # ABSTRACT: Plugin to sort candidates by most recent first
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has 'filter'   => undef;
@@ -17,17 +16,17 @@ has '+version' => qr/([0-9](?:[0-9\.]*[0-9])?)/;
 sub init
 {
   my($self, $meta) = @_;
-
+  
   $meta->add_requires('share' => 'Sort::Versions' => 0);
-
+  
   $meta->register_hook( prefer => sub {
     my(undef, $res) = @_;
-
+    
     my $cmp = sub {
       my($A,$B) = map { $_ =~ $self->version } @_;
       Sort::Versions::versioncmp($B,$A);
     };
-
+    
     my @list = sort { $cmp->($a->{filename}, $b->{filename}) }
                map {
                  ($_->{version}) = $_->{filename} =~ $self->version;
@@ -35,7 +34,7 @@ sub init
                grep { $_->{filename} =~ $self->version }
                grep { defined $self->filter ? $_->{filename} =~ $self->filter : 1 }
                @{ $res->{list} };
-
+    
     return {
       type => 'list',
       list => \@list,
@@ -57,13 +56,13 @@ Alien::Build::Plugin::Prefer::SortVersions - Plugin to sort candidates by most r
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use alienfile;
  
- plugin 'Prefer::SortVersions';
+ plugin 'Prefer::SortVersions' => ();
 
 =head1 DESCRIPTION
 
@@ -75,9 +74,6 @@ This Prefer plugin sorts the packages that were retrieved from a dir listing, ei
 directly from a Fetch plugin, or from a Decode plugin.  It Returns a listing with the
 items sorted from post preferable to least, and filters out any undesirable candidates.
 
-This plugin updates the file list to include the versions that are extracted, so they
-can be used by other plugins, such as L<Alien::Build::Plugin::Prefer::BadVersion>.
-
 =head1 PROPERTIES
 
 =head2 filter
@@ -110,7 +106,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -124,7 +120,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -142,27 +138,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
