@@ -8,8 +8,7 @@ use File::Temp ();
 use Capture::Tiny qw( capture_merged capture );
 
 # ABSTRACT: Probe for system libraries by guessing with ExtUtils::CBuilder
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 has options => sub { {} };
@@ -35,11 +34,11 @@ has lang => 'C';
 sub init
 {
   my($self, $meta) = @_;
-
-  $meta->add_requires('configure' => 'ExtUtils::CBuilder' => 0 );
+  
+  $meta->add_requires('configure' => 'ExtUtils::CBuilder' => 0 );  
 
   if(@{ $self->aliens })
-  {
+  {  
     die "You can't specify both 'aliens' and either 'cflags' or 'libs' for the Probe::CBuilder plugin" if $self->cflags || $self->libs;
 
     $meta->add_requires('configure' => $_ => 0 ) for @{ $self->aliens };
@@ -49,87 +48,83 @@ sub init
     my $libs   = '';
     foreach my $alien (@{ $self->aliens })
     {
-      my $pm = "$alien.pm";
-      $pm =~ s/::/\//g;
-      require $pm;
+      require Module::Load;
+      Module::Load::load($alien);
       $cflags .= $alien->cflags . ' ';
       $libs   .= $alien->libs   . ' ';
     }
     $self->cflags($cflags);
     $self->libs($libs);
   }
-
+  
   my @cpp;
-
+  
   if($self->lang ne 'C')
   {
     $meta->add_requires('Alien::Build::Plugin::Probe::CBuilder' => '0.53');
     @cpp = ('C++' => 1) if $self->lang eq 'C++';
   }
-
+  
   $meta->register_hook(
     probe => sub {
       my($build) = @_;
-      local $CWD = File::Temp::tempdir( CLEANUP => 1, DIR => $CWD );
-
+      local $CWD = File::Temp::tempdir( CLEANUP => 1 );
+      
       open my $fh, '>', 'mytest.c';
       print $fh $self->program;
       close $fh;
-
+      
       $build->log("trying: cflags=@{[ $self->cflags ]} libs=@{[ $self->libs ]}");
-
-      my $cb = ExtUtils::CBuilder->new(%{ $self->options });
+      
+      my $b = ExtUtils::CBuilder->new(%{ $self->options });
 
       my($out1, $obj) = capture_merged { eval {
-        $cb->compile(
+        $b->compile(
           source               => 'mytest.c',
           extra_compiler_flags => $self->cflags,
           @cpp,
         );
       } };
-
+      
       if(my $error = $@)
       {
         $build->log("compile failed: $error");
         $build->log("compile failed: $out1");
         die $@;
       }
-
+      
       my($out2, $exe) = capture_merged { eval {
-        $cb->link_executable(
+        $b->link_executable(
           objects              => [$obj],
           extra_linker_flags   => $self->libs,
         );
       } };
-
+      
       if(my $error = $@)
       {
         $build->log("link failed: $error");
         $build->log("link failed: $out2");
         die $@;
-      }
-
+      }      
+      
       my($out, $err, $ret) = capture { system($^O eq 'MSWin32' ? $exe : "./$exe") };
       die "execute failed" if $ret;
-
-      my $cflags = $self->cflags;
-      my $libs   = $self->libs;
-
-      $cflags =~ s{\s*$}{ };
-      $libs =~ s{\s*$}{ };
-
-      $build->install_prop->{plugin_probe_cbuilder_gather} = {
-        cflags  => $cflags,
-        libs    => $libs,
-      };
-
+      
       if(defined $self->version)
       {
-        my($version) = $out =~ $self->version;
-        $build->hook_prop->{version} = $version;
-        $build->install_prop->{plugin_probe_cbuilder_gather}->{version} = $version;
+        ($build->runtime_prop->{version}) = $out =~ $self->version;
       }
-
+      
+      my $cflags = $self->cflags;
+      my $libs   = $self->libs;
+      
+      $cflags =~ s{\s*$}{ };
+      $libs =~ s{\s*$}{ };
+      
+      $build->runtime_prop->{cflags} = $cflags;
+      $build->runtime_prop->{libs}   = $libs;
+      $build->install_prop->{plugin_probe_cbuilder_gather} = 1;
+      
       'system';
     }
   );
@@ -137,13 +132,9 @@ sub init
   $meta->register_hook(
     gather_system => sub {
       my($build) = @_;
-      if(my $p = $build->install_prop->{plugin_probe_cbuilder_gather})
+      unless($build->install_prop->{plugin_probe_cbuilder_gather})
       {
-        $build->runtime_prop->{$_} = $p->{$_} for keys %$p;
-      }
-      else
-      {
-        die "cbuilder unable to gather; if you are using multiple probe steps you may need to provide your own gather.";
+        die "cbuilder plugin failed to gather";
       }
     },
   );
@@ -163,7 +154,7 @@ Alien::Build::Plugin::Probe::CBuilder - Probe for system libraries by guessing w
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -231,7 +222,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -245,7 +236,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -263,27 +254,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
