@@ -4,14 +4,12 @@ use strict;
 use warnings;
 use base qw( Exporter );
 use Path::Tiny qw( path );
-use Config;
 
 # ABSTRACT: Private utility functions for Alien::Build
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
-our @EXPORT_OK = qw( _mirror _dump _destdir_prefix _perl_config _ssl_reqs _has_ssl );
+our @EXPORT_OK = qw( _mirror _dump _destdir_prefix );
 
 # usage: _mirror $source_directory, $dest_direction, \%options
 #
@@ -29,7 +27,7 @@ sub _mirror
   require Alien::Build;
   require File::Find;
   require File::Copy;
-
+  
   File::Find::find({
     wanted => sub {
       next unless -e $File::Find::name;
@@ -73,19 +71,19 @@ sub _mirror
         # TODO: rmtree if a directory?
         if(-e "$dst")
         { unlink "$dst" }
-        Alien::Build->log("cp $src $dst") if $opt->{verbose};
+        Alien::Build->log("Alien::Build> cp $src $dst") if $opt->{verbose};
         File::Copy::cp("$src", "$dst") || die "copy error $src => $dst: $!";
         if($] < 5.012 && -x "$src" && $^O ne 'MSWin32')
         {
           # apparently Perl 5.8 and 5.10 do not preserver perms
-          my $mode = [stat "$src"]->[2] & oct(777);
+          my $mode = [stat "$src"]->[2] & 0777;
           eval { chmod $mode, "$dst" };
         }
       }
     },
     no_chdir => 1,
   }, "$src_root");
-
+  
   ();
 }
 
@@ -109,32 +107,6 @@ sub _destdir_prefix
   path($destdir)->child($prefix)->stringify;
 }
 
-sub _perl_config
-{
-  my($key) = @_;
-  $Config{$key};
-}
-
-sub _ssl_reqs
-{
-  return {
-    'Net::SSLeay' => '1.49',
-    'IO::Socket::SSL' => '1.56',
-  };
-}
-
-sub _has_ssl
-{
-  my %reqs = %{ _ssl_reqs() };
-  eval {
-    require Net::SSLeay;
-    die "need Net::SSLeay $reqs{'Net::SSLeay'}" unless Net::SSLeay->VERSION($reqs{'Net::SSLeay'});
-    require IO::Socket::SSL;
-    die "need IO::Socket::SSL $reqs{'IO::Socket::SSL'}" unless IO::Socket::SSL->VERSION($reqs{'IO::Socket::SSL'});
-  };
-  $@ eq '';
-}
-
 1;
 
 __END__
@@ -149,7 +121,7 @@ Alien::Build::Util - Private utility functions for Alien::Build
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 DESCRIPTION
 
@@ -173,7 +145,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -187,7 +159,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -205,27 +177,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
