@@ -7,8 +7,7 @@ use base qw( Exporter );
 our @EXPORT_OK = qw( _read_win32_reg_dump );
 
 # ABSTRACT: Private utility functions for Alien::Build
-our $VERSION = '1.15_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 # perl -MYAML= -MConfig::INI::Reader::Multiline -MFile::BOM -E 'use autodie; open $fh, "<:via(File::BOM)", "foo.reg"; <$fh>; say Dump(Config::INI::Reader::Multiline->read_handle($fh))'
@@ -83,7 +82,7 @@ Alien::Build::Util::Win32::RegistryDump - Private utility functions for Alien::B
 
 =head1 VERSION
 
-version 1.15_01
+version 1.01
 
 =head1 DESCRIPTION
 
@@ -121,7 +120,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -139,10 +138,6 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
