@@ -6,20 +6,20 @@ use 5.008001;
 use Env qw( @PATH );
 use File::Which 1.10 qw( which );
 use Capture::Tiny qw( capture capture_merged );
-use Alien::Build::Temp;
+use File::Temp ();
+use Carp qw( croak );
+use File::Basename qw( dirname );
 use File::Copy qw( move );
 use Text::ParseWords qw( shellwords );
 use Test2::API qw( context run_subtest );
 use base qw( Exporter );
 use Path::Tiny qw( path );
 use Alien::Build::Util qw( _dump );
-use Config;
 
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 our @aliens;
@@ -32,14 +32,14 @@ sub alien_ok ($;$)
   $name = 'undef' unless defined $name;
   my @methods = qw( cflags libs dynamic_libs bin_dir );
   $message ||= "$name responds to: @methods";
-
+  
   my $ok;
   my @diag;
-
+  
   if(defined $alien)
   {
     my @missing = grep { ! $alien->can($_) } @methods;
-
+  
     $ok = !@missing;
     push @diag, map { "  missing method $_" } @missing;
 
@@ -59,7 +59,7 @@ sub alien_ok ($;$)
   $ctx->ok($ok, $message);
   $ctx->diag($_) for @diag;
   $ctx->release;
-
+  
   $ok;
 }
 
@@ -70,17 +70,17 @@ sub synthetic
   $opt ||= {};
   my %alien = %$opt;
   require Test::Alien::Synthetic;
-  bless \%alien, 'Test::Alien::Synthetic',
+  bless \%alien, 'Test::Alien::Synthetic', 
 }
 
 
 sub run_ok
 {
   my($command, $message) = @_;
-
+  
   my(@command) = ref $command ? @$command : ($command);
   $message ||= "run @command";
-
+  
   require Test::Alien::Run;
   my $run = bless {
     out    => '',
@@ -89,7 +89,7 @@ sub run_ok
     sig    => 0,
     cmd    => [@command],
   }, 'Test::Alien::Run';
-
+  
   my $ctx = context();
   my $exe = which $command[0];
   if(defined $exe)
@@ -100,7 +100,7 @@ sub run_ok
     my $ok = 1;
     my($exit, $errno);
     ($run->{out}, $run->{err}, $exit, $errno) = capture { system $exe, @command; ($?,$!); };
-
+  
     if($exit == -1)
     {
       $ok = 0;
@@ -119,8 +119,8 @@ sub run_ok
     }
 
     $ctx->ok($ok, $message);
-    $ok
-      ? $ctx->note("  using $exe")
+    $ok 
+      ? $ctx->note("  using $exe") 
       : $ctx->diag("  using $exe");
     $ctx->diag(@diag) for @diag;
 
@@ -131,9 +131,9 @@ sub run_ok
     $ctx->diag("  command not found");
     $run->{fail} = 'command not found';
   }
-
+  
   $ctx->release;
-
+  
   $run;
 }
 
@@ -147,6 +147,26 @@ sub _flags
     : $class->$method;
 }
 
+{
+  my $seen = 0;
+  sub _warn_cpp
+  {
+    return if $seen;
+    my $ctx = context();
+    $ctx->diag('');
+    $ctx->diag('');
+    $ctx->diag(' !!!');
+    $ctx->diag('');
+    $ctx->diag("Test::Alien xs_ok C++ is DEPRECATED and will be removed on or after 31 August 2017");
+    $ctx->diag("Please use Test::Alien::CPP instead");
+    $ctx->diag('');
+    $ctx->diag(' !!!');
+    $ctx->diag('');
+    $ctx->release;
+    $seen++;
+  }
+}
+
 sub xs_ok
 {
   my $cb;
@@ -154,21 +174,8 @@ sub xs_ok
   my($xs, $message) = @_;
   $message ||= 'xs';
 
-  $xs = { xs => $xs } unless ref $xs;
-  # make sure this is a copy because we may
-  # modify it.
-  $xs->{xs} = "@{[ $xs->{xs} ]}";
-  $xs->{pxs}              ||= {};
-  $xs->{cbuilder_check}   ||= 'have_compiler';
-  $xs->{cbuilder_config}  ||= {};
-  $xs->{cbuilder_compile} ||= {};
-  $xs->{cbuilder_link}    ||= {};
-
   require ExtUtils::CBuilder;
-  my $skip = do {
-    my $have_compiler = $xs->{cbuilder_check};
-    !ExtUtils::CBuilder->new( config => $xs->{cbuilder_config} )->$have_compiler;
-  };
+  my $skip = !ExtUtils::CBuilder->new->have_compiler;
 
   if($skip)
   {
@@ -178,27 +185,34 @@ sub xs_ok
     $ctx->release;
     return;
   }
+  
+  $xs = { xs => $xs } unless ref $xs;
+  # make sure this is a copy because we may
+  # modify it.
+  $xs->{xs} = "@{[ $xs->{xs} ]}";
+  $xs->{pxs} ||= {};
+  $xs->{cbuilder_compile} ||= {};
+  $xs->{cbuilder_link}    ||= {};
 
   if($xs->{cpp} || $xs->{'C++'})
   {
-    my $ctx = context();
-    $ctx->bail("The cpp and C++ options have been removed from xs_ok");
+    _warn_cpp();
+    $xs->{pxs}->{'C++'} = 1;
+    $xs->{cbuilder_compile}->{'C++'} = 1;
+    $xs->{c_ext} = 'cpp';
   }
   else
   {
-    $xs->{c_ext} ||= 'c';
+    $xs->{c_ext} = 'c';
   }
 
   my $verbose = $xs->{verbose} || 0;
   my $ok = 1;
   my @diag;
-  my $dir = Alien::Build::Temp->newdir(
-    TEMPLATE => 'test-alien-XXXXXX',
-    CLEANUP  => $^O eq 'MSWin32' ? 0 : 1,
-  );
+  my $dir = _tempdir( CLEANUP => 1, TEMPLATE => 'testalienXXXXX' );
   my $xs_filename = path($dir)->child('test.xs')->stringify;
   my $c_filename  = path($dir)->child("test.@{[ $xs->{c_ext} ]}")->stringify;
-
+  
   my $ctx = context();
   my $module;
 
@@ -232,10 +246,10 @@ sub xs_ok
     open my $fh, '>', $xs_filename;
     print $fh $xs->{xs};
     close $fh;
-
+  
     require ExtUtils::ParseXS;
     my $pxs = ExtUtils::ParseXS->new;
-
+  
     my($out, $err) = capture_merged {
       eval {
         $pxs->process_file(
@@ -248,7 +262,7 @@ sub xs_ok
       };
       $@;
     };
-
+    
     $ctx->note("parse xs $xs_filename => $c_filename") if $verbose;
     $ctx->note($out) if $verbose;
     $ctx->note("error: $err") if $verbose && $err;
@@ -264,34 +278,21 @@ sub xs_ok
 
   if($ok)
   {
-    my $cb = ExtUtils::CBuilder->new(
-      config => do {
-        my %config = %{ $xs->{cbuilder_config} };
-        my $lddlflags = join(' ', grep !/^-l/, shellwords map { _flags $_, 'libs' } @aliens) . " $Config{lddlflags}";
-        $config{lddlflags} = defined $config{lddlflags} ? "$config{lddlflags} $lddlflags" : $lddlflags;
-        \%config;
-      },
-    );
+    my $cb = ExtUtils::CBuilder->new;
 
     my %compile_options = (
       source               => $c_filename,
+      extra_compiler_flags => [shellwords map { _flags $_, 'cflags' } @aliens],
       %{ $xs->{cbuilder_compile} },
     );
 
-    if(defined $compile_options{extra_compiler_flags} && ref($compile_options{extra_compiler_flags}) eq '')
-    {
-      $compile_options{extra_compiler_flags} = [ shellwords $compile_options{extra_compiler_flags} ];
-    }
-
-    push @{ $compile_options{extra_compiler_flags} }, shellwords map { _flags $_, 'cflags' } @aliens;
-
     my($out, $obj, $err) = capture_merged {
       my $obj = eval {
         $cb->compile(%compile_options);
       };
       ($obj, $@);
     };
-
+    
     $ctx->note("compile $c_filename") if $verbose;
     $ctx->note($out) if $verbose;
     $ctx->note($err) if $verbose && $err;
@@ -300,7 +301,7 @@ sub xs_ok
     {
       $ctx->note(_dump({ compile_options => \%compile_options }));
     }
-
+    
     unless($obj)
     {
       $ok = 0;
@@ -308,30 +309,24 @@ sub xs_ok
       push @diag, "    $err" if $err;
       push @diag, "    $_" for split /\r?\n/, $out;
     }
-
+    
     if($ok)
     {
 
       my %link_options = (
         objects            => [$obj],
         module_name        => $module,
+        extra_linker_flags => [shellwords map { _flags $_, 'libs' } @aliens],
         %{ $xs->{cbuilder_link} },
       );
 
-      if(defined $link_options{extra_linker_flags} && ref($link_options{extra_linker_flags}) eq '')
-      {
-        $link_options{extra_linker_flags} = [ shellwords $link_options{extra_linker_flags} ];
-      }
-
-      unshift @{ $link_options{extra_linker_flags} }, grep /^-l/, shellwords map { _flags $_, 'libs' } @aliens;
-
       my($out, $lib, $err) = capture_merged {
-        my $lib = eval {
+        my $lib = eval { 
           $cb->link(%link_options);
         };
         ($lib, $@);
       };
-
+      
       $ctx->note("link $obj") if $verbose;
       $ctx->note($out) if $verbose;
       $ctx->note($err) if $verbose && $err;
@@ -352,24 +347,25 @@ sub xs_ok
         push @diag, "    $err" if $err;
         push @diag, "    $_" for split /\r?\n/, $out;
       }
-
+      
       if($ok)
       {
+        require Config;
         my @modparts = split(/::/,$module);
-        my $dl_dlext = $Config{dlext};
+        my $dl_dlext = $Config::Config{dlext};
         my $modfname = $modparts[-1];
 
         my $libpath = path($dir)->child('auto', @modparts, "$modfname.$dl_dlext");
         $libpath->parent->mkpath;
         move($lib, "$libpath") || die "unable to copy $lib => $libpath $!";
-
+        
         pop @modparts;
         my $pmpath = path($dir)->child(@modparts, "$modfname.pm");
         $pmpath->parent->mkpath;
         open my $fh, '>', "$pmpath";
-
+        
         my($alien_with_xs_load, @rest) = grep { $_->can('xs_load') } @aliens;
-
+        
         if($alien_with_xs_load)
         {
           {
@@ -379,15 +375,15 @@ sub xs_ok
           }
           print $fh '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
             package $module;
-
+            
             use strict;
             use warnings;
             our \$VERSION = '0.01';
             our \@rest;
             our \$alien_with_xs_load;
-
+            
             \$alien_with_xs_load->xs_load('$module', \$VERSION, \@rest);
-
+            
             1;
           };
         }
@@ -395,13 +391,13 @@ sub xs_ok
         {
           print $fh '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
             package $module;
-
+          
             use strict;
             use warnings;
             require XSLoader;
             our \$VERSION = '0.01';
             XSLoader::load('$module',\$VERSION);
-
+          
             1;
           };
         }
@@ -409,18 +405,16 @@ sub xs_ok
 
         {
           local @INC = @INC;
-          unshift @INC, "$dir";
-          ## no critic
+          unshift @INC, $dir;
           eval '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
             use $module;
           };
-          ## use critic
         }
-
+        
         if(my $error = $@)
         {
           $ok = 0;
-          push @diag, '  XSLoader failed';
+          push @diag, '  DynaLoader failed';
           push @diag, "    $error";
         }
       }
@@ -430,7 +424,7 @@ sub xs_ok
   $ctx->ok($ok, $message);
   $ctx->diag($_) for @diag;
   $ctx->release;
-
+  
   if($cb)
   {
     $cb = sub {
@@ -447,26 +441,7 @@ sub xs_ok
   $ok;
 }
 
-sub with_subtest (&)
-{
-  my($code) = @_;
-
-  # it may be possible to catch a segmentation fault,
-  # but not with signal handlers apparently.  See:
-  # https://feepingcreature.github.io/handling.html
-  return $code if $^O eq 'MSWin32';
-
-  # try to catch a segmentation fault and bail out
-  # with a useful diagnostic.  prove test to swallow
-  # the diagnostic on such failures.
-  sub {
-    local $SIG{SEGV} = sub {
-      my $ctx = context();
-      $ctx->bail("Segmentation fault");
-    };
-    $code->(@_);
-  }
-}
+sub with_subtest (&) { $_[0]; }
 
 
 sub ffi_ok
@@ -474,53 +449,43 @@ sub ffi_ok
   my $cb;
   $cb = pop if defined $_[-1] && ref $_[-1] eq 'CODE';
   my($opt, $message) = @_;
-
+  
   $message ||= 'ffi';
-
+  
   my $ok = 1;
   my $skip;
   my $ffi;
   my @diag;
-
+  
   {
     my $min = '0.12'; # the first CPAN release
     $min = '0.15' if $opt->{ignore_not_found};
     $min = '0.18' if $opt->{lang};
-    $min = '0.99' if defined $opt->{api} && $opt->{api} > 0;
-    unless(eval { require FFI::Platypus; FFI::Platypus->VERSION($min) })
+    eval qq{ use FFI::Platypus $min };
+    if($@)
     {
       $ok = 0;
       $skip = "Test requires FFI::Platypus $min";
     }
   }
-
+  
   if($ok && $opt->{lang})
   {
     my $class = "FFI::Platypus::Lang::@{[ $opt->{lang} ]}";
-    {
-      my $pm = "$class.pm";
-      $pm =~ s/::/\//g;
-      eval { require $pm };
-    }
+    eval qq{ use $class () };
     if($@)
     {
       $ok = 0;
       $skip = "Test requires FFI::Platypus::Lang::@{[ $opt->{lang} ]}";
     }
   }
-
+  
   if($ok)
   {
     $ffi = FFI::Platypus->new(
-      do {
-        my @args = (
-          lib              => [map { $_->dynamic_libs } @aliens],
-          ignore_not_found => $opt->{ignore_not_found},
-          lang             => $opt->{lang},
-        );
-        push @args, api => $opt->{api} if defined $opt->{api};
-        @args;
-      }
+      lib              => [map { $_->dynamic_libs } @aliens],
+      ignore_not_found => $opt->{ignore_not_found},
+      lang             => $opt->{lang},
     );
     foreach my $symbol (@{ $opt->{symbols} || [] })
     {
@@ -531,9 +496,9 @@ sub ffi_ok
       }
     }
   }
-
-  my $ctx = context();
-
+  
+  my $ctx = context(); 
+  
   if($skip)
   {
     $ctx->skip($message, $skip);
@@ -543,7 +508,7 @@ sub ffi_ok
     $ctx->ok($ok, $message);
   }
   $ctx->diag($_) for @diag;
-
+  
   $ctx->release;
 
   if($cb)
@@ -558,16 +523,16 @@ sub ffi_ok
 
     goto \&Test2::API::run_subtest;
   }
-
+  
   $ok;
 }
 
 
 sub _interpolator
-{
+{  
   require Alien::Build::Interpolate::Default;
   my $intr = Alien::Build::Interpolate::Default->new;
-
+  
   foreach my $alien (@aliens)
   {
     if($alien->can('alien_helper'))
@@ -580,7 +545,7 @@ sub _interpolator
       }
     }
   }
-
+  
   $intr;
 }
 
@@ -590,7 +555,7 @@ sub helper_ok
 
   $message ||= "helper $name exists";
 
-  my $intr = _interpolator;
+  my $intr = _interpolator; 
 
   my $code = $intr->has_helper($name);
 
@@ -599,7 +564,7 @@ sub helper_ok
   my $ctx = context();
   $ctx->ok($ok, $message);
   $ctx->release;
-
+  
   $ok;
 }
 
@@ -607,16 +572,16 @@ sub helper_ok
 sub interpolate_template_is
 {
   my($template, $pattern, $message) = @_;
-
+  
   $message ||= "template matches";
-
+  
   my $intr = _interpolator;
-
+  
   my $value = eval { $intr->interpolate($template) };
   my $error = $@;
   my @diag;
   my $ok;
-
+  
   if($error)
   {
     $ok = 0;
@@ -633,14 +598,38 @@ sub interpolate_template_is
     $ok = $value eq "$pattern";
     push @diag, "value '$value' does not equal '$pattern'" unless $ok;
   }
-
+  
   my $ctx = context();
   $ctx->ok($ok, $message, [@diag]);
   $ctx->release;
-
+  
   $ok;
 }
 
+sub _tempdir {
+  # makes sure /tmp or whatever isn't mounted noexec,
+  # which will cause xs_ok tests to fail.
+
+  my $dir = File::Temp::tempdir(@_);
+
+  if($^O ne 'MSWin32')
+  {
+    my $filename = path($dir, 'foo.pl');
+    my $fh;
+    open $fh, '>', $filename;
+    print $fh "#!$^X";
+    close $fh;
+    chmod 0755, $filename;
+    system $filename, 'foo';
+    if($?)
+    {
+      $dir = File::Temp::tempdir( DIR => path('.')->absolute->stringify );
+    }
+  }
+  
+  $dir;  
+}
+
 1;
 
 __END__
@@ -655,7 +644,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -670,7 +659,7 @@ Test commands that come with your Alien:
    ->success
    # we only accept the version written
    # by Larry ...
-   ->out_like(qr{Larry Wall});
+   ->out_like(qr{Larry Wall}); 
  
  done_testing;
 
@@ -688,7 +677,7 @@ Test that your library works with C<XS>:
  };
  
  done_testing;
- 
+
  __DATA__
  
  #include "EXTERN.h"
@@ -868,16 +857,6 @@ The XS code.  This is the only required element.
 
 Extra L<ExtUtils::ParseXS> arguments passed in as a hash reference.
 
-=item cbuilder_check
-
-The compile check that should be done prior to attempting to build.
-Should be one of C<have_compiler> or C<have_cplusplus>.  Defaults
-to C<have_compiler>.
-
-=item cbuilder_config
-
-Hash to override values normally provided by C<Config>.
-
 =item cbuilder_compile
 
 Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
@@ -890,6 +869,12 @@ Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
 
 Spew copious debug information via test note.
 
+=item C++ or cpp
+
+[EXPERIMENTAL]
+
+XS should be compiled as C++.
+
 =back
 
 You can use the C<with_subtest> keyword to conditionally
@@ -900,6 +885,7 @@ skipped.  Example:
  xs_ok $xs, with_subtest {
    # skipped if $xs fails for some reason
    my($module) = @_;
+   plan 1;
    is $module->foo, 1;
  };
 
@@ -907,8 +893,6 @@ The module name detected during the XS parsing phase will
 be passed in to the subtest.  This is helpful when you are
 using a generated module name.
 
-If you need to test XS C++ interfaces, see L<Test::Alien::CPP>.
-
 =head2 ffi_ok
 
  ffi_ok;
@@ -935,16 +919,6 @@ not influence the C<symbols> key above.
 
 Set the language.  Used primarily for language specific native types.
 
-=item api
-
-Set the API.  C<api = 1> requires FFI::Platypus 0.99 or later.  This
-option was added with Test::Alien version 1.90, so your use line should
-include this version as a safeguard to make sure it works:
-
- use Test::Alien 1.90;
- ...
- ffi_ok ...;
-
 =back
 
 As with L</xs_ok> above, you can use the C<with_subtest> keyword to specify
@@ -996,8 +970,6 @@ either the given string or regular expression.
 
 =item L<Test::Alien::Synthetic>
 
-=item L<Test::Alien::CPP>
-
 =back
 
 =head1 AUTHOR
@@ -1008,7 +980,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -1022,7 +994,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -1040,27 +1012,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
