@@ -6,42 +6,19 @@ use 5.008001;
 use base qw( Exporter);
 use Path::Tiny qw( path );
 use Carp qw( croak );
-use Test2::API qw( context run_subtest );
+use File::Temp qw( tempdir );
+use Test2::API qw( context );
 use Capture::Tiny qw( capture_merged );
 use Alien::Build::Util qw( _mirror );
-use List::Util 1.33 qw( any );
-use Alien::Build::Temp;
 
-our @EXPORT = qw(
-  alienfile
-  alienfile_ok
-  alienfile_skip_if_missing_prereqs
-  alien_download_ok
-  alien_extract_ok
-  alien_build_ok
-  alien_build_clean
-  alien_clean_install
-  alien_install_type_is
-  alien_checkpoint_ok
-  alien_resume_ok
-  alien_subtest
-  alien_rc
-);
+our @EXPORT = qw( alienfile alienfile_ok alien_download_ok alien_extract_ok alien_build_ok alien_build_clean alien_install_type_is );
 
 # ABSTRACT: Tools for testing Alien::Build + alienfile
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 my $build;
-my $build_alienfile;
 my $build_root;
-my $build_targ;
-
-sub alienfile::targ
-{
-  $build_targ;
-}
 
 sub alienfile
 {
@@ -50,15 +27,11 @@ sub alienfile
   $filename = path($filename)->absolute;
   my %args = @_ == 0 ? (filename => 'alienfile') : @_ % 2 ? ( source => do { '# line '. $line . ' "' . path($filename)->absolute . qq("\n) . $_[0] }) : @_;
 
-  require alienfile;
-  push @alienfile::EXPORT, 'targ' unless any { /^targ$/ } @alienfile::EXPORT;
-
-  my $temp = Alien::Build::Temp->newdir;
   my $get_temp_root = do{
     my $root; # may be undef;
     sub {
-      $root ||= Path::Tiny->new($temp);
-
+      $root ||= Path::Tiny->new(tempdir( CLEANUP => 1 ));
+      
       if(@_)
       {
         my $path = $root->child(@_);
@@ -71,11 +44,11 @@ sub alienfile
       }
     };
   };
-
+  
   if($args{source})
   {
     my $file = $get_temp_root->()->child('alienfile');
-    $file->spew_utf8($args{source});
+    $file->spew($args{source});
     $args{filename} = $file->stringify;
   }
   else
@@ -86,16 +59,16 @@ sub alienfile
     }
     $args{filename} = path($args{filename})->absolute->stringify;
   }
-
+  
   $args{stage}  ||= $get_temp_root->('stage')->stringify;
   $args{prefix} ||= $get_temp_root->('prefix')->stringify;
   $args{root}   ||= $get_temp_root->('root')->stringify;
 
   require Alien::Build;
-
-  _alienfile_clear();
+  
+  undef $build;
+  undef $build_root;
   my $out = capture_merged {
-    $build_targ = $args{targ};
     $build = Alien::Build->load($args{filename}, root => $args{root});
     $build->set_stage($args{stage});
     $build->set_prefix($args{prefix});
@@ -105,103 +78,36 @@ sub alienfile
   $ctx->note($out) if $out;
   $ctx->release;
 
-  $build_alienfile = $args{filename};
-  $build_root      = $temp;
+  $build_root = $get_temp_root->();
   $build
 }
 
-sub _alienfile_clear
-{
-  eval { defined $build_root && -d $build_root && path($build_root)->remove_tree };
-  undef $build;
-  undef $build_alienfile;
-  undef $build_root;
-  undef $build_targ;
-}
-
 
 sub alienfile_ok
 {
-  my $build;
-  my $name;
-  my $error;
-
-  if(@_ == 1 && ! defined $_[0])
-  {
-    $build = $_[0];
-    $error = 'no alienfile given';
-    $name = 'alienfile compiled';
-  }
-  elsif(@_ == 1 && eval { $_[0]->isa('Alien::Build') })
-  {
-    $build = $_[0];
-    $name = 'alienfile compiled';
-  }
-  else
-  {
-    $build = eval { alienfile(@_) };
-    $error = $@;
-    $name = 'alienfile compiles';
-  }
-
+  my $build = eval { alienfile(@_) };
+  my $error = $@;
   my $ok = !! $build;
-
+  
   my $ctx = context();
-  $ctx->ok($ok, $name);
+  $ctx->ok($ok, 'alienfile compiles');
   $ctx->diag("error: $error") if $error;
   $ctx->release;
-
+  
   $build;
 }
 
 
-sub alienfile_skip_if_missing_prereqs
-{
-  my($phase) = @_;
-
-  if($build)
-  {
-    eval { $build->load_requires('configure', 1) };
-    if(my $error = $@)
-    {
-      my $reason = "Missing configure prereq";
-      if($error =~ /Required (.*) (.*),/)
-      {
-        $reason .= ": $1 $2";
-      }
-      my $ctx = context();
-      $ctx->plan(0, SKIP => $reason);
-      $ctx->release;
-      return;
-    }
-    $phase ||= $build->install_type;
-    eval { $build->load_requires($phase, 1) };
-    if(my $error = $@)
-    {
-      my $reason = "Missing $phase prereq";
-      if($error =~ /Required (.*) (.*),/)
-      {
-        $reason .= ": $1 $2";
-      }
-      my $ctx = context();
-      $ctx->plan(0, SKIP => $reason);
-      $ctx->release;
-      return;
-    }
-  }
-}
-
-
 sub alien_install_type_is
 {
   my($type, $name) = @_;
 
-  croak "invalid install type" unless defined $type && $type =~ /^(system|share)$/;
+  croak "invalid install type" unless defined $type && $type =~ /^(system|share)$/;  
   $name ||= "alien install type is $type";
-
+  
   my $ok = 0;
   my @diag;
-
+  
   if($build)
   {
     my($out, $actual) = capture_merged {
@@ -221,7 +127,7 @@ sub alien_install_type_is
   {
     push @diag, 'no alienfile'
   }
-
+  
   my $ctx = context();
   $ctx->ok($ok, $name);
   $ctx->diag($_) for @diag;
@@ -234,14 +140,13 @@ sub alien_install_type_is
 sub alien_download_ok
 {
   my($name) = @_;
-
+  
   $name ||= 'alien download';
-
+  
   my $ok;
   my $file;
   my @diag;
-  my @note;
-
+  
   if($build)
   {
     my($out, $error) = capture_merged {
@@ -264,12 +169,10 @@ sub alien_download_ok
       if(-d $file || -f $file)
       {
         $ok = 1;
-        push @note, $out if defined $out;
       }
       else
       {
         $ok = 0;
-        push @diag, $out if defined $out;
         push @diag, 'no file or directory';
       }
     }
@@ -279,10 +182,9 @@ sub alien_download_ok
     $ok = 0;
     push @diag, 'no alienfile';
   }
-
+  
   my $ctx = context();
   $ctx->ok($ok, $name);
-  $ctx->note($_) for @note;
   $ctx->diag($_) for @diag;
   $ctx->release;
 
@@ -293,12 +195,12 @@ sub alien_download_ok
 sub alien_extract_ok
 {
   my($archive, $name) = @_;
-
+  
   $name ||= $archive ? "alien extraction of $archive" : 'alien extraction';
   my $ok;
   my $dir;
   my @diag;
-
+  
   if($build)
   {
     my($out, $error);
@@ -335,7 +237,7 @@ sub alien_extract_ok
     $ok = 0;
     push @diag, 'no alienfile';
   }
-
+  
   my $ctx = context();
   $ctx->ok($ok, $name);
   $ctx->diag($_) for @diag;
@@ -359,7 +261,7 @@ sub alien_build_ok
   my @diag;
   my @note;
   my $alien;
-
+  
   if($build)
   {
     my($out,$error) = capture_merged {
@@ -380,27 +282,27 @@ sub alien_build_ok
     else
     {
       $ok = 1;
-
+      
       push @note, $out if defined $out;
-
+      
       require Alien::Base;
-
+      
       my $prefix = $build->runtime_prop->{prefix};
       my $stage  = $build->install_prop->{stage};
       my %prop   = %{ $build->runtime_prop };
-
+      
       $prop{distdir} = $prefix;
-
+      
       _mirror $stage, $prefix;
-
+      
       my $dist_dir = sub {
         $prefix;
       };
-
+      
       my $runtime_prop = sub {
         \%prop;
       };
-
+      
       $alien = sprintf 'Test::Alien::Build::Faux%04d', $count++;
       {
         no strict 'refs';
@@ -415,13 +317,13 @@ sub alien_build_ok
     $ok = 0;
     push @diag, 'no alienfile';
   }
-
+  
   my $ctx = context();
   $ctx->ok($ok, $name);
   $ctx->diag($_) for @diag;
   $ctx->note($_) for @note;
   $ctx->release;
-
+  
   $alien;
 }
 
@@ -431,7 +333,7 @@ sub alien_build_clean
   my $ctx = context();
   if($build_root)
   {
-    foreach my $child (path($build_root)->children)
+    foreach my $child ($build_root->children)
     {
       next if $child->basename eq 'prefix';
       $ctx->note("clean: rm: $child");
@@ -445,169 +347,7 @@ sub alien_build_clean
   $ctx->release;
 }
 
-
-sub alien_clean_install
-{
-  my($name) = @_;
-
-  $name ||= "run clean_install";
-
-  my $ok;
-  my @diag;
-  my @note;
-
-  if($build)
-  {
-    my($out,$error) = capture_merged {
-      eval {
-        $build->clean_install;
-      };
-      $@;
-    };
-    if($error)
-    {
-      $ok = 0;
-      push @diag, $out if defined $out && $out ne '';
-      push @diag, "build threw exception: $error";
-    }
-    else
-    {
-      $ok = 1;
-      push @note, $out if defined $out && $out ne '';
-    }
-  }
-  else
-  {
-    $ok = 0;
-    push @diag, 'no alienfile';
-  }
-
-  my $ctx = context();
-  $ctx->ok($ok, $name);
-  $ctx->diag($_) for @diag;
-  $ctx->note($_) for @note;
-  $ctx->release;
-}
-
-
-sub alien_checkpoint_ok
-{
-  my($name) = @_;
-
-  $name ||= "alien checkpoint ok";
-  my $ok;
-  my @diag;
-
-  if($build)
-  {
-    eval { $build->checkpoint };
-    if($@)
-    {
-      push @diag, "error in checkpoint: $@";
-      $ok = 0;
-    }
-    else
-    {
-      $ok = 1;
-    }
-    undef $build;
-  }
-  else
-  {
-    push @diag, "no build to checkpoint";
-    $ok = 0;
-  }
-
-  my $ctx = context();
-  $ctx->ok($ok, $name);
-  $ctx->diag($_) for @diag;
-  $ctx->release;
-
-  $ok;
-}
-
-
-sub alien_resume_ok
-{
-  my($name) = @_;
-
-  $name ||= "alien resume ok";
-  my $ok;
-  my @diag;
-
-  if($build_alienfile && $build_root && !defined $build)
-  {
-    $build = eval { Alien::Build->resume($build_alienfile, "$build_root/root") };
-    if($@)
-    {
-      push @diag, "error in resume: $@";
-      $ok = 0;
-    }
-    else
-    {
-      $ok = 1;
-    }
-  }
-  else
-  {
-    if($build)
-    {
-      push @diag, "build has not been checkpointed";
-    }
-    else
-    {
-      push @diag, "no build to resume";
-    }
-    $ok = 0;
-  }
-
-  my $ctx = context();
-  $ctx->ok($ok, $name);
-  $ctx->diag($_) for @diag;
-  $ctx->release;
-
-  ($ok && $build) || $ok;
-}
-
-
-my $alien_rc_root;
-
-sub alien_rc
-{
-  my($code) = @_;
-
-  croak "passed in undef rc" unless defined $code;
-  croak "looks like you have already defined a rc.pl file" if $ENV{ALIEN_BUILD_RC} ne '-';
-
-  my(undef, $filename, $line) = caller;
-  my $code2 = "use strict; use warnings;\n" .
-              '# line ' . $line . ' "' . path($filename)->absolute . "\n$code";
-
-  $alien_rc_root ||= Alien::Build::Temp->newdir;
-
-  my $rc = path($alien_rc_root)->child('rc.pl');
-  $rc->spew_utf8($code2);
-  $ENV{ALIEN_BUILD_RC} = "$rc";
-  return 1;
-}
-
-
-sub alien_subtest
-{
-  my($name, $code, @args) = @_;
-
-  _alienfile_clear;
-
-  my $ctx = context();
-  my $pass = run_subtest($name, $code, { buffered => 1 }, @args);
-  $ctx->release;
-
-  _alienfile_clear;
-
-  $pass;
-}
-
-delete $ENV{$_} for qw( ALIEN_BUILD_LOG ALIEN_BUILD_PRELOAD ALIEN_BUILD_POSTLOAD ALIEN_INSTALL_TYPE PKG_CONFIG_PATH );
+delete $ENV{$_} for qw( ALIEN_BUILD_PRELOAD ALIEN_BUILD_POSTLOAD ALIEN_INSTALL_TYPE );
 $ENV{ALIEN_BUILD_RC} = '-';
 
 1;
@@ -624,7 +364,7 @@ Test::Alien::Build - Tools for testing Alien::Build + alienfile
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -634,7 +374,7 @@ version 1.99_01
  # returns an instance of Alien::Build.
  my $build = alienfile_ok q{
    use alienfile;
- 
+   
    plugin 'My::Plugin' => (
      foo => 1,
      bar => 'string',
@@ -708,31 +448,10 @@ The install prefix for the build.
  my $build = alienfile_ok;
  my $build = alienfile_ok q{ use alienfile ... };
  my $build = alienfile_ok filename => 'alienfile';
- my $build = alienfile_ok $build;
 
 Same as C<alienfile> above, except that it runs as a test, and will not throw an exception
 on failure (it will return undef instead).
 
-[version 1.49]
-
-As of version 1.49 you can also pass in an already formed instance of L<Alien::Build>.  This
-allows you to do something like this:
-
- subtest 'a subtest' => sub {
-   my $build = alienfile q{ use alienfile; ... };
-   alienfile_skip_if_missing_prereqs; # skip if alienfile prereqs are missing
-   alienfile_ok $build;  # delayed pass/fail for the compile of alienfile
- };
-
-=head2 alienfile_skip_if_missing_prereqs
-
- alienfile_skip_if_missing_prereqs;
- alienfile_skip_if_missing_prereqs $phase;
-
-Skips the test or subtest if the prereqs for the alienfile are missing.
-If C<$phase> is not given, then either C<share> or C<system> will be
-detected.
-
 =head2 alien_install_type_is
 
  alien_install_type_is $type;
@@ -788,42 +507,6 @@ be a subclass of L<Alien::Base>, or at least adhere to its API.
 Removes all files with the current build, except for the runtime prefix.
 This helps test that the final install won't depend on the build files.
 
-=head2 alien_clean_install
-
- alien_clean_install;
-
-Runs C<$build-E<gt>clean_install>, and verifies it did not crash.
-
-=head2 alien_checkpoint_ok
-
- alien_checkpoint_ok;
- alien_checkpoint_ok $test_name;
-
-Test the checkpoint of a build.
-
-=head2 alien_resume_ok
-
- alien_resume_ok;
- alien_resume_ok $test_name;
-
-Test a resume a checkpointed build.
-
-=head2 alien_rc
-
- alien_rc $code;
-
-Creates C<rc.pl> file in a temp directory and sets ALIEN_BUILD_RC.  Useful for testing
-plugins that should be called from C<~/.alienbuild/rc.pl>.  Note that because of the
-nature of how the C<~/.alienbuild/rc.pl> file works, you can only use this once!
-
-=head2 alien_subtest
-
- alienfile_subtest $test_name => sub {
-   ...
- };
-
-Clear the build object and clear the build object before and after the subtest.
-
 =head1 SEE ALSO
 
 =over 4
@@ -846,7 +529,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -860,7 +543,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -878,27 +561,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
