@@ -5,8 +5,7 @@ use warnings;
 use Test2::API qw( context );
 
 # ABSTRACT: Run object
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub out    { shift->{out} }
@@ -38,10 +37,10 @@ sub success
 sub exit_is
 {
   my($self, $exit, $message) = @_;
-
+  
   $message ||= "command exited with value $exit";
   my $ok = $self->exit == $exit;
-
+  
   my $ctx = context();
   $ctx->ok($ok, $message);
   $ctx->diag("  actual exit value was: @{[ $self->exit ]}") unless $ok;
@@ -53,10 +52,10 @@ sub exit_is
 sub exit_isnt
 {
   my($self, $exit, $message) = @_;
-
+  
   $message ||= "command exited with value not $exit";
   my $ok = $self->exit != $exit;
-
+  
   my $ctx = context();
   $ctx->ok($ok, $message);
   $ctx->diag("  actual exit value was: @{[ $self->exit ]}") unless $ok;
@@ -68,11 +67,11 @@ sub exit_isnt
 sub _like
 {
   my($self, $regex, $source, $not, $message) = @_;
-
+  
   my $ok = $self->{$source} =~ $regex;
   $ok = !$ok if $not;
-
-  my $ctx = context();
+  
+  my $ctx = context();  
   $ctx->ok($ok, $message);
   unless($ok)
   {
@@ -82,7 +81,7 @@ sub _like
     $ctx->diag("    $regex");
   }
   $ctx->release;
-
+  
   $self;
 }
 
@@ -121,7 +120,7 @@ sub err_unlike
 sub note
 {
   my($self) = @_;
-  my $ctx = context();
+  my $ctx = context();  
   $ctx->note("[cmd]");
   $ctx->note("  @{$self->{cmd}}");
   if($self->out ne '')
@@ -173,7 +172,7 @@ Test::Alien::Run - Run object
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -299,7 +298,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -313,7 +312,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -331,27 +330,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
