@@ -5,8 +5,7 @@ use warnings;
 use Test2::API qw( context );
 
 # ABSTRACT: A mock alien object for testing
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
 sub _def ($) { my($val) = @_; defined $val ? $val : '' }
@@ -59,21 +58,21 @@ Test::Alien::Synthetic - A mock alien object for testing
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use Test2::V0;
  use Test::Alien;
  
+ plan 1;
+ 
  my $alien = synthetic {
    cflags => '-I/foo/bar/include',
    libs   => '-L/foo/bar/lib -lbaz',
  };
  
  alien_ok $alien;
- 
- done_testing;
 
 =head1 DESCRIPTION
 
@@ -130,6 +129,8 @@ based L<Alien> distribution.
  use Test::Alien;
  use Alien::Libarchive;
  
+ plan 5;
+ 
  my $real = Alien::Libarchive->new;
  my $alien = synthetic {
    cflags       => scalar $real->cflags,
@@ -141,6 +142,7 @@ based L<Alien> distribution.
  
  xs_ok do { local $/; <DATA> }, with_subtest {
    my($module) = @_;
+   plan 1;
    my $ptr = $module->archive_read_new;
    like $ptr, qr{^[0-9]+$};
    $module->archive_read_free($ptr);
@@ -155,8 +157,6 @@ based L<Alien> distribution.
    $free->($ptr);
  };
  
- done_testing;
- 
  __DATA__
  
  #include "EXTERN.h"
@@ -195,7 +195,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -209,7 +209,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -227,27 +227,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
