@@ -10,11 +10,10 @@ use Carp ();
 sub _path { Path::Tiny::path(@_) }
 
 # ABSTRACT: Specification for defining an external dependency for CPAN
-our $VERSION = '1.99_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '1.01'; # VERSION
 
 
-our @EXPORT = qw( requires on plugin probe configure share sys download fetch decode prefer extract patch patch_ffi build build_ffi gather gather_ffi meta_prop ffi log test start_url before after );
+our @EXPORT = qw( requires on plugin probe configure share sys download fetch decode prefer extract patch patch_ffi build build_ffi gather gather_ffi meta_prop ffi log );
 
 
 sub requires
@@ -31,9 +30,52 @@ sub requires
 sub plugin
 {
   my($name, @args) = @_;
+  
+  my $class;
+  my $pm;
+  my $found;
+  
+  if($name =~ /^=(.*)$/)
+  {
+    $class = $1;
+    $pm    = $class;
+    $pm =~ s!::!/!g;
+    $pm .= ".pm";
+    $found = 1;
+  }
+  
+  if($name !~ /::/ && ! $found)
+  {
+    foreach my $inc (@INC)
+    {
+      # TODO: allow negotiators to work with
+      # @INC hooks
+      next if ref $inc;
+      my $file = _path("$inc/Alien/Build/Plugin/$name/Negotiate.pm");
+      if(-r $file)
+      {
+        $class = "Alien::Build::Plugin::${name}::Negotiate";
+        $pm    = "Alien/Build/Plugin/$name/Negotiate.pm";
+        $found = 1;
+        last;
+      }
+    }
+  }
+  
+  unless($found)
+  {
+    $class = "Alien::Build::Plugin::$name";
+    $pm    = do {
+      my $name = $name;
+      $name =~ s!::!/!g;
+      "Alien/Build/Plugin/$name.pm";
+    };
+  }
 
+  require $pm unless $class->can('new');  
   my $caller = caller;
-  $caller->meta->apply_plugin($name, @args);
+  my $plugin = $class->new(@args);
+  $plugin->init($caller->meta);
   return;
 }
 
@@ -91,18 +133,6 @@ sub _in_phase
     unless $meta->{phase} eq $phase;
 }
 
-sub start_url
-{
-  my($url) = @_;
-  _in_phase 'share';
-  my $caller = caller;
-  my $meta = $caller->meta;
-  $meta->prop->{start_url} = $url;
-  $meta->add_requires('configure' => 'Alien::Build' => '1.19');
-  return;
-}
-
-
 sub download
 {
   my($instr) = @_;
@@ -255,99 +285,6 @@ sub log
   goto &Alien::Build::log;
 }
 
-
-sub test
-{
-  my($instr) = @_;
-  my $caller = caller;
-  my $meta = $caller->meta;
-  my $phase = $meta->{phase};
-  Carp::croak "test is not allowed in $phase block"
-    if $phase eq 'any' || $phase eq 'configure';
-
-  $meta->add_requires('configure' => 'Alien::Build' => '1.14');
-
-  if($phase eq 'share')
-  {
-    my $suffix = $caller->meta->{build_suffix} || '_share';
-    $meta->register_hook(
-      "test$suffix" => $instr,
-    );
-  }
-  elsif($phase eq 'system')
-  {
-    $meta->register_hook(
-      "test_system" => $instr,
-    );
-  }
-  else
-  {
-    die "unknown phase: $phase";
-  }
-}
-
-
-my %modifiers = (
-  probe    => { any   => 'probe'    },
-  download => { share => 'download' },
-  fetch    => { share => 'fetch'    },
-  decode   => { share => 'fetch'    },
-  prefer   => { share => 'prefer'   },
-  extract  => { share => 'extract'  },
-  patch    => { share => 'patch$'   },
-  build    => { share => 'build$'   },
-  test     => { share => 'test$'    },
-  # Note: below special case gather_ffi for the ffi block :P
-  gather   => { share => 'gather_share', system => 'gather_system', any => 'gather_share,gather_system' },
-);
-
-sub _add_modifier
-{
-  my($type, $stage, $sub) = @_;
-
-  my $method = "${type}_hook";
-
-  Carp::croak "No such stage $stage" unless defined $modifiers{$stage};
-  Carp::croak "$type $stage argument must be a code reference" unless defined $sub && ref($sub) eq 'CODE';
-
-  my $caller = caller;
-  my $meta = $caller->meta;
-  Carp::croak "$type $stage is not allowed in sys block" unless defined $modifiers{$stage}->{$meta->{phase}};
-
-  $meta->add_requires('configure' => 'Alien::Build' => '1.40');
-
-  my $suffix = $meta->{build_suffix};
-  if($suffix eq '_ffi' && $stage eq 'gather')
-  {
-    $meta->$method('gather_ffi' => $sub);
-  }
-
-  foreach my $hook (
-    map { split /,/, $_ }                        # split on , for when multiple hooks must be attachewd (gather in any)
-    map { my $x = $_ ; $x =~ s/\$/$suffix/; $x } # substitute $ at the end for a suffix (_ffi) if any
-    $modifiers{$stage}->{$meta->{phase}})        # get the list of modifiers
-  {
-    $meta->$method($hook => $sub);
-  }
-
-  return;
-}
-
-sub before
-{
-  my($stage, $sub) = @_;
-  @_ = ('before', @_);
-  goto &alienfile::_add_modifier;
-}
-
-
-sub after
-{
-  my($stage, $sub) = @_;
-  @_ = ('after', @_);
-  goto &alienfile::_add_modifier;
-}
-
 sub import
 {
   strict->import;
@@ -369,7 +306,7 @@ alienfile - Specification for defining an external dependency for CPAN
 
 =head1 VERSION
 
-version 1.99_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -380,22 +317,20 @@ Do-it-yourself approach:
  probe [ 'pkg-config --exists libarchive' ];
  
  share {
- 
-   start_url 'http://libarchive.org/downloads/libarchive-3.2.2.tar.gz';
- 
+
    # the first one which succeeds will be used
-   download [ 'wget %{.meta.start_url}' ];
-   download [ 'curl -o %{.meta.start_url}' ];
- 
+   download [ 'wget http://libarchive.org/downloads/libarchive-3.2.2.tar.gz' ];
+   download [ 'curl -o http://libarchive.org/downloads/libarchive-3.2.2.tar.gz' ];
+   
    extract [ 'tar xf %{.install.download}' ];
- 
-   build [
+   
+   build [ 
      # Note: will not work on Windows, better to use Build::Autoconf plugin
      # if you need windows support
      './configure --prefix=%{.install.prefix} --disable-shared',
      '%{make}',
      '%{make} install',
-   ];
+   ];   
  }
  
  gather [
@@ -411,13 +346,13 @@ With plugins (better):
  plugin 'PkgConfig' => 'libarchive';
  
  share {
-   start_url 'http://libarchive.org/downloads/';
    plugin Download => (
+     url => 'http://libarchive.org/downloads/',
      filter => qr/^libarchive-.*\.tar\.gz$/,
      version => qr/([0-9\.]+)/,
    );
    plugin Extract => 'tar.gz';
-   plugin 'Build::Autoconf';
+   plugin 'Build::Autoconf' => ();
    build [
      '%{configure} --disable-shared',
      '%{make}',
@@ -437,27 +372,27 @@ for those libraries.
 "any" requirement (either share or system):
 
  requires $module;
- requires $module => $version;
+ requires $module => $verson;
 
 configure time requirement:
 
  configure {
    requires $module;
-   requires $module => $version;
+   requires $module => $verson;
  };
 
 system requirement:
 
  sys {
    requires $module;
-   requires $module => $version;
+   requires $module => $verson;
  };
 
 share requirement:
 
  share {
    requires $module;
-   requires $module => $version;
+   requires $module => $verson;
  };
 
 specifies a requirement.  L<Alien::Build> takes advantage of dynamic requirements, so only
@@ -502,8 +437,8 @@ Examples:
  plugin 'Fetch' => 'http://ftp.gnu.org/gnu/gcc';
  
  # loads the plugin with the badly named class!
- plugin '=Badly::Named::Plugin::Not::In::Alien::Build::Namespace';
- 
+ plugin '=Badly::Named::Plugin::Not::In::Alien::Build::Namespace' => ();
+
  # explicitly loads Alien::Build::Plugin::Prefer::SortVersions
  plugin 'Prefer::SortVersions => (
    filter => qr/^gcc-.*\.tar\.gz$/,
@@ -543,14 +478,6 @@ System block.  Allowed directives are: requires and gather.
 
 System block.  Allowed directives are: download, fetch, decode, prefer, extract, build, gather.
 
-=head2 start_url
-
- share {
-   start_url $url;
- };
-
-Set the start URL for download.  This should be the URL to an index page, or the actual tarball of the source.
-
 =head2 download
 
  share {
@@ -709,61 +636,6 @@ Returns the meta object for your L<alienfile>.
 
 Prints the given log to stdout.
 
-=head2 test
-
- share {
-   test \&code;
-   test \@commandlist;
- };
- sys {
-   test \&code;
-   test \@commandlist;
- };
-
-Run the tests
-
-=head2 before
-
- before $stage => \&code;
-
-Execute the given code before the given stage.  Stage should be one of
-C<probe>, C<download>, C<fetch>, C<decode>, C<prefer>, C<extract>,
-C<patch>, C<build>, C<test>, and C<gather>.
-
-The before directive is only legal in the same blocks as the stage would
-normally be legal in.  For example, you can't do this:
-
- use alienfile;
- 
- sys {
-   before 'build' => sub {
-     ...
-   };
- };
-
-Because a C<build> wouldn't be legal inside a C<sys> block.
-
-=head2 after
-
- after $stage => \&code;
-
-Execute the given code after the given stage.  Stage should be one of
-C<probe>, C<download>, C<fetch>, C<decode>, C<prefer>, C<extract>,
-C<patch>, C<build>, C<test>, and C<gather>.
-
-The after directive is only legal in the same blocks as the stage would
-normally be legal in.  For example, you can't do this:
-
- use alienfile;
- 
- sys {
-   after 'build' => sub {
-     ...
-   };
- };
-
-Because a C<build> wouldn't be legal inside a C<sys> block.
-
 =head1 SEE ALSO
 
 =over 4
@@ -786,7 +658,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey (KIWIROY)
+Roy Storey
 
 Ilya Pavlov
 
@@ -800,7 +672,7 @@ Brian Wightman (MidLifeXis)
 
 Zaki Mughal (zmughal)
 
-mohawk (mohawk2, ETJ)
+mohawk2
 
 Vikas N Kumar (vikasnkumar)
 
@@ -818,27 +690,9 @@ Nicholas Shipp (nshp)
 
 Juan Julián Merelo Guervós (JJ)
 
-Joel Berger (JBERGER)
-
-Petr Pisar (ppisar)
-
-Lance Wicks (LANCEW)
-
-Ahmad Fatoum (a3f, ATHREEF)
-
-José Joaquín Atria (JJATRIA)
-
-Duke Leto (LETO)
-
-Shoichi Kaji (SKAJI)
-
-Shawn Laffan (SLAFFAN)
-
-Paul Evans (leonerd, PEVANS)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
